@@ -3,7 +3,7 @@
 *                     U n d o a b l e   C o m m a n d s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -19,10 +19,12 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: Commands.cpp,v 1.13 2003/10/03 20:58:44 fox Exp $                        *
+* $Id: Commands.cpp,v 1.16 2004/05/15 17:15:30 fox Exp $                        *
 ********************************************************************************/
 #include "fx.h"
 #include "Commands.h"
+#include "FXRex.h"
+#include "FXArray.h"
 #include "Hilite.h"
 #include "TextWindow.h"
 #include "Adie.h"
@@ -46,23 +48,22 @@ FXIMPLEMENT_ABSTRACT(FXTextCommand,FXCommand,NULL,0)
 
 // Return size of record plus any data kept here
 FXuint FXTextCommand::size() const {
-  return sizeof(FXTextCommand)+del;
+  return sizeof(FXTextCommand)+ndel;
   }
 
 
 FXIMPLEMENT_ABSTRACT(FXTextInsert,FXTextCommand,NULL,0)
 
 // Insert command
-FXTextInsert::FXTextInsert(FXText* txt,FXint p,FXint ni):
-  FXTextCommand(txt,p,ni,0){
+FXTextInsert::FXTextInsert(FXText* txt,FXint p,FXint ni,const FXchar* ins):FXTextCommand(txt,p,0,ni){
+  FXMALLOC(&buffer,FXchar,ni);
+  memcpy(buffer,ins,ni);
   }
 
 
 // Undo an insert removes the inserted text
 void FXTextInsert::undo(){
-  FXCALLOC(&buffer,FXchar,ins);
-  text->extractText(buffer,pos,ins);
-  text->removeText(pos,ins,TRUE);
+  text->removeText(pos,nins,TRUE);
   text->setCursorPos(pos);
   text->makePositionVisible(pos);
   }
@@ -70,37 +71,32 @@ void FXTextInsert::undo(){
 
 // Redo an insert inserts the same old text again
 void FXTextInsert::redo(){
-  text->insertText(pos,buffer,ins,TRUE);
-  text->setCursorPos(pos+ins);
-  text->makePositionVisible(pos+ins);
-  FXFREE(&buffer);
+  text->insertText(pos,buffer,nins,TRUE);
+  text->setCursorPos(pos+nins);
+  text->makePositionVisible(pos+nins);
   }
 
 
 FXIMPLEMENT_ABSTRACT(FXTextDelete,FXTextCommand,NULL,0)
 
 // Delete command
-FXTextDelete::FXTextDelete(FXText* txt,FXint p,FXint nd):
-  FXTextCommand(txt,p,0,nd){
-  FXCALLOC(&buffer,FXchar,del);
-  text->extractText(buffer,pos,del);
+FXTextDelete::FXTextDelete(FXText* txt,FXint p,FXint nd,const FXchar* del):FXTextCommand(txt,p,nd,0){
+  FXMALLOC(&buffer,FXchar,nd);
+  memcpy(buffer,del,nd);
   }
 
 
 // Undo a delete reinserts the old text
 void FXTextDelete::undo(){
-  text->insertText(pos,buffer,del,TRUE);
-  text->setCursorPos(pos+del);
-  text->makePositionVisible(pos+del);
-  FXFREE(&buffer);
+  text->insertText(pos,buffer,ndel,TRUE);
+  text->setCursorPos(pos+ndel);
+  text->makePositionVisible(pos+ndel);
   }
 
 
 // Redo a delete removes it again
 void FXTextDelete::redo(){
-  FXCALLOC(&buffer,FXchar,del);
-  text->extractText(buffer,pos,del);
-  text->removeText(pos,del,TRUE);
+  text->removeText(pos,ndel,TRUE);
   text->setCursorPos(pos);
   text->makePositionVisible(pos);
   }
@@ -109,35 +105,25 @@ void FXTextDelete::redo(){
 FXIMPLEMENT_ABSTRACT(FXTextReplace,FXTextCommand,NULL,0)
 
 // Replace command
-FXTextReplace::FXTextReplace(FXText* txt,FXint p,FXint nd,FXint ni):
-  FXTextCommand(txt,p,ni,nd){
-  FXCALLOC(&buffer,FXchar,del);
-  text->extractText(buffer,pos,del);
+FXTextReplace::FXTextReplace(FXText* txt,FXint p,FXint nd,FXint ni,const FXchar* del,const FXchar* ins):FXTextCommand(txt,p,nd,ni){
+  FXMALLOC(&buffer,FXchar,nd+ni);
+  memcpy(buffer,del,nd);
+  memcpy(buffer+nd,ins,ni);
   }
 
 
 // Undo a replace reinserts the old text
 void FXTextReplace::undo(){
-  FXchar *tmp;
-  FXMALLOC(&tmp,FXchar,ins);
-  text->extractText(tmp,pos,ins);
-  text->replaceText(pos,ins,buffer,del,TRUE);
-  text->setCursorPos(pos+del);
-  text->makePositionVisible(pos+del);
-  FXFREE(&buffer);
-  buffer=tmp;
+  text->replaceText(pos,nins,buffer,ndel,TRUE);
+  text->setCursorPos(pos+ndel);
+  text->makePositionVisible(pos+ndel);
   }
 
 
 // Redo a replace reinserts the new text
 void FXTextReplace::redo(){
-  FXchar *tmp;
-  FXMALLOC(&tmp,FXchar,del);
-  text->extractText(tmp,pos,del);
-  text->replaceText(pos,del,buffer,ins,TRUE);
-  text->setCursorPos(pos+ins);
-  text->makePositionVisible(pos+ins);
-  FXFREE(&buffer);
-  buffer=tmp;
+  text->replaceText(pos,ndel,buffer+ndel,nins,TRUE);
+  text->setCursorPos(pos+nins);
+  text->makePositionVisible(pos+nins);
   }
 
