@@ -3,7 +3,7 @@
 *                     U n d o a b l e   C o m m a n d s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: Commands.h,v 1.12 2003/10/03 20:58:44 fox Exp $                          *
+* $Id: Commands.h,v 1.14 2004/05/15 17:15:30 fox Exp $                          *
 ********************************************************************************/
 #ifndef COMMANDS_H
 #define COMMANDS_H
@@ -33,10 +33,10 @@ protected:
   FXText *text;     // Text widget
   FXchar *buffer;   // Character buffer
   FXint   pos;      // Character position
-  FXint   del;      // Deleted characters
-  FXint   ins;      // Inserted characters
+  FXint   ndel;     // Deleted characters
+  FXint   nins;     // Inserted characters
 public:
-  FXTextCommand(FXText* txt,FXint p,FXint ni,FXint nd):text(txt),buffer(NULL),pos(p),del(nd),ins(ni){}
+  FXTextCommand(FXText* txt,FXint p,FXint nd,FXint ni):text(txt),buffer(NULL),pos(p),ndel(nd),nins(ni){}
   virtual FXuint size() const;
   virtual ~FXTextCommand(){FXFREE(&buffer);}
   };
@@ -46,7 +46,7 @@ public:
 class FXTextInsert : public FXTextCommand {
   FXDECLARE_ABSTRACT(FXTextInsert)
 public:
-  FXTextInsert(FXText* txt,FXint p,FXint ni);
+  FXTextInsert(FXText* txt,FXint p,FXint ni,const FXchar* ins);
   virtual FXString undoName() const { return "Undo insert"; }
   virtual FXString redoName() const { return "Redo insert"; }
   virtual void undo();
@@ -58,7 +58,7 @@ public:
 class FXTextDelete : public FXTextCommand {
   FXDECLARE_ABSTRACT(FXTextDelete)
 public:
-  FXTextDelete(FXText* txt,FXint p,FXint nd);
+  FXTextDelete(FXText* txt,FXint p,FXint nd,const FXchar* del);
   virtual FXString undoName() const { return "Undo delete"; }
   virtual FXString redoName() const { return "Redo delete"; }
   virtual void undo();
@@ -70,7 +70,7 @@ public:
 class FXTextReplace : public FXTextCommand {
   FXDECLARE_ABSTRACT(FXTextReplace)
 public:
-  FXTextReplace(FXText* txt,FXint p,FXint ni,FXint nd);
+  FXTextReplace(FXText* txt,FXint p,FXint nd,FXint ni,const FXchar* del,const FXchar* ins);
   virtual FXString undoName() const { return "Undo replace"; }
   virtual FXString redoName() const { return "Redo replace"; }
   virtual void undo();
