@@ -3,7 +3,7 @@
 *                     T h e   A d i e   T e x t   E d i t o r                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This program is free software; you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
@@ -19,10 +19,9 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: main.cpp,v 1.9 2003/08/29 14:36:37 fox Exp $                             *
+* $Id: main.cpp,v 1.12 2004/05/15 17:15:30 fox Exp $                            *
 ********************************************************************************/
 #include "fx.h"
-#include "FXRex.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -31,6 +30,8 @@
 #include <unistd.h>
 #endif
 #include <ctype.h>
+#include "FXRex.h"
+#include "FXArray.h"
 #include "Hilite.h"
 #include "TextWindow.h"
 #include "Adie.h"
@@ -63,8 +64,8 @@ int main(int argc,char *argv[]){
   FXchar     *language=NULL;
   FXchar     *tags=NULL;
   FXbool      edit=TRUE;
-  FXString    file;
   FXint       line=0;
+  FXString    file;
   FXint       arg;
   FXint       x,y,w,h,g;
 
@@ -124,8 +125,8 @@ int main(int argc,char *argv[]){
       window->readBookmarks(file);
       window->readView(file);
       window->setEditable(edit);
-      //window->setLanguage(language);
-      //window->gotoLine(line);
+      if(language) window->forceSyntax(language);
+      if(line) window->visitLine(line);
       }
     }
 
@@ -133,7 +134,7 @@ int main(int argc,char *argv[]){
   if(!window){
     window=new TextWindow(&application,"untitled");
     window->create();
-    //window->setLanguage(language);
+    if(language) window->forceSyntax(language);
     }
 
   // Run
