@@ -3,7 +3,7 @@
 *                          C a n v a s   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCanvas.h,v 1.11 2001/08/23 16:24:51 jeroen Exp $                       *
+* $Id: FXCanvas.h,v 1.17 2004/02/08 17:17:33 fox Exp $                          *
 ********************************************************************************/
 #ifndef FXCANVAS_H
 #define FXCANVAS_H
 
+#ifndef FXWINDOW_H
+#include "FXWindow.h"
+#endif
+
+namespace FX {
 
 
 /// Canvas, an area drawn by another object
@@ -48,5 +53,6 @@ public:
   virtual FXbool canFocus() const;
   };
 
+}
 
 #endif
