@@ -3,7 +3,7 @@
 *                           C h a r a c t e r   S e t s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,12 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCharset.h,v 1.7 2002/01/18 22:42:51 jeroen Exp $                       *
+* $Id: FXCharset.h,v 1.14 2004/02/08 17:17:33 fox Exp $                         *
 ********************************************************************************/
 #ifndef FXCHARSET_H
 #define FXCHARSET_H
 
+namespace FX {
 
 /// A set of characters
 class FXAPI FXCharset {
@@ -150,7 +151,9 @@ public:
 
   /// Load set from a stream
   friend FXAPI FXStream& operator>>(FXStream& store,FXCharset& cs);
+
   };
 
+}
 
 #endif
