@@ -3,7 +3,7 @@
 *                       D r a g   C o r n e r   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,16 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDragCorner.h,v 1.5 2001/03/23 07:02:41 jeroen Exp $                    *
+* $Id: FXDragCorner.h,v 1.11 2004/02/08 17:17:33 fox Exp $                       *
 ********************************************************************************/
 #ifndef FXDRAGCORNER_H
 #define FXDRAGCORNER_H
 
+#ifndef FXWINDOW_H
+#include "FXWindow.h"
+#endif
+
+namespace FX {
 
 
 /**
@@ -79,6 +84,6 @@ public:
   virtual void load(FXStream& store);
   };
 
-
+}
 
 #endif
