@@ -3,7 +3,7 @@
 *                    F o n t   S e l e c t i o n   D i a l o g                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,17 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFontDialog.h,v 1.6 2001/03/23 07:02:41 jeroen Exp $                    *
+* $Id: FXFontDialog.h,v 1.12 2004/02/08 17:17:33 fox Exp $                      *
 ********************************************************************************/
 #ifndef FXFONTDIALOG_H
 #define FXFONTDIALOG_H
 
+#ifndef FXDIALOGBOX_H
+#include "FXDialogBox.h"
+#endif
+
+namespace FX {
+
 
 class FXFontSelector;
 
@@ -58,5 +64,6 @@ public:
   virtual ~FXFontDialog();
   };
 
+}
 
 #endif
