@@ -3,7 +3,7 @@
 *                         G I F   I m a g e   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGIFImage.h,v 1.9 2002/01/18 22:42:53 jeroen Exp $                      *
+* $Id: FXGIFImage.h,v 1.17 2004/04/24 14:10:29 fox Exp $                        *
 ********************************************************************************/
 #ifndef FXGIFIMAGE_H
 #define FXGIFIMAGE_H
@@ -28,6 +28,7 @@
 #include "FXImage.h"
 #endif
 
+namespace FX {
 
 /// GIF Image class
 class FXAPI FXGIFImage : public FXImage {
@@ -43,22 +44,34 @@ public:
   FXGIFImage(FXApp* a,const void *pix=NULL,FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in [un]GIF format
-  virtual void savePixels(FXStream& store) const;
+  virtual FXbool savePixels(FXStream& store) const;
 
   /// Load pixels from stream in CompuServe GIF format
-  virtual void loadPixels(FXStream& store);
+  virtual FXbool loadPixels(FXStream& store);
 
   /// Destroy
   virtual ~FXGIFImage();
   };
 
 
-/// Load a gif file from a stream
-extern FXAPI FXbool fxloadGIF(FXStream& store,FXuchar*& data,FXColor& transp,FXint& width,FXint& height);
+#ifndef FXLOADGIF
+#define FXLOADGIF
+
+/**
+* Load an GIF (Graphics Interchange Format) file from a stream.
+* Upon successful return, the pixel array and size are returned.
+* If an error occurred, the pixel array is set to NULL.
+*/
+extern FXAPI FXbool fxloadGIF(FXStream& store,FXColor*& data,FXint& width,FXint& height);
 
 
-/// Save a gif file to a stream
-extern FXAPI FXbool fxsaveGIF(FXStream& store,const FXuchar *data,FXColor transp,FXint width,FXint height);
+/**
+* Save an GIF (Graphics Interchange Format) file to a stream.
+*/
+extern FXAPI FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height,FXbool fast=TRUE);
 
+#endif
+
+}
 
 #endif
