@@ -3,7 +3,7 @@
 *             O p e n G L   T r i a n g l e   M e s h   O b j e c t             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,11 +19,17 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLTriangleMesh.h,v 1.7 2001/04/25 05:47:37 jeroen Exp $                *
+* $Id: FXGLTriangleMesh.h,v 1.13 2004/02/08 17:17:33 fox Exp $                  *
 ********************************************************************************/
 #ifndef FXGLTRIANGLEMESH_H
 #define FXGLTRIANGLEMESH_H
-    
+
+#ifndef FXGLSHAPE_H
+#include "FXGLShape.h"
+#endif
+
+namespace FX {
+
 
 /*
  * Arrays Formats
@@ -56,7 +62,7 @@ public:
 
   /// Construct triangle mesh with nv vertices, and optional normals, colors, and texture coordinates, and surface material
   FXGLTriangleMesh(FXfloat x,FXfloat y,FXfloat z,FXint nv,FXfloat *v,FXfloat *n,FXfloat *c,FXfloat *t,const FXMaterial& mtl);
-  
+
   /// Copy constructor
   FXGLTriangleMesh(const FXGLTriangleMesh& orig);
 
@@ -71,7 +77,7 @@ public:
 
   /// Set vertex buffer
   void setVertexBuffer(FXfloat *vertices);
-  
+
   /// Get vertex buffer
   FXfloat* getVertexBuffer() const { return vertexBuffer; }
 
@@ -90,7 +96,7 @@ public:
   /// Set texture coordinate buffer
   void setTextureCoordBuffer(FXfloat *textures){ textureBuffer=textures; }
 
-  /// Get texture coordinate buffer 
+  /// Get texture coordinate buffer
   FXfloat* getTextureCoordBuffer() const { return textureBuffer; }
 
   /// Save to a stream
@@ -103,5 +109,6 @@ public:
   virtual ~FXGLTriangleMesh();
   };
 
+}
 
 #endif
