@@ -3,7 +3,7 @@
 *                       I m a g e   V i e w   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXImageView.h,v 1.8 2002/01/18 22:42:53 jeroen Exp $                     *
+* $Id: FXImageView.h,v 1.13 2004/02/08 17:17:33 fox Exp $                       *
 ********************************************************************************/
 #ifndef FXIMAGEVIEW_H
 #define FXIMAGEVIEW_H
@@ -28,11 +28,24 @@
 #include "FXScrollArea.h"
 #endif
 
+namespace FX {
 
 
 class FXImage;
 
 
+/// Image alignment styles
+enum {
+  IMAGEVIEW_NORMAL    = 0,              /// Normal mode is centered
+  IMAGEVIEW_CENTER_X  = 0,              /// Centered horizontally
+  IMAGEVIEW_LEFT      = 0x00100000,     /// Left-aligned
+  IMAGEVIEW_RIGHT     = 0x00200000,     /// Right-aligned
+  IMAGEVIEW_CENTER_Y  = 0,              /// Centered vertically
+  IMAGEVIEW_TOP       = 0x00400000,     /// Top-aligned
+  IMAGEVIEW_BOTTOM    = 0x00800000      /// Bottom-aligned
+  };
+
+
 /**
 * The Image View widget display a scrollable view of an image.
 */
@@ -44,7 +57,6 @@ protected:
   FXint    graby;         // Grab point y
 protected:
   FXImageView();
-  virtual void layout();
 private:
   FXImageView(const FXImageView&);
   FXImageView &operator=(const FXImageView&);
@@ -69,6 +81,9 @@ public:
   /// Detach server-side resources
   virtual void detach();
 
+  /// Perform layout
+  virtual void layout();
+
   /// Image view widget can receive focus
   virtual FXbool canFocus() const;
 
@@ -84,6 +99,12 @@ public:
   /// Return image
   FXImage* getImage() const { return image; }
 
+  /// Set the current alignment.
+  void setAlignment(FXuint mode);
+
+  /// Get the current alignment.
+  FXuint getAlignment() const;
+
   /// Save list to a stream
   virtual void save(FXStream& store) const;
 
@@ -94,5 +115,6 @@ public:
   virtual ~FXImageView();
   };
 
+}
 
 #endif
