@@ -1,9 +1,9 @@
 /********************************************************************************
 *                                                                               *
-*                     M e n u   C o m m a n d   W i d g e t                     *
+*                       M e n u C o m m a n d   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMenuCommand.h,v 1.19 2002/01/18 22:42:53 jeroen Exp $                  *
+* $Id: FXMenuCommand.h,v 1.26 2004/02/08 17:17:33 fox Exp $                     *
 ********************************************************************************/
 #ifndef FXMENUCOMMAND_H
 #define FXMENUCOMMAND_H
@@ -28,32 +28,21 @@
 #include "FXMenuCaption.h"
 #endif
 
-
-
-/// States the menu command can be in
-enum {
-  MENUSTATE_NORMAL   = 0,           /// Normal, unchecked state
-  MENUSTATE_CHECKED  = 1,           /// Checked with a checkmark
-  MENUSTATE_RCHECKED = 2            /// Checked with a bullet
-  };
+namespace FX {
 
 
 /**
 * The menu command widget is used to invoke a command in the
 * application from a menu.  Menu commands may reflect
-* the state of the application by graying out, becoming hidden,
-* or by a check mark or bullit.
+* the state of the application by graying out, or becoming hidden.
 */
 class FXAPI FXMenuCommand : public FXMenuCaption {
   FXDECLARE(FXMenuCommand)
 protected:
-  FXuchar      state;       // State of menu
   FXString     accel;       // Accelerator string
   FXHotKey     acckey;      // Accelerator key
 protected:
   FXMenuCommand();
-  void drawCheck(FXDCWindow& dc,FXint x,FXint y);
-  void drawBullit(FXDCWindow& dc,FXint x,FXint y);
 private:
   FXMenuCommand(const FXMenuCommand&);
   FXMenuCommand &operator=(const FXMenuCommand&);
@@ -67,11 +56,6 @@ public:
   long onKeyRelease(FXObject*,FXSelector,void*);
   long onHotKeyPress(FXObject*,FXSelector,void*);
   long onHotKeyRelease(FXObject*,FXSelector,void*);
-  long onCheck(FXObject*,FXSelector,void*);
-  long onUncheck(FXObject*,FXSelector,void*);
-  long onCmdSetValue(FXObject*,FXSelector,void*);
-  long onCmdSetIntValue(FXObject*,FXSelector,void*);
-  long onCmdGetIntValue(FXObject*,FXSelector,void*);
   long onCmdAccel(FXObject*,FXSelector,void*);
 public:
 
@@ -93,24 +77,6 @@ public:
   /// Remove the focus from this window
   virtual void killFocus();
 
-  /// Place checkmark next to text
-  void check();
-
-  /// Uncheck the item
-  void uncheck();
-
-  /// Return TRUE if checked
-  FXint isChecked() const;
-
-  /// Place radio bullit next to text
-  void checkRadio();
-
-  /// Uncheck radio bullit
-  void uncheckRadio();
-
-  /// Return TRUE if radio-checked
-  FXint isRadioChecked() const;
-
   /// Set accelerator text
   void setAccelText(const FXString& text);
 
@@ -127,5 +93,6 @@ public:
   virtual ~FXMenuCommand();
   };
 
+}
 
 #endif
