@@ -3,7 +3,7 @@
 *                         M e s s a g e   B o x e s                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,21 +19,27 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMessageBox.h,v 1.14 2001/08/13 23:20:06 jeroen Exp $                   *
+* $Id: FXMessageBox.h,v 1.23 2004/02/08 17:17:34 fox Exp $                      *
 ********************************************************************************/
 #ifndef FXMESSAGEBOX_H
 #define FXMESSAGEBOX_H
 
+#ifndef FXDIALOGBOX_H
+#include "FXDialogBox.h"
+#endif
+
+namespace FX {
 
 
 // Message box buttons
 enum {
-  MBOX_OK               = 0x10000000,   /// Message box has a only an OK button
-  MBOX_OK_CANCEL        = 0x20000000,   /// Message box has OK and CANCEL buttons
-  MBOX_YES_NO           = 0x30000000,   /// Message box has YES and NO buttons
-  MBOX_YES_NO_CANCEL    = 0x40000000,   /// Message box has YES, NO, and CANCEL buttons
-  MBOX_QUIT_CANCEL      = 0x50000000,   /// Message box has QUIT and CANCEL buttons
-  MBOX_QUIT_SAVE_CANCEL = 0x60000000    /// Message box has QUIT, SAVE, and CANCEL buttons
+  MBOX_OK                 = 0x10000000, /// Message box has a only an OK button
+  MBOX_OK_CANCEL          = 0x20000000, /// Message box has OK and CANCEL buttons
+  MBOX_YES_NO             = 0x30000000, /// Message box has YES and NO buttons
+  MBOX_YES_NO_CANCEL      = 0x40000000, /// Message box has YES, NO, and CANCEL buttons
+  MBOX_QUIT_CANCEL        = 0x50000000, /// Message box has QUIT and CANCEL buttons
+  MBOX_QUIT_SAVE_CANCEL   = 0x60000000, /// Message box has QUIT, SAVE, and CANCEL buttons
+  MBOX_SKIP_SKIPALL_CANCEL =0x70000000  /// Message box has SKIP, SKIP ALL, and CANCEL buttons
   };
 
 
@@ -44,7 +50,9 @@ enum {
   MBOX_CLICKED_OK       = 3,            /// The OK button was clicked
   MBOX_CLICKED_CANCEL   = 4,            /// The CANCEL button was clicked
   MBOX_CLICKED_QUIT     = 5,            /// The QUIT button was clicked
-  MBOX_CLICKED_SAVE     = 6             /// The SAVE button was clicked
+  MBOX_CLICKED_SAVE     = 6,            /// The SAVE button was clicked
+  MBOX_CLICKED_SKIP     = 7,            /// The SKIP button was clicked
+  MBOX_CLICKED_SKIPALL  = 8             /// The SKIP ALL button was clicked
   };
 
 
@@ -56,6 +64,7 @@ protected:
 private:
   FXMessageBox(const FXMessageBox&);
   FXMessageBox &operator=(const FXMessageBox&);
+  void initialize(const FXString& text,FXIcon* ic,FXuint whichbuttons);
 public:
   long onCmdClicked(FXObject*,FXSelector,void*);
   long onCmdCancel(FXObject*,FXSelector,void*);
@@ -67,6 +76,8 @@ public:
     ID_CLICKED_CANCEL,
     ID_CLICKED_QUIT,
     ID_CLICKED_SAVE,
+    ID_CLICKED_SKIP,
+    ID_CLICKED_SKIPALL,
     ID_LAST
     };
 public:
@@ -74,32 +85,55 @@ public:
   /// Construct message box with given caption, icon, and message text
   FXMessageBox(FXWindow* owner,const FXString& caption,const FXString& text,FXIcon* ic=NULL,FXuint opts=0,FXint x=0,FXint y=0);
 
+  /// Construct free floating message box with given caption, icon, and message text
+  FXMessageBox(FXApp* app,const FXString& caption,const FXString& text,FXIcon* ic=NULL,FXuint opts=0,FXint x=0,FXint y=0);
+
   /**
   * Show a modal error message.
   * The text message may contain printf-tyle formatting commands.
   */
   static FXuint error(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
+  /**
+  * Show modal error message, in free floating window.
+  */
+  static FXuint error(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+
   /**
   * Show a modal warning message
   * The text message may contain printf-tyle formatting commands.
   */
   static FXuint warning(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
+  /**
+  * Show modal warning message, in free floating window.
+  */
+  static FXuint warning(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+
   /**
   * Show a modal question dialog
   * The text message may contain printf-tyle formatting commands.
   */
   static FXuint question(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
+  /**
+  * Show modal question message, in free floating window.
+  */
+  static FXuint question(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+
   /**
   * Show a modal information dialog
   * The text message may contain printf-tyle formatting commands.
   */
   static FXuint information(FXWindow* owner,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
 
+  /**
+  * Show modal information message, in free floating window.
+  */
+  static FXuint information(FXApp* app,FXuint opts,const char* caption,const char* message,...) FX_PRINTF(4,5) ;
+
   };
 
-
+}
 
 #endif
