@@ -3,7 +3,7 @@
 *                          P N G   I m a g e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPNGIcon.h,v 1.8 2002/01/18 22:42:54 jeroen Exp $                       *
+* $Id: FXPNGIcon.h,v 1.15 2004/02/08 17:17:34 fox Exp $                         *
 ********************************************************************************/
 #ifndef FXPNGICON_H
 #define FXPNGICON_H
@@ -28,6 +28,9 @@
 #include "FXIcon.h"
 #endif
 
+namespace FX {
+
+
 /// Portable Network Graphics (PNG) Icon class
 class FXAPI FXPNGIcon : public FXIcon {
   FXDECLARE(FXPNGIcon)
@@ -42,22 +45,29 @@ public:
   FXPNGIcon(FXApp *a,const void *pix=NULL,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in PNG format
-  virtual void savePixels(FXStream& store) const;
+  virtual FXbool savePixels(FXStream& store) const;
 
   /// Load pixels from stream in PNG format
-  virtual void loadPixels(FXStream& store);
+  virtual FXbool loadPixels(FXStream& store);
 
   /// Destroy
   virtual ~FXPNGIcon();
   };
 
 
-/// Load a png from a stream
-extern FXAPI FXbool fxloadPNG(FXStream& store,FXuchar*& data,FXColor& transp,FXint& width,FXint& height);
+/**
+* Load an PNG (Portable Network Graphics) file from a stream.
+* Upon successful return, the pixel array and size are returned.
+* If an error occurred, the pixel array is set to NULL.
+*/
+extern FXAPI FXbool fxloadPNG(FXStream& store,FXColor*& data,FXint& width,FXint& height);
 
 
-/// Save a png to a stream
-extern FXAPI FXbool fxsavePNG(FXStream& store,const FXuchar* data,FXColor transp,FXint width,FXint height);
+/**
+* Save an PNG (Portable Network Graphics) file to a stream.
+*/
+extern FXAPI FXbool fxsavePNG(FXStream& store,const FXColor* data,FXint width,FXint height);
 
+}
 
 #endif
