@@ -3,7 +3,7 @@
 *                          T I F F   I c o n   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2002 Eric Gillet.   All Rights Reserved.                   *
+* Copyright (C) 2001,2004 Eric Gillet.   All Rights Reserved.                   *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTIFIcon.h,v 1.7 2002/01/18 22:55:03 jeroen Exp $                       *
+* $Id: FXTIFIcon.h,v 1.15 2004/02/08 17:17:34 fox Exp $                         *
 ********************************************************************************/
 #ifndef FXTIFICON_H
 #define FXTIFICON_H
@@ -28,6 +28,8 @@
 #include "FXIcon.h"
 #endif
 
+namespace FX {
+
 
 /// TIFF Icon class
 class FXAPI FXTIFIcon : public FXIcon {
@@ -51,22 +53,29 @@ public:
   FXuint getCodec() const { return codec; }
 
   /// Save pixels into stream in TIFF format
-  virtual void savePixels(FXStream& store) const;
+  virtual FXbool savePixels(FXStream& store) const;
 
   /// Load pixels from stream in TIFF format
-  virtual void loadPixels(FXStream& store);
+  virtual FXbool loadPixels(FXStream& store);
 
   /// Destroy
   virtual ~FXTIFIcon();
   };
 
 
-/// Load a tiff from a stream
-extern FXAPI FXbool fxloadTIF(FXStream& store,FXuchar*& data,FXColor& transp,FXint& width,FXint& height,FXushort& codec);
+/**
+* Load an TIFF (Tagged Image File Format) file from a stream.
+* Upon successful return, the pixel array and size are returned.
+* If an error occurred, the pixel array is set to NULL.
+*/
+extern FXAPI FXbool fxloadTIF(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXushort& codec);
 
 
-/// Save a tiff to a stream
-extern FXAPI FXbool fxsaveTIF(FXStream& store,const FXuchar* data,FXColor transp,FXint width,FXint height,FXushort codec);
+/**
+* Save an TIFF (Tagged Image File Format) file to a stream.
+*/
+extern FXAPI FXbool fxsaveTIF(FXStream& store,const FXColor* data,FXint width,FXint height,FXushort codec);
 
+}
 
 #endif
