@@ -3,7 +3,7 @@
 *                         T a b   B o o k   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTabBook.h,v 1.3 2002/01/18 22:42:55 jeroen Exp $                       *
+* $Id: FXTabBook.h,v 1.7 2004/02/08 17:17:34 fox Exp $                          *
 ********************************************************************************/
 #ifndef FXTABBOOK_H
 #define FXTABBOOK_H
@@ -28,6 +28,7 @@
 #include "FXTabBar.h"
 #endif
 
+namespace FX {
 
 
 /**
@@ -47,7 +48,6 @@ class FXAPI FXTabBook : public FXTabBar {
   FXDECLARE(FXTabBook)
 protected:
   FXTabBook(){}
-  virtual void layout();
 private:
   FXTabBook(const FXTabBook&);
   FXTabBook& operator=(const FXTabBook&);
@@ -65,6 +65,9 @@ public:
   /// Construct tab book
   FXTabBook(FXComposite* p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=TABBOOK_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_SPACING,FXint pr=DEFAULT_SPACING,FXint pt=DEFAULT_SPACING,FXint pb=DEFAULT_SPACING);
 
+  /// Perform layout
+  virtual void layout();
+
   /// Return default width
   virtual FXint getDefaultWidth();
 
@@ -72,6 +75,6 @@ public:
   virtual FXint getDefaultHeight();
   };
 
-
+}
 
 #endif
