@@ -3,7 +3,7 @@
 *      A d d i t i o n a l   F O X   I n c l u d e   F i l e   F o r   3 D      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fx3d.h,v 1.5.4.1 2003/04/08 14:06:03 fox Exp $                            *
+* $Id: fx3d.h,v 1.19 2004/02/24 06:40:49 fox Exp $                              *
 ********************************************************************************/
 #ifndef FX3D_H
 #define FX3D_H
@@ -31,27 +31,36 @@
 #endif
 #include <windows.h>
 #endif
-#ifdef HAVE_OPENGL
+#ifdef HAVE_GL_H
 #include <GL/gl.h>
+#endif
 #ifndef GLAPIENTRY
 #define GLAPIENTRY
 #endif
 #ifndef GLAPI
 #define GLAPI
 #endif
+#ifdef HAVE_GLU_H
 #include <GL/glu.h>
 #endif
 
 // Additional FOX includes
-#include "FXVec.h"
-#include "FXHVec.h"
-#include "FXQuat.h"
-#include "FXHMat.h"
-#include "FXRange.h"
-#include "FXDVec.h"
-#include "FXDHVec.h"
-#include "FXDQuat.h"
-#include "FXDHMat.h"
+#include "FXVec2f.h"
+#include "FXVec2d.h"
+#include "FXVec3f.h"
+#include "FXVec3d.h"
+#include "FXVec4f.h"
+#include "FXVec4d.h"
+#include "FXQuatf.h"
+#include "FXQuatd.h"
+#include "FXMat3f.h"
+#include "FXMat3d.h"
+#include "FXMat4f.h"
+#include "FXMat4d.h"
+#include "FXRangef.h"
+#include "FXRanged.h"
+#include "FXSpheref.h"
+#include "FXSphered.h"
 #include "FXGLVisual.h"
 #include "FXGLContext.h"
 #include "FXGLCanvas.h"
@@ -64,4 +73,8 @@
 #include "FXGLSphere.h"
 #include "FXGLTriangleMesh.h"
 
+#ifndef FX_NO_GLOBAL_NAMESPACE
+using namespace FX;
+#endif
+
 #endif
