@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: PathFinder.cpp,v 1.93 2003/09/10 03:54:37 fox Exp $                      *
+* $Id: PathFinder.cpp,v 1.99 2004/02/24 14:26:44 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fx.h"
@@ -176,8 +176,8 @@ PathFinderMain::PathFinderMain(FXApp* a):
   bookmarkeddirs("Bookmarked Directories"){
 
   // Make some icons
-  bigp=new FXBMPIcon(getApp(),bigpenguin,0,IMAGE_ALPHAGUESS);
-  minip=new FXBMPIcon(getApp(),minipenguin,0,IMAGE_ALPHAGUESS);
+  foxbigicon=new FXGIFIcon(getApp(),foxbig);
+  foxminiicon=new FXGIFIcon(getApp(),foxmini);
   cuticon=new FXBMPIcon(getApp(),cut,0,IMAGE_ALPHAGUESS);
   copyicon=new FXGIFIcon(getApp(),copyit);
   moveicon=new FXGIFIcon(getApp(),moveit);
@@ -206,8 +206,8 @@ PathFinderMain::PathFinderMain(FXApp* a):
   quiticon=new FXGIFIcon(getApp(),quit_gif);
 
   // Set application icons for Window Manager
-  setIcon(bigp);
-  setMiniIcon(minip);
+  setIcon(foxbigicon);
+  setMiniIcon(foxminiicon);
 
   // Make main window; set myself as the target
   setTarget(this);
@@ -241,10 +241,11 @@ PathFinderMain::PathFinderMain(FXApp* a):
   statusline->setSelector(ID_STATUSLINE);
 
   // Subtle plug for LINUX
-  new FXButton(statusbar,"\tHello, I'm Tux...\nThe symbol for the Linux Operating System.\nAnd all it stands for.\tLinux:- The Only Operating System.",minip,this,ID_ABOUT,LAYOUT_TOP|LAYOUT_RIGHT);
+  new FXButton(statusbar,"\tAbout PathFinder",foxminiicon,this,ID_ABOUT,LAYOUT_TOP|LAYOUT_RIGHT);
 
   // Pattern
-  pattern=new FXComboBox(statusbar,25,4,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_RIGHT|LAYOUT_FIX_WIDTH|FRAME_SUNKEN|FRAME_THICK, 0,0,200,0, 0,0,1,1);
+  pattern=new FXComboBox(statusbar,25,this,ID_FILEFILTER,COMBOBOX_STATIC|LAYOUT_RIGHT|LAYOUT_FIX_WIDTH|FRAME_SUNKEN|FRAME_THICK, 0,0,200,0, 0,0,1,1);
+  pattern->setNumVisible(4);
 
   // Caption before pattern
   new FXLabel(statusbar,"Pattern:",NULL,LAYOUT_RIGHT|LAYOUT_CENTER_Y);
@@ -266,7 +267,7 @@ PathFinderMain::PathFinderMain(FXApp* a):
   new FXButton(header1,"",closeicon,group1,FXWindow::ID_HIDE,BUTTON_TOOLBAR|FRAME_RAISED,0,0,0,0, 0,0,0,0);
 
   // Folder List
-  dirlist=new FXDirList(group1,0,this,ID_DIRECTORYLIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_RIGHT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC);
+  dirlist=new FXDirList(group1,this,ID_DIRECTORYLIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_TOP|LAYOUT_RIGHT|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC);
   dirlist->setAssociations(associations);
 
   // Header above files
@@ -305,7 +306,7 @@ PathFinderMain::PathFinderMain(FXApp* a):
   new FXMenuCommand(filemenu,"&New Directory...",NULL,this,ID_NEW);
   new FXMenuCommand(filemenu,"Delete\tDel\tDelete the selection.",deleteicon,this,ID_DELETE);
   new FXMenuSeparator(filemenu);
-  new FXMenuCommand(filemenu,"New &PathFinder...\tCtrl-P\tStart another PathFinder.",minip,this,ID_NEW_PATHFINDER);
+  new FXMenuCommand(filemenu,"New &PathFinder...\tCtrl-P\tStart another PathFinder.",foxminiicon,this,ID_NEW_PATHFINDER);
   new FXMenuCommand(filemenu,"&Quit\tCtl-Q\tQuit PathFinder",quiticon,this,ID_CLOSE);
 
   // Edit Menu Pane
@@ -411,7 +412,8 @@ PathFinderMain::PathFinderMain(FXApp* a):
   new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,2,0);
 
   // Directory box
-  dirbox=new FXDirBox(toolbar,5,this,ID_DIRBOX,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,180,0, 0,0, 1,1);
+  dirbox=new FXDirBox(toolbar,this,ID_DIRBOX,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FIX_WIDTH|LAYOUT_CENTER_Y,0,0,180,0, 0,0, 1,1);
+  dirbox->setNumVisible(5);
 
   // Spacer
   new FXFrame(toolbar,LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FIX_WIDTH,0,0,2,0);
@@ -490,8 +492,9 @@ PathFinderMain::PathFinderMain(FXApp* a):
   // Recent directories
   visiting=0;
 
-  // Image previewing
+  // Image previewing and blending
   preview=TRUE;
+  blending=FALSE;
 
   // Bookmarked directories
   bookmarkeddirs.setTarget(this);
@@ -520,8 +523,8 @@ PathFinderMain::~PathFinderMain(){
   delete prefmenu;
   delete helpmenu;
   delete bookmarkmenu;
-  delete bigp;
-  delete minip;
+  delete foxbigicon;
+  delete foxminiicon;
   delete cuticon;
   delete copyicon;
   delete moveicon;
@@ -757,7 +760,7 @@ long PathFinderMain::onFileListPopup(FXObject*,FXSelector,void* ptr){
 
 // About
 long PathFinderMain::onCmdAbout(FXObject*,FXSelector,void*){
-  FXMessageBox about(this,"About PathFinder","PathFinder File Browser V1.0\n\nUsing the FOX C++ GUI Library (http://www.fox-tookit.org)\n\nCopyright (C) 1998,2003 Jeroen van der Zijp (jeroen@fox-toolkit.org)",bigp,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
+  FXMessageBox about(this,"About PathFinder","PathFinder File Browser V1.0\n\nUsing the FOX C++ GUI Library (http://www.fox-tookit.org)\n\nCopyright (C) 1998,2003 Jeroen van der Zijp (jeroen@fox-toolkit.org)",foxbigicon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
   about.execute();
   return 1;
   }
@@ -1217,6 +1220,7 @@ void PathFinderMain::saveSettings(){
 
   // Preview
   getApp()->reg().writeIntEntry("PathFinder Settings","preview",preview);
+  getApp()->reg().writeIntEntry("PathFinder Settings","blending",blending);
 
   // Toolbar, location bar, status bar shown
   getApp()->reg().writeIntEntry("PathFinder Settings","toolbar",toolbar->shown());
@@ -1312,6 +1316,7 @@ void PathFinderMain::loadSettings(){
 
   // Preview
   preview=getApp()->reg().readIntEntry("PathFinder Settings","preview",TRUE);
+  blending=getApp()->reg().readIntEntry("PathFinder Settings","blending",FALSE);
 
   // Toolbar, location bar, status bar shown
   tbshown=getApp()->reg().readIntEntry("PathFinder Settings","toolbar",1);
@@ -1393,21 +1398,11 @@ FXString PathFinderMain::getPatterns() const {
   }
 
 
-// Strip pattern from text if present
-static FXString patternFromText(const FXString& pattern){
-  FXint beg,end;
-  end=pattern.rfind(')');
-  beg=pattern.rfind('(',end-1);
-  if(0<=beg && beg<end) return pattern.mid(beg+1,end-beg-1);
-  return pattern;
-  }
-
-
 // Set current pattern
 void PathFinderMain::setCurrentPattern(FXint n){
   n=FXCLAMP(0,n,pattern->getNumItems()-1);
   pattern->setCurrentItem(n);
-  dirlist->setPattern(patternFromText(pattern->getItemText(n)));
+  dirlist->setPattern(FXFileSelector::patternFromText(pattern->getItemText(n)));
   }
 
 
@@ -1427,7 +1422,7 @@ void PathFinderMain::create(){
 
 // Change the pattern
 long PathFinderMain::onCmdFilter(FXObject*,FXSelector,void* ptr){
-  filelist->setPattern(patternFromText((FXchar*)ptr));
+  filelist->setPattern(FXFileSelector::patternFromText((FXchar*)ptr));
   return 1;
   }
 
@@ -1507,12 +1502,14 @@ long PathFinderMain::onCmdPreferences(FXObject*,FXSelector,void*){
   preferences.setEditor(editor);
   preferences.setTerminal(terminal);
   preferences.setPreview(preview);
+  preferences.setBlend(blending);
   preferences.setIconPath(associations->getIconPath());
   if(preferences.execute()){
     setPatterns(preferences.getPatterns());
     terminal=preferences.getTerminal();
     editor=preferences.getEditor();
     preview=preferences.getPreview();
+    blending=preferences.getBlend();
     associations->setIconPath(preferences.getIconPath());
     }
   return 1;
@@ -1729,7 +1726,7 @@ FXbool PathFinderMain::loadImage(const FXString& filename){
   else if(comparecase(ext,"pcx")==0){
     img=new FXPCXImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
-  else if(comparecase(ext,"ico")==0){
+  else if(comparecase(ext,"ico")==0 || comparecase(ext,"cur")==0){
     img=new FXICOImage(getApp(),NULL,IMAGE_KEEP|IMAGE_SHMI|IMAGE_SHMP);
     }
   else if(comparecase(ext,"tga")==0){
@@ -1766,15 +1763,28 @@ FXbool PathFinderMain::loadImage(const FXString& filename){
   // Perhaps failed
   if(img){
     FXFileStream stream;
+
+    // Load image
     if(stream.open(filename,FXStreamLoad)){
       getApp()->beginWaitCursor();
       img->loadPixels(stream);
       stream.close();
+
+      // Blend over background
+      if(blending){
+        img->blend(imagepreview->getBackColor());
+        }
+
+      // Create image
       img->create();
+
+      // Set new image, deleting old
       old=imagepreview->getImage();
       imagepreview->setImage(img);
       delete old;
       getApp()->endWaitCursor();
+
+      // Switch to preview
       switcher->setCurrent(1);
       return TRUE;
       }
