@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: PathFinder.h,v 1.34 2003/09/10 03:54:37 fox Exp $                        *
+* $Id: PathFinder.h,v 1.36 2003/12/03 06:55:24 fox Exp $                        *
 ********************************************************************************/
 #ifndef PATHFINDER_H
 #define PATHFINDER_H
@@ -61,8 +61,8 @@ protected:
   FXImageView       *imagepreview;
   FXRecentFiles      bookmarkeddirs;
   FXFileDict        *associations;
-  FXIcon            *bigp;
-  FXIcon            *minip;
+  FXIcon            *foxbigicon;
+  FXIcon            *foxminiicon;
   FXIcon            *cuticon;
   FXIcon            *copyicon;
   FXIcon            *moveicon;
@@ -95,6 +95,7 @@ protected:
   FXString           program;
   FXint              visiting;
   FXbool             preview;
+  FXbool             blending;
 protected:
   PathFinderMain(){}
   void visitDirectory(const FXString& dir);
