@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: ShutterBug.cpp,v 1.18 2003/09/10 03:54:37 fox Exp $                      *
+* $Id: ShutterBug.cpp,v 1.26 2004/04/28 16:29:07 fox Exp $                      *
 ********************************************************************************/
 #include "fx.h"
 #include "fxkeys.h"
@@ -47,11 +47,12 @@
   - In fixed size mode you can just drag the snap rectangle around;
     it stays the same size.
   - Now remembers last selected filename and file type.
+  - Add feature to cut shot to clipboard.
 */
 
 #define FUDGE         10        // Corner fudge for diagonal dragging
-#define MINSIZE       8 // Minimum snap size
-#define VERSION_MAJOR 1
+#define MINSIZE       8         // Minimum snap size
+#define VERSION_MAJOR 2
 #define VERSION_MINOR 0
 #define VERSION_PATCH 0
 
@@ -69,22 +70,39 @@ FXDEFMAP(ShutterBug) ShutterBugMap[]={
   FXMAPFUNC(SEL_RIGHTBUTTONRELEASE,0,ShutterBug::onBtnRelease),
   FXMAPFUNC(SEL_KEYPRESS,0,ShutterBug::onKeyPress),
   FXMAPFUNC(SEL_KEYRELEASE,0,ShutterBug::onKeyRelease),
+  FXMAPFUNC(SEL_CLIPBOARD_LOST,0,ShutterBug::onClipboardLost),
+  FXMAPFUNC(SEL_CLIPBOARD_REQUEST,0,ShutterBug::onClipboardRequest),
+  FXMAPFUNC(SEL_TIMEOUT,ShutterBug::ID_SNAPSHOT,ShutterBug::onCmdSnap),
   FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_SNAPSHOT,ShutterBug::onCmdSnap),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_SNAPSHOT_DELAYED,ShutterBug::onCmdSnapDelayed),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_SNAPSHOT_CLIPBOARD,ShutterBug::onCmdSnapClipboard),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_DELAY,ShutterBug::onCmdDelay),
   FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_ABOUT,ShutterBug::onCmdAbout),
   FXMAPFUNC(SEL_UPDATE,ShutterBug::ID_TOGGLE_LASSO,ShutterBug::onUpdLasso),
   FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_TOGGLE_LASSO,ShutterBug::onCmdLasso),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_QUIT,ShutterBug::onCmdQuit),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_COLOR,ShutterBug::onCmdLineColor),
+  FXMAPFUNC(SEL_UPDATE,ShutterBug::ID_INSIDE,ShutterBug::onUpdLineInside),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_INSIDE,ShutterBug::onCmdLineInside),
+  FXMAPFUNC(SEL_UPDATE,ShutterBug::ID_QUANTIZE,ShutterBug::onUpdQuantize),
+  FXMAPFUNC(SEL_COMMAND,ShutterBug::ID_QUANTIZE,ShutterBug::onCmdQuantize),
   FXMAPFUNCS(SEL_LEFTBUTTONPRESS,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onPressSnapper),
   FXMAPFUNCS(SEL_LEFTBUTTONRELEASE,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onReleaseSnapper),
+  FXMAPFUNCS(SEL_MIDDLEBUTTONPRESS,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onPressSnapper),
+  FXMAPFUNCS(SEL_MIDDLEBUTTONRELEASE,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onReleaseSnapper),
+  FXMAPFUNCS(SEL_RIGHTBUTTONPRESS,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onPressSnapper),
+  FXMAPFUNCS(SEL_RIGHTBUTTONRELEASE,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onReleaseSnapper),
   FXMAPFUNCS(SEL_MOTION,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onMovedSnapper),
   FXMAPFUNCS(SEL_ENTER,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onEnterSnapper),
   FXMAPFUNCS(SEL_LEAVE,ShutterBug::ID_SNAPPER_0,ShutterBug::ID_SNAPPER_3,ShutterBug::onLeaveSnapper),
-  FXMAPFUNCS(SEL_UPDATE,ShutterBug::ID_SIZE_CUSTOM,ShutterBug::ID_SIZE_512X512,ShutterBug::onUpdSize),
-  FXMAPFUNCS(SEL_COMMAND,ShutterBug::ID_SIZE_CUSTOM,ShutterBug::ID_SIZE_512X512,ShutterBug::onCmdSize),
+  FXMAPFUNCS(SEL_UPDATE,ShutterBug::ID_SIZE_SCREEN,ShutterBug::ID_SIZE_512X512,ShutterBug::onUpdSize),
+  FXMAPFUNCS(SEL_COMMAND,ShutterBug::ID_SIZE_SCREEN,ShutterBug::ID_SIZE_512X512,ShutterBug::onCmdSize),
+  FXMAPFUNCS(SEL_COMMAND,ShutterBug::ID_WEIGHT_0,ShutterBug::ID_WEIGHT_6,ShutterBug::onCmdLineWeight),
   };
 
 
 // Implementation
-FXIMPLEMENT(ShutterBug,FXMainWindow,ShutterBugMap,ARRAYNUMBER(ShutterBugMap))
+FXIMPLEMENT(ShutterBug,FXShell,ShutterBugMap,ARRAYNUMBER(ShutterBugMap))
 
 // Pattern wildcards
 const FXchar patterns[]=
@@ -131,10 +149,29 @@ enum {
   };
 
 
+// Drag type names
+const FXchar ShutterBug::bmpTypeName[]="image/x-bmp";
+const FXchar ShutterBug::gifTypeName[]="image/gif";
+const FXchar ShutterBug::jpgTypeName[]="image/jpeg";
+const FXchar ShutterBug::pngTypeName[]="image/png";     // x-png?
+const FXchar ShutterBug::tifTypeName[]="image/tiff";
+const FXchar ShutterBug::xpmTypeName[]="image/xpm";
+const FXchar ShutterBug::ppmTypeName[]="image/x-portable-pixmap";
+
+// Drag types
+FXDragType ShutterBug::bmpType=0;
+FXDragType ShutterBug::gifType=0;
+FXDragType ShutterBug::jpgType=0;
+FXDragType ShutterBug::pngType=0;
+FXDragType ShutterBug::tifType=0;
+FXDragType ShutterBug::xpmType=0;
+FXDragType ShutterBug::ppmType=0;
+
+
 /*******************************************************************************/
 
 // ShutterBug main window
-ShutterBug::ShutterBug(FXApp* a):FXMainWindow(a,"ShutterBug",NULL,NULL,DECOR_NONE, 0,0,0,0, 0,0){
+ShutterBug::ShutterBug(FXApp* a):FXShell(a,0,0,0,0,0){
   flags|=FLAG_ENABLED;
   rectangle.x=100;
   rectangle.y=100;
@@ -142,30 +179,62 @@ ShutterBug::ShutterBug(FXApp* a):FXMainWindow(a,"ShutterBug",NULL,NULL,DECOR_NON
   rectangle.h=100;
   filename="image.gif";
   fileformat=TYPE_GIF;
+  clipbuffer=NULL;
+  clipwidth=0;
+  clipheight=0;
   snapper[0]=new Snapper(getApp(),this,ID_SNAPPER_0);
   snapper[1]=new Snapper(getApp(),this,ID_SNAPPER_1);
   snapper[2]=new Snapper(getApp(),this,ID_SNAPPER_2);
   snapper[3]=new Snapper(getApp(),this,ID_SNAPPER_3);
   bigicon=new FXGIFIcon(getApp(),shutterbug);
   smallicon=new FXGIFIcon(getApp(),tinyshutterbug);
-  setIcon(bigicon);
-  setMiniIcon(smallicon);
+  weighticons[0]=new FXGIFIcon(getApp(),line_1);
+  weighticons[1]=new FXGIFIcon(getApp(),line_2);
+  weighticons[2]=new FXGIFIcon(getApp(),line_3);
+  weighticons[3]=new FXGIFIcon(getApp(),line_4);
+  weighticons[4]=new FXGIFIcon(getApp(),line_5);
+  weighticons[5]=new FXGIFIcon(getApp(),line_6);
   weight=3;
   size=0;
+  delay=3000;
+  inside=FALSE;
+  quantize=TRUE;        // Fast method
   spotx=0;
   spoty=0;
   mode=MODE_NONE;
   }
 
 
+// Snapper does override-redirect
+FXbool ShutterBug::doesOverrideRedirect() const { return TRUE; }
+
 // Create and show window
 void ShutterBug::create(){
   readRegistry();
-  FXMainWindow::create();
+  FXShell::create();
+  if(!bmpType) bmpType=getApp()->registerDragType(bmpTypeName);
+  if(!gifType) gifType=getApp()->registerDragType(gifTypeName);
+  if(!jpgType) jpgType=getApp()->registerDragType(jpgTypeName);
+  if(!pngType) pngType=getApp()->registerDragType(pngTypeName);
+  if(!tifType) tifType=getApp()->registerDragType(tifTypeName);
+  if(!xpmType) xpmType=getApp()->registerDragType(xpmTypeName);
+  if(!ppmType) ppmType=getApp()->registerDragType(ppmTypeName);
   snapper[0]->create();
   snapper[1]->create();
   snapper[2]->create();
   snapper[3]->create();
+  bigicon->create();
+  smallicon->create();
+  weighticons[0]->create();
+  weighticons[1]->create();
+  weighticons[2]->create();
+  weighticons[3]->create();
+  weighticons[4]->create();
+  weighticons[5]->create();
+  snapper[0]->setBackColor(color);
+  snapper[1]->setBackColor(color);
+  snapper[2]->setBackColor(color);
+  snapper[3]->setBackColor(color);
   moveSnapRectangle(rectangle);
   showSnapRectangle();
   show();
@@ -174,10 +243,22 @@ void ShutterBug::create(){
 
 // Move snap rectangle
 void ShutterBug::moveSnapRectangle(const FXRectangle& r){
-  snapper[0]->position(r.x,r.y,weight,r.h);
-  snapper[1]->position(r.x+r.w-weight,r.y,weight,r.h);
-  snapper[2]->position(r.x,r.y,r.w,weight);
-  snapper[3]->position(r.x,r.y+r.h-weight,r.w,weight);
+  if(inside){
+    snapper[0]->position(r.x,r.y,weight,r.h);
+    snapper[1]->position(r.x+r.w-weight,r.y,weight,r.h);
+    snapper[2]->position(r.x,r.y,r.w,weight);
+    snapper[3]->position(r.x,r.y+r.h-weight,r.w,weight);
+    }
+  else{
+    snapper[0]->position(r.x-weight,r.y-weight,weight,r.h+weight+weight);
+    snapper[1]->position(r.x+r.w,r.y-weight,weight,r.h+weight+weight);
+    snapper[2]->position(r.x-weight,r.y-weight,r.w+weight+weight,weight);
+    snapper[3]->position(r.x-weight,r.y+r.h,r.w+weight+weight,weight);
+    }
+  snapper[0]->raise();
+  snapper[1]->raise();
+  snapper[2]->raise();
+  snapper[3]->raise();
   }
 
 
@@ -202,7 +283,6 @@ void ShutterBug::hideSnapRectangle(){
   snapper[2]->hide();
   snapper[3]->hide();
   getApp()->flush(TRUE);
-  fxsleep(10000);
   }
 
 
@@ -231,12 +311,28 @@ void ShutterBug::readRegistry(){
   fileformat=getApp()->reg().readIntEntry("SETTINGS","fileformat",TYPE_GIF);
   setX(getApp()->reg().readIntEntry("SETTINGS","x",50));
   setY(getApp()->reg().readIntEntry("SETTINGS","y",50));
+  weight=getApp()->reg().readIntEntry("SETTINGS","weight",3);
   rectangle.x=getApp()->reg().readIntEntry("SETTINGS","snapx",50);
   rectangle.y=getApp()->reg().readIntEntry("SETTINGS","snapy",50);
   rectangle.w=getApp()->reg().readIntEntry("SETTINGS","snapw",50);
   rectangle.h=getApp()->reg().readIntEntry("SETTINGS","snaph",50);
+  delay=getApp()->reg().readUnsignedEntry("SETTINGS","delay",3000);
+  inside=getApp()->reg().readIntEntry("SETTINGS","inside",FALSE);
+  color=getApp()->reg().readColorEntry("SETTINGS","color",FXRGB(255,128,128));
   size=getApp()->reg().readIntEntry("SETTINGS","size",0);
-  if(size){ rectangle.w=size; rectangle.h=size; }
+  quantize=getApp()->reg().readIntEntry("SETTINGS","quantize",TRUE);
+  if(size){
+    if(size<0){
+      rectangle.x=0;
+      rectangle.y=0;
+      rectangle.w=getRoot()->getWidth();
+      rectangle.h=getRoot()->getHeight();
+      }
+    else{
+      rectangle.w=size;
+      rectangle.h=size;
+      }
+    }
   }
 
 
@@ -246,11 +342,16 @@ void ShutterBug::writeRegistry(){
   getApp()->reg().writeIntEntry("SETTINGS","fileformat",fileformat);
   getApp()->reg().writeIntEntry("SETTINGS","x",getX());
   getApp()->reg().writeIntEntry("SETTINGS","y",getY());
+  getApp()->reg().writeIntEntry("SETTINGS","weight",weight);
   getApp()->reg().writeIntEntry("SETTINGS","snapx",rectangle.x);
   getApp()->reg().writeIntEntry("SETTINGS","snapy",rectangle.y);
   getApp()->reg().writeIntEntry("SETTINGS","snapw",rectangle.w);
   getApp()->reg().writeIntEntry("SETTINGS","snaph",rectangle.h);
+  getApp()->reg().writeUnsignedEntry("SETTINGS","delay",delay);
+  getApp()->reg().writeIntEntry("SETTINGS","inside",inside);
+  getApp()->reg().writeColorEntry("SETTINGS","color",color);
   getApp()->reg().writeIntEntry("SETTINGS","size",size);
+  getApp()->reg().writeIntEntry("SETTINGS","quantize",quantize);
   }
 
 
@@ -308,7 +409,7 @@ long ShutterBug::onPaint(FXObject*,FXSelector,void* ptr){
   dc.fillRectangle(0,0,width,height);
   dc.setForeground(FXRGB(0,0,0));
   dc.drawRectangle(0,0,width-1,height-1);
-  dc.drawIcon(icon,2,2);
+  dc.drawIcon(bigicon,2,2);
   return 1;
   }
 
@@ -344,8 +445,10 @@ long ShutterBug::onBtnRelease(FXObject*,FXSelector,void* ptr){
   FXMenuPane filemenu(this);
   new FXMenuCaption(&filemenu,"ShutterBug",smallicon);
   new FXMenuSeparator(&filemenu);
-  new FXMenuCommand(&filemenu,"Snap...",NULL,this,ShutterBug::ID_SNAPSHOT);
-  new FXMenuCheck(&filemenu,"Show lasso",this,ShutterBug::ID_TOGGLE_LASSO);
+  new FXMenuCommand(&filemenu,"Snap...",NULL,this,ID_SNAPSHOT);
+  new FXMenuCommand(&filemenu,"Snap delayed...",NULL,this,ID_SNAPSHOT_DELAYED);
+  new FXMenuCommand(&filemenu,"Snap to clipboard...",NULL,this,ID_SNAPSHOT_CLIPBOARD);
+  new FXMenuCheck(&filemenu,"Show lasso",this,ID_TOGGLE_LASSO);
   FXMenuPane sizemenu(this);
   new FXMenuCascade(&filemenu,"Size",NULL,&sizemenu);
   new FXMenuRadio(&sizemenu,"8x8",this,ID_SIZE_8X8);
@@ -355,9 +458,22 @@ long ShutterBug::onBtnRelease(FXObject*,FXSelector,void* ptr){
   new FXMenuRadio(&sizemenu,"128x128",this,ID_SIZE_128X128);
   new FXMenuRadio(&sizemenu,"256X256",this,ID_SIZE_256X256);
   new FXMenuRadio(&sizemenu,"512X512",this,ID_SIZE_512X512);
+  new FXMenuRadio(&sizemenu,"Screen",this,ID_SIZE_SCREEN);
   new FXMenuRadio(&sizemenu,"Custom",this,ID_SIZE_CUSTOM);
-  new FXMenuCommand(&filemenu,"About...",NULL,this,ShutterBug::ID_ABOUT);
-  new FXMenuCommand(&filemenu,"Quit",NULL,this,ShutterBug::ID_CLOSE);
+  FXMenuPane weightmenu(this);
+  new FXMenuCascade(&filemenu,"Weight",NULL,&weightmenu);
+  new FXMenuCommand(&weightmenu,FXString::null,weighticons[0],this,ID_WEIGHT_1);
+  new FXMenuCommand(&weightmenu,FXString::null,weighticons[1],this,ID_WEIGHT_2);
+  new FXMenuCommand(&weightmenu,FXString::null,weighticons[2],this,ID_WEIGHT_3);
+  new FXMenuCommand(&weightmenu,FXString::null,weighticons[3],this,ID_WEIGHT_4);
+  new FXMenuCommand(&weightmenu,FXString::null,weighticons[4],this,ID_WEIGHT_5);
+  new FXMenuCommand(&weightmenu,FXString::null,weighticons[5],this,ID_WEIGHT_6);
+  new FXMenuCheck(&filemenu,"Lines inside",this,ID_INSIDE);
+  new FXMenuCommand(&filemenu,"Color...",NULL,this,ID_COLOR);
+  new FXMenuCommand(&filemenu,"Delay...",NULL,this,ID_DELAY);
+  new FXMenuCheck(&filemenu,"Fast quantization...",this,ID_QUANTIZE);
+  new FXMenuCommand(&filemenu,"About...",NULL,this,ID_ABOUT);
+  new FXMenuCommand(&filemenu,"Quit",NULL,this,ID_QUIT);
   filemenu.create();
   filemenu.popup(NULL,event->root_x,event->root_y);
   getApp()->runModalWhileShown(&filemenu);
@@ -366,9 +482,11 @@ long ShutterBug::onBtnRelease(FXObject*,FXSelector,void* ptr){
 
 
 // Keyboard press
-long ShutterBug::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
+long ShutterBug::onKeyPress(FXObject*,FXSelector,void* ptr){
   if(((FXEvent*)ptr)->code==KEY_q || ((FXEvent*)ptr)->code==KEY_Q){
-    close(TRUE);
+    FXTRACE((1,"quit\n"));
+    writeRegistry();
+    getApp()->exit();
     }
   return 1;
   }
@@ -380,10 +498,12 @@ long ShutterBug::onKeyRelease(FXObject*,FXSelector,void*){
   }
 
 
-// Close window and save registry
-FXbool ShutterBug::close(FXbool notify){
+// Quit
+long ShutterBug::onCmdQuit(FXObject*,FXSelector,void*){
+  FXTRACE((1,"quit\n"));
   writeRegistry();
-  return FXMainWindow::close(notify);
+  getApp()->exit();
+  return 1;
   }
 
 
@@ -400,7 +520,7 @@ void ShutterBug::readPixels(FXImage* image,const FXRectangle& r){
 FXbool ShutterBug::snapRectangle(FXColor*& data,const FXRectangle& r){
   data=NULL;
   if(1<r.w && 1<r.h){
-    FXTRACE((1,"size=%d %d\n",r.w,r.h));
+    FXTRACE((1,"size=%dx%d\n",r.w,r.h));
 
     // Allocate memory for pixels
     if(FXCALLOC(&data,FXColor,r.w*r.h)){
@@ -408,6 +528,12 @@ FXbool ShutterBug::snapRectangle(FXColor*& data,const FXRectangle& r){
       // Hide snap rectangle
       hideSnapRectangle();
 
+      // Hide myself
+      hide();
+
+      // Give other apps a chance to repaint
+      fxsleep(10000);
+
       // Make image
       FXImage image(getApp(),data,IMAGE_KEEP,r.w,r.h);
 
@@ -423,6 +549,9 @@ FXbool ShutterBug::snapRectangle(FXColor*& data,const FXRectangle& r){
       // Show snap rectangle
       showSnapRectangle();
 
+      // Restore myself
+      show();
+
       return TRUE;
       }
     }
@@ -452,9 +581,9 @@ long ShutterBug::onCmdSnap(FXObject*,FXSelector,void*){
         FXFileStream outfile;
         if(outfile.open(filename,FXStreamSave)){
           switch(fileformat){
-            case TYPE_GIF: ok=fxsaveGIF(outfile,data,rectangle.w,rectangle.h); break;
+            case TYPE_GIF: ok=fxsaveGIF(outfile,data,rectangle.w,rectangle.h,quantize); break;
             case TYPE_BMP: ok=fxsaveBMP(outfile,data,rectangle.w,rectangle.h); break;
-            case TYPE_XPM: ok=fxsaveXPM(outfile,data,rectangle.w,rectangle.h); break;
+            case TYPE_XPM: ok=fxsaveXPM(outfile,data,rectangle.w,rectangle.h,quantize); break;
             case TYPE_PCX: ok=fxsavePCX(outfile,data,rectangle.w,rectangle.h); break;
             case TYPE_RGB: ok=fxsaveRGB(outfile,data,rectangle.w,rectangle.h); break;
             case TYPE_XBM: ok=fxsaveXBM(outfile,data,rectangle.w,rectangle.h); break;
@@ -481,11 +610,147 @@ long ShutterBug::onCmdSnap(FXObject*,FXSelector,void*){
   }
 
 
+// We lost the selection somehow
+long ShutterBug::onClipboardLost(FXObject* sender,FXSelector sel,void* ptr){
+  FXShell::onClipboardLost(sender,sel,ptr);
+  FXTRACE((1,"%s::onClipboardLost \n",getClassName()));
+  FXFREE(&clipbuffer);
+  clipwidth=0;
+  clipheight=0;
+  return 1;
+  }
+
+
+// Somebody wants our selection
+long ShutterBug::onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr){
+  FXEvent *event=(FXEvent*)ptr;
+  unsigned long size;
+  FXuchar *data;
+
+  FXTRACE((1,"%s::onClipboardRequest \n",getClassName()));
+
+  // Try handling it in base class first
+  if(FXShell::onClipboardRequest(sender,sel,ptr)) return 1;
+
+  // One of the supported image types?
+  if(event->target==bmpType || event->target==gifType || event->target==jpgType || event->target==pngType || event->target==xpmType || event->target==ppmType || event->target==imageType){
+    if(clipbuffer){
+      FXMemoryStream ms;
+
+
+      // Open memory stream
+      ms.open(FXStreamSave,NULL);
+
+      // Render image to memory stream
+      if(event->target==bmpType){
+        FXTRACE((1,"Request for bmpType\n"));
+        fxsaveBMP(ms,clipbuffer,clipwidth,clipheight);
+        }
+      else if(event->target==gifType){
+        FXTRACE((1,"Request for gifType\n"));
+        fxsaveGIF(ms,clipbuffer,clipwidth,clipheight);
+        }
+      else if(event->target==xpmType){
+        FXTRACE((1,"Request for xpmType\n"));
+        fxsaveXPM(ms,clipbuffer,clipwidth,clipheight);
+        }
+      else if(event->target==ppmType){
+        FXTRACE((1,"Request for ppmType\n"));
+        fxsavePPM(ms,clipbuffer,clipwidth,clipheight);
+        }
+#ifdef HAVE_JPEG_H
+      else if(event->target==jpgType){
+        FXTRACE((1,"Request for jpgType\n"));
+        fxsaveJPG(ms,clipbuffer,clipwidth,clipheight,75);
+        }
+#endif
+#ifdef HAVE_PNG_H
+      else if(event->target==pngType){
+        FXTRACE((1,"Request for pngType\n"));
+        fxsavePNG(ms,clipbuffer,clipwidth,clipheight);
+        }
+#endif
+#ifdef HAVE_TIFF_H
+      else if(event->target==tifType){
+        FXTRACE((1,"Request for tifType\n"));
+        fxsaveTIF(ms,clipbuffer,clipwidth,clipheight,0);
+        }
+#endif
+#ifdef WIN32
+  //  else if(event->target==imageType){
+  //    FXTRACE((1,"Request for imageType\n"));
+  //    fxsaveBMP(ms,chart->getData(),chart->getWidth(),chart->getHeight());
+  //    }
+#endif
+
+      // Grab buffered image
+      ms.takeBuffer(data,size);
+
+      // Close memory stream
+      ms.close();
+
+      // Set DND data
+      setDNDData(FROM_CLIPBOARD,event->target,data,size);
+      return 1;
+      }
+    }
+  return 0;
+  }
+
+
+// Snapshot to clipboard
+long ShutterBug::onCmdSnapClipboard(FXObject*,FXSelector,void*){
+  FXDragType types[7];
+
+  // Free old, if any
+  FXFREE(&clipbuffer);
+  clipwidth=0;
+  clipheight=0;
+
+  types[0]=bmpType;
+  types[1]=gifType;
+  types[2]=jpgType;
+  types[3]=pngType;
+  types[4]=tifType;
+  types[5]=xpmType;
+  types[6]=ppmType;
+
+  // Grab clipboard
+  if(acquireClipboard(types,7)){
+
+    // Grab pixels
+    if(snapRectangle(clipbuffer,rectangle)){
+      clipwidth=rectangle.w;
+      clipheight=rectangle.h;
+      }
+    }
+
+  return 1;
+  }
+
+
+// Snapshot after small delay
+long ShutterBug::onCmdSnapDelayed(FXObject*,FXSelector,void*){
+  getApp()->addTimeout(this,ID_SNAPSHOT,delay);
+  return 1;
+  }
+
+
+// Set snapshot delay
+long ShutterBug::onCmdDelay(FXObject*,FXSelector,void*){
+  FXint time=(FXint)delay;
+  if(FXInputDialog::getInteger(time,this,"Snap Shot Delay","Snapshot delay in milliseconds:",NULL,100,10000)){
+    delay=(FXuint)time;
+    }
+  return 1;
+  }
+
+
 // Pressed on snapper
 long ShutterBug::onPressSnapper(FXObject*,FXSelector sel,void* ptr){
   register FXint which=FXSELID(sel)-ID_SNAPPER_0;
   register FXEvent *event=(FXEvent*)ptr;
-  if((event->state&CONTROLMASK) || (0<size)){
+  if((event->state&CONTROLMASK) || (event->type!=SEL_LEFTBUTTONPRESS) || size){
     mode=MODE_WHOLERECT;
     spotx=event->root_x-rectangle.x;
     spoty=event->root_y-rectangle.y;
@@ -560,7 +825,7 @@ long ShutterBug::onMovedSnapper(FXObject*,FXSelector sel,void* ptr){
     m=mode;
     }
   else{
-    if((event->state&CONTROLMASK) || (0<size))
+    if((event->state&CONTROLMASK) || size)
       m=MODE_WHOLERECT;
     else
       m=where(event->root_x,event->root_y);
@@ -620,8 +885,21 @@ long ShutterBug::onUpdLasso(FXObject* sender,FXSelector,void*){
 long ShutterBug::onCmdSize(FXObject*,FXSelector sel,void*){
   size=FXSELID(sel)-ID_SIZE_CUSTOM;
   if(size){
-    rectangle.w=size;
-    rectangle.h=size;
+    if(size<0){
+      rectangle.x=0;
+      rectangle.y=0;
+      rectangle.w=getRoot()->getDefaultWidth();
+      rectangle.h=getRoot()->getDefaultHeight();
+      }
+    else{
+      if(rectangle.x>getRoot()->getDefaultWidth()-size){ rectangle.x=getRoot()->getDefaultWidth()-size; }
+      if(rectangle.y>getRoot()->getDefaultHeight()-size){ rectangle.y=getRoot()->getDefaultHeight()-size; }
+      if(rectangle.x<0){ rectangle.x=0; }
+      if(rectangle.y<0){ rectangle.y=0; }
+      rectangle.w=size;
+      rectangle.h=size;
+      }
+    FXTRACE((1,"x=%d y=%d w=%d h=%d\n",rectangle.x,rectangle.y,rectangle.w,rectangle.h));
     moveSnapRectangle(rectangle);
     }
   return 1;
@@ -635,14 +913,75 @@ long ShutterBug::onUpdSize(FXObject* sender,FXSelector sel,void*){
   }
 
 
+// Change line weigth
+long ShutterBug::onCmdLineWeight(FXObject*,FXSelector sel,void*){
+  weight=FXSELID(sel)-ID_WEIGHT_0;
+  moveSnapRectangle(rectangle);
+  return 1;
+  }
+
+
+// Change line color
+long ShutterBug::onCmdLineColor(FXObject*,FXSelector,void*){
+  FXColorDialog colordialog(this,"Line Color");
+  colordialog.setOpaqueOnly(TRUE);
+  colordialog.setRGBA(color);
+  if(colordialog.execute()){
+    color=colordialog.getRGBA();
+    snapper[0]->setBackColor(color);
+    snapper[1]->setBackColor(color);
+    snapper[2]->setBackColor(color);
+    snapper[3]->setBackColor(color);
+    }
+  return 1;
+  }
+
+
+// Lines inside area
+long ShutterBug::onCmdLineInside(FXObject*,FXSelector sel,void* ptr){
+  inside=(FXbool)(FXuval)ptr;
+  moveSnapRectangle(rectangle);
+  return 1;
+  }
+
+
+// Update lines inside area
+long ShutterBug::onUpdLineInside(FXObject* sender,FXSelector,void*){
+  sender->handle(this,inside?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  return 1;
+  }
+
+
+// Quantization
+long ShutterBug::onCmdQuantize(FXObject*,FXSelector sel,void* ptr){
+  quantize=(FXbool)(FXuval)ptr;
+  return 1;
+  }
+
+
+// Update quantization
+long ShutterBug::onUpdQuantize(FXObject* sender,FXSelector,void*){
+  sender->handle(this,quantize?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
+  return 1;
+  }
+
+
 // Destroy main window
 ShutterBug::~ShutterBug(){
+  getApp()->removeTimeout(this,ID_SNAPSHOT);
+  FXFREE(&clipbuffer);
   delete snapper[0];
   delete snapper[1];
   delete snapper[2];
   delete snapper[3];
   delete bigicon;
   delete smallicon;
+  delete weighticons[0];
+  delete weighticons[1];
+  delete weighticons[2];
+  delete weighticons[3];
+  delete weighticons[4];
+  delete weighticons[5];
   }
 
 /*******************************************************************************/
