@@ -3,7 +3,7 @@
 *                       F o u r - W a y   S p l i t t e r                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FX4Splitter.cpp,v 1.34 2003/10/23 04:19:44 fox Exp $                     *
+* $Id: FX4Splitter.cpp,v 1.36 2004/04/05 14:49:33 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -392,11 +392,13 @@ long FX4Splitter::onFocusUp(FXObject*,FXSelector,void* ptr){
     else if(getFocus()==getBottomRight()) child=getTopRight();
     }
   else{
-    child=getFirst();
+    child=getLast();
     }
   if(child){
-    if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-    if(child->handle(this,FXSEL(SEL_FOCUS_UP,0),ptr)) return 1;
+    if(child->shown()){
+      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+      if(child->handle(this,FXSEL(SEL_FOCUS_UP,0),ptr)) return 1;
+      }
     }
   return 0;
   }
@@ -413,8 +415,10 @@ long FX4Splitter::onFocusDown(FXObject*,FXSelector,void* ptr){
     child=getFirst();
     }
   if(child){
-    if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-    if(child->handle(this,FXSEL(SEL_FOCUS_DOWN,0),ptr)) return 1;
+    if(child->shown()){
+      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+      if(child->handle(this,FXSEL(SEL_FOCUS_DOWN,0),ptr)) return 1;
+      }
     }
   return 0;
   }
@@ -428,11 +432,13 @@ long FX4Splitter::onFocusLeft(FXObject*,FXSelector,void* ptr){
     else if(getFocus()==getBottomRight()) child=getBottomLeft();
     }
   else{
-    child=getFirst();
+    child=getLast();
     }
   if(child){
-    if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-    if(child->handle(this,FXSEL(SEL_FOCUS_LEFT,0),ptr)) return 1;
+    if(child->shown()){
+      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+      if(child->handle(this,FXSEL(SEL_FOCUS_LEFT,0),ptr)) return 1;
+      }
     }
   return 0;
   }
@@ -449,8 +455,10 @@ long FX4Splitter::onFocusRight(FXObject*,FXSelector,void* ptr){
     child=getFirst();
     }
   if(child){
-    if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-    if(child->handle(this,FXSEL(SEL_FOCUS_RIGHT,0),ptr)) return 1;
+    if(child->shown()){
+      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+      if(child->handle(this,FXSEL(SEL_FOCUS_RIGHT,0),ptr)) return 1;
+      }
     }
   return 0;
   }
