@@ -3,7 +3,7 @@
 *                     A r r o w   B u t t o n    O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXArrowButton.cpp,v 1.35 2003/10/23 17:53:17 fox Exp $                   *
+* $Id: FXArrowButton.cpp,v 1.39 2004/02/08 17:29:06 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -38,11 +38,19 @@
 #include "FXArrowButton.h"
 
 
+/*
+  Notes:
+  - Automatic mode works by simply hovering cursor over arrow button; it is
+    used for scrolling menus.
+  - Possible interactions between auto mode and manual pressing..
+*/
+
+
 // Justification
 #define JUSTIFY_MASK  (JUSTIFY_HZ_APART|JUSTIFY_VT_APART)
 
 // Arrow styles
-#define ARROW_MASK    (ARROW_UP|ARROW_DOWN|ARROW_LEFT|ARROW_RIGHT|ARROW_REPEAT|ARROW_AUTOGRAY|ARROW_AUTOHIDE|ARROW_TOOLBAR)
+#define ARROW_MASK    (ARROW_UP|ARROW_DOWN|ARROW_LEFT|ARROW_RIGHT|ARROW_AUTO|ARROW_REPEAT|ARROW_AUTOGRAY|ARROW_AUTOHIDE|ARROW_TOOLBAR)
 
 using namespace FX;
 
@@ -57,6 +65,7 @@ FXDEFMAP(FXArrowButton) FXArrowButtonMap[]={
   FXMAPFUNC(SEL_UPDATE,0,FXArrowButton::onUpdate),
   FXMAPFUNC(SEL_ENTER,0,FXArrowButton::onEnter),
   FXMAPFUNC(SEL_LEAVE,0,FXArrowButton::onLeave),
+  FXMAPFUNC(SEL_TIMEOUT,FXArrowButton::ID_AUTO,FXArrowButton::onAuto),
   FXMAPFUNC(SEL_TIMEOUT,FXArrowButton::ID_REPEAT,FXArrowButton::onRepeat),
   FXMAPFUNC(SEL_LEFTBUTTONPRESS,0,FXArrowButton::onLeftBtnPress),
   FXMAPFUNC(SEL_LEFTBUTTONRELEASE,0,FXArrowButton::onLeftBtnRelease),
@@ -153,11 +162,26 @@ long FXArrowButton::onUpdate(FXObject* sender,FXSelector sel,void* ptr){
   }
 
 
+// Press automatically
+long FXArrowButton::onAuto(FXObject*,FXSelector,void*){
+  setState(TRUE);
+  getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollSpeed());
+  flags&=~FLAG_UPDATE;
+  fired=FALSE;
+  return 1;
+  }
+
+
 // Entered button
 long FXArrowButton::onEnter(FXObject* sender,FXSelector sel,void* ptr){
   FXFrame::onEnter(sender,sel,ptr);
   if(isEnabled()){
-    if(flags&FLAG_PRESSED) setState(TRUE);
+    if(flags&FLAG_PRESSED){
+      setState(TRUE);
+      }
+    else if(options&ARROW_AUTO){
+      if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_AUTO,getApp()->getScrollDelay());
+      }
     if(options&ARROW_TOOLBAR) update();
     }
   return 1;
@@ -168,7 +192,15 @@ long FXArrowButton::onEnter(FXObject* sender,FXSelector sel,void* ptr){
 long FXArrowButton::onLeave(FXObject* sender,FXSelector sel,void* ptr){
   FXFrame::onLeave(sender,sel,ptr);
   if(isEnabled()){
-    if(flags&FLAG_PRESSED) setState(FALSE);
+    if(flags&FLAG_PRESSED){
+      setState(FALSE);
+      }
+    else if(options&ARROW_AUTO){
+      setState(FALSE);
+      if(options&ARROW_REPEAT) getApp()->removeTimeout(this,ID_AUTO);
+      flags|=FLAG_UPDATE;
+      fired=FALSE;
+      }
     if(options&ARROW_TOOLBAR) update();
     }
   return 1;
@@ -182,8 +214,9 @@ long FXArrowButton::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
   if(isEnabled() && !(flags&FLAG_PRESSED)){
     grab();
     if(target && target->handle(this,FXSEL(SEL_LEFTBUTTONPRESS,message),ptr)) return 1;
-    if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollDelay());
     setState(TRUE);
+    getApp()->removeTimeout(this,ID_AUTO);
+    if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollDelay());
     flags|=FLAG_PRESSED;
     flags&=~FLAG_UPDATE;
     fired=FALSE;
@@ -199,8 +232,8 @@ long FXArrowButton::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
   if(isEnabled() && (flags&FLAG_PRESSED)){
     ungrab();
     if(target && target->handle(this,FXSEL(SEL_LEFTBUTTONRELEASE,message),ptr)) return 1;
-    if(options&ARROW_REPEAT) getApp()->removeTimeout(this,ID_REPEAT);
     setState(FALSE);
+    getApp()->removeTimeout(this,ID_REPEAT);
     flags|=FLAG_UPDATE;
     flags&=~FLAG_PRESSED;
     fired=FALSE;
@@ -214,8 +247,8 @@ long FXArrowButton::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
 // Lost the grab for some reason
 long FXArrowButton::onUngrabbed(FXObject* sender,FXSelector sel,void* ptr){
   FXFrame::onUngrabbed(sender,sel,ptr);
-  if(options&ARROW_REPEAT) getApp()->removeTimeout(this,ID_REPEAT);
   setState(FALSE);
+  getApp()->removeTimeout(this,ID_REPEAT);
   flags&=~FLAG_PRESSED;
   flags|=FLAG_UPDATE;
   fired=FALSE;
@@ -239,8 +272,9 @@ long FXArrowButton::onKeyPress(FXObject*,FXSelector,void* ptr){
   if(isEnabled() && !(flags&FLAG_PRESSED)){
     if(target && target->handle(this,FXSEL(SEL_KEYPRESS,message),ptr)) return 1;
     if(event->code==KEY_space || event->code==KEY_KP_Space){
-      if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollDelay());
       setState(TRUE);
+      getApp()->removeTimeout(this,ID_AUTO);
+      if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollDelay());
       flags|=FLAG_PRESSED;
       flags&=~FLAG_UPDATE;
       fired=FALSE;
@@ -258,8 +292,8 @@ long FXArrowButton::onKeyRelease(FXObject*,FXSelector,void* ptr){
   if(isEnabled() && (flags&FLAG_PRESSED)){
     if(target && target->handle(this,FXSEL(SEL_KEYRELEASE,message),ptr)) return 1;
     if(event->code==KEY_space || event->code==KEY_KP_Space){
-      if(options&ARROW_REPEAT) getApp()->removeTimeout(this,ID_REPEAT);
       setState(FALSE);
+      getApp()->removeTimeout(this,ID_REPEAT);
       flags|=FLAG_UPDATE;
       flags&=~FLAG_PRESSED;
       fired=FALSE;
@@ -276,8 +310,9 @@ long FXArrowButton::onHotKeyPress(FXObject*,FXSelector,void* ptr){
   flags&=~FLAG_TIP;
   handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr);
   if(isEnabled() && !(flags&FLAG_PRESSED)){
-    if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollDelay());
     setState(TRUE);
+    getApp()->removeTimeout(this,ID_AUTO);
+    if(options&ARROW_REPEAT) getApp()->addTimeout(this,ID_REPEAT,getApp()->getScrollDelay());
     flags|=FLAG_PRESSED;
     flags&=~FLAG_UPDATE;
     fired=FALSE;
@@ -290,8 +325,8 @@ long FXArrowButton::onHotKeyPress(FXObject*,FXSelector,void* ptr){
 long FXArrowButton::onHotKeyRelease(FXObject*,FXSelector,void*){
   FXbool click=(!fired && state);
   if(isEnabled() && (flags&FLAG_PRESSED)){
-    if(options&ARROW_REPEAT) getApp()->removeTimeout(this,ID_REPEAT);
     setState(FALSE);
+    getApp()->removeTimeout(this,ID_REPEAT);
     flags|=FLAG_UPDATE;
     flags&=~FLAG_PRESSED;
     fired=FALSE;
@@ -555,7 +590,8 @@ void FXArrowButton::load(FXStream& store){
 
 // Kill the timer
 FXArrowButton::~FXArrowButton(){
-  if(options&ARROW_REPEAT) getApp()->removeTimeout(this,ID_REPEAT);
+  getApp()->removeTimeout(this,ID_AUTO);
+  getApp()->removeTimeout(this,ID_REPEAT);
   }
 
 }
