@@ -3,7 +3,7 @@
 *                           B u t t o n    O b j e c t s                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXButton.cpp,v 1.52 2003/10/23 04:19:44 fox Exp $                        *
+* $Id: FXButton.cpp,v 1.54 2004/02/08 17:29:06 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -446,31 +446,35 @@ long FXButton::onPaint(FXObject*,FXSelector,void* ptr){
     iw=icon->getWidth();
     ih=icon->getHeight();
     }
+
   just_x(tx,ix,tw,iw);
   just_y(ty,iy,th,ih);
 
   // Shift a bit when pressed
   if(state && (options&(FRAME_RAISED|FRAME_SUNKEN))){ ++tx; ++ty; ++ix; ++iy; }
 
-  // Draw the icon
-  if(icon){
-    if(isEnabled())
+  // Draw enabled state
+  if(isEnabled()){
+    if(icon){
       dc.drawIcon(icon,ix,iy);
-    else
-      dc.drawIconSunken(icon,ix,iy);
-    }
-
-  // Draw the text
-  if(!label.empty()){
-    dc.setFont(font);
-    if(isEnabled()){
+      }
+    if(!label.empty()){
+      dc.setFont(font);
       dc.setForeground(textColor);
       drawLabel(dc,label,hotoff,tx,ty,tw,th);
-      if(hasFocus()){
-        dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
-        }
       }
-    else{
+    if(hasFocus()){
+      dc.drawFocusRectangle(border+1,border+1,width-2*border-2,height-2*border-2);
+      }
+    }
+
+  // Draw grayed-out state
+  else{
+    if(icon){
+      dc.drawIconSunken(icon,ix,iy);
+      }
+    if(!label.empty()){
+      dc.setFont(font);
       dc.setForeground(hiliteColor);
       drawLabel(dc,label,hotoff,tx+1,ty+1,tw,th);
       dc.setForeground(shadowColor);
