@@ -3,7 +3,7 @@
 *                        C U R   C u r s o r    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2003 by Sander Jansen.   All Rights Reserved.              *
+* Copyright (C) 2001,2004 by Sander Jansen.   All Rights Reserved.              *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCURCursor.cpp,v 1.14 2003/10/23 04:19:44 fox Exp $                     *
+* $Id: FXCURCursor.cpp,v 1.16 2004/01/14 14:21:28 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -36,15 +36,13 @@
 #include "FXApp.h"
 #include "FXCURCursor.h"
 
+
 /*
  Notes:
-
- - The inversion of the bits and mask should happen in the fxloadCUR function.
+  - Tossed old code now that FXCursor has an RGBA representation.
 */
 
 
-#define DWORD_ALIGN_BITS(b)   (((b) / 32) + (((b) % 32 > 0) ? 1 : 0))
-
 using namespace FX;
 
 
@@ -58,21 +56,30 @@ FXIMPLEMENT(FXCURCursor,FXCursor,NULL,0)
 
 
 // Constructor
-FXCURCursor::FXCURCursor(FXApp* a,const void *pix):FXCursor(a,NULL,NULL,0,0,0,0){
+FXCURCursor::FXCURCursor(FXApp* a,const void *pix):FXCursor(a,NULL,0,0,0,0){
   if(pix){
     FXMemoryStream ms;
     ms.open(FXStreamLoad,(FXuchar*)pix);
-    if(fxloadCUR(ms,source,mask,width,height,hotx,hoty)) owned=TRUE;
+    fxloadICO(ms,data,width,height,hotx,hoty);
+    options|=CURSOR_OWNED;
     ms.close();
     }
   }
 
 
 
+// Save pixel data only, in CUR format
+FXbool FXCURCursor::savePixels(FXStream& store) const {
+  if(!fxsaveICO(store,data,width,height,hotx,hoty)) return FALSE;
+  return TRUE;
+  }
+
+
 // Load cursor mask and image
 FXbool FXCURCursor::loadPixels(FXStream & store){
-  if(!fxloadCUR(store,source,mask,width,height,hotx,hoty)) return FALSE;
-  owned=TRUE;
+  if(options&CURSOR_OWNED){FXFREE(&data);}
+  if(!fxloadICO(store,data,width,height,hotx,hoty)) return FALSE;
+  options|=CURSOR_OWNED;
   return TRUE;
   }
 
