@@ -3,7 +3,7 @@
 *                    C h e c k   B u t t o n    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCheckButton.cpp,v 1.44 2003/10/23 04:19:44 fox Exp $                   *
+* $Id: FXCheckButton.cpp,v 1.46 2004/02/17 21:06:02 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -82,20 +82,22 @@ FXIMPLEMENT(FXCheckButton,FXLabel,FXCheckButtonMap,ARRAYNUMBER(FXCheckButtonMap)
 
 // Deserialization
 FXCheckButton::FXCheckButton(){
+  checkColor=0;
+  boxColor=0;
   check=FALSE;
   oldcheck=FALSE;
-  boxColor=0;
   }
 
 
 // Make a check button
 FXCheckButton::FXCheckButton(FXComposite* p,const FXString& text,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb):
   FXLabel(p,text,NULL,opts,x,y,w,h,pl,pr,pt,pb){
+  checkColor=getApp()->getForeColor();
+  boxColor=getApp()->getBackColor();
   target=tgt;
   message=sel;
   check=FALSE;
   oldcheck=FALSE;
-  boxColor=getApp()->getBackColor();
   }
 
 
@@ -372,7 +374,7 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr){
   if(check==MAYBE || !isEnabled())
     dc.setForeground(shadowColor);
   else
-    dc.setForeground(textColor);
+    dc.setForeground(checkColor);
 
   // Show as +
   if(options&CHECKBUTTON_PLUS){
@@ -430,6 +432,15 @@ long FXCheckButton::onPaint(FXObject*,FXSelector,void* ptr){
   }
 
 
+// Set check color
+void FXCheckButton::setCheckColor(FXColor clr){
+  if(clr!=checkColor){
+    checkColor=clr;
+    update();
+    }
+  }
+
+
 // Set box color
 void FXCheckButton::setBoxColor(FXColor clr){
   if(clr!=boxColor){
@@ -458,6 +469,7 @@ FXuint FXCheckButton::getCheckButtonStyle() const {
 // Save object to stream
 void FXCheckButton::save(FXStream& store) const {
   FXLabel::save(store);
+  store << checkColor;
   store << boxColor;
   }
 
@@ -465,6 +477,7 @@ void FXCheckButton::save(FXStream& store) const {
 // Load object from stream
 void FXCheckButton::load(FXStream& store){
   FXLabel::load(store);
+  store >> checkColor;
   store >> boxColor;
   }
 
