@@ -3,7 +3,7 @@
 *                        C o l o r W h e e l   W i d g e t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2001,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXColorWheel.cpp,v 1.30 2003/10/23 17:53:17 fox Exp $                    *
+* $Id: FXColorWheel.cpp,v 1.32 2004/02/08 17:29:06 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -334,10 +334,10 @@ long FXColorWheel::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
 
 // Rotate hue by means of dial
 long FXColorWheel::onMouseWheel(FXObject*,FXSelector,void* ptr){
-  FXfloat amount=((FXEvent*)ptr)->code/12;
+  FXfloat amount=((FXEvent*)ptr)->code/12.0f;
   if(isEnabled()){
     if(((FXEvent*)ptr)->state&CONTROLMASK) amount/=10.0f;
-    setHue(fmod(hsv[0]+amount+360.0,360.0));
+    setHue(fmodf(hsv[0]+amount+360.0f,360.0f));
     if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)hsv);
     return 1;
     }
