@@ -3,7 +3,7 @@
 *           D e v i c e   C o n t e x t   F o r   P r i n t i n g               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDCPrint.cpp,v 1.38 2003/10/23 04:19:44 fox Exp $                       *
+* $Id: FXDCPrint.cpp,v 1.41 2004/03/10 23:19:41 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -136,8 +136,19 @@ void FXDCPrint::bbox(FXfloat x,FXfloat y){
   }
 
 
+// Send the range of coordinates that will be sent
+FXbool FXDCPrint::setContentRange(FXint pxminArg, FXint pyminArg, FXint pxmaxArg, FXint pymaxArg){
+  pxmin=pxminArg;
+  pymin=pyminArg;
+  pxmax=pxmaxArg;
+  pymax=pymaxArg;
+  return TRUE;    // Should we check for appropriate ranges?
+  }
+
+
 // Transform point
 void FXDCPrint::tfm(FXfloat& xo,FXfloat& yo,FXfloat xi,FXfloat yi){
+/*
   if(flags&PRINT_LANDSCAPE){
     xo=yi;
     yo=(FXfloat)(mediaheight-xi);
@@ -146,6 +157,38 @@ void FXDCPrint::tfm(FXfloat& xo,FXfloat& yo,FXfloat xi,FXfloat yi){
     xo=xi;
     yo=(FXfloat)(mediaheight-yi);
     }
+*/
+  FXfloat pxrange=static_cast<FXfloat>(pxmax-pxmin);
+  FXfloat pyrange=static_cast<FXfloat>(pymax-pymin);
+  FXfloat mxmin,mxmax,mymin,mymax,mxrange,myrange;
+
+  if(flags&PRINT_LANDSCAPE){
+    mxmin=static_cast<FXfloat>(mediabb.ymin);
+    mxmax=static_cast<FXfloat>(mediabb.ymax);
+    mymin=static_cast<FXfloat>(mediawidth-mediabb.xmax);
+    mymax=static_cast<FXfloat>(mediawidth-mediabb.xmin);
+    mxrange=mxmax-mxmin;
+    myrange=mymax-mymin;
+    //xo=xi;
+    //yo=mediawidth-yi;
+    }
+  else{
+    mxmin=static_cast<FXfloat>(mediabb.xmin);
+    mxmax=static_cast<FXfloat>(mediabb.xmax);
+    mymin=static_cast<FXfloat>(mediabb.ymin);
+    mymax=static_cast<FXfloat>(mediabb.ymax);
+    mxrange=mxmax-mxmin;
+    myrange=mymax-mymin;
+    }
+
+  if (pyrange/pxrange<=myrange/mxrange) { // short/wide
+    xo=mxmin+((xi-pxmin)/pxrange)*mxrange;
+    yo=mymin+.5f*(myrange-pyrange*(mxrange/pxrange))+(pyrange-yi)*(mxrange/pxrange);
+    }
+  else {// tall/thin
+    xo=mxmin+.5f*(mxrange-pxrange*(myrange/pyrange))+xi*(myrange/pyrange);
+    yo=mymin+((pyrange-yi)/pyrange)*myrange;
+    }
   }
 
 
@@ -716,6 +759,7 @@ void FXDCPrint::fillComplexPolygonRel(const FXPoint*,FXuint){
 // Draw string (only foreground bits)
 // Contributed by S. Ancelot <sancelot@online.fr>
 void FXDCPrint::drawText(FXint x,FXint y,const FXchar* string,FXuint len){
+/*
   FXfloat xx,yy;
   tfm(xx,yy,(FXfloat)x,(FXfloat)y);
   bbox(xx,yy);
@@ -732,6 +776,89 @@ void FXDCPrint::drawText(FXint x,FXint y,const FXchar* string,FXuint len){
     }
   outf(") show\n");
   outf("grestore\n");
+*/
+  FXfloat xx,yy;
+  tfm(xx,yy,(FXfloat)x,(FXfloat)y);
+
+  // old font size was hardcoded...
+  //outf("(%s) %g %g %d /Courier drawText\n",string,xx,yy,15);
+
+  FXfloat pxrange=static_cast<FXfloat>(pxmax-pxmin);
+  FXfloat pyrange=static_cast<FXfloat>(pymax-pymin);
+  FXfloat mxmin,mxmax,mymin,mymax,mxrange,myrange;
+
+  if(flags&PRINT_LANDSCAPE){
+    mxmin=static_cast<FXfloat>(mediabb.ymin);
+    mxmax=static_cast<FXfloat>(mediabb.ymax);
+    mymin=static_cast<FXfloat>(mediawidth-mediabb.xmax);
+    mymax=static_cast<FXfloat>(mediawidth-mediabb.xmin);
+    mxrange=mxmax-mxmin;
+    myrange=mymax-mymin;
+    }
+  else{
+    mxmin=static_cast<FXfloat>(mediabb.xmin);
+    mxmax=static_cast<FXfloat>(mediabb.xmax);
+    mymin=static_cast<FXfloat>(mediabb.ymin);
+    mymax=static_cast<FXfloat>(mediabb.ymax);
+    mxrange=mxmax-mxmin;
+    myrange=mymax-mymin;
+    }
+  FXfloat fsize=0.1f*font->getSize();
+  // Hack...
+  // Account for dpi and scale up or down with graph...
+  // Perhaps override screen resolution via registry
+  FXint screenres=getApp()->reg().readUnsignedEntry("SETTINGS","screenres",100);
+  // Validate
+  if(screenres<50) screenres=50;
+  if(screenres>200) screenres=200;
+
+  if(pyrange/pxrange<=myrange/mxrange){ // short/wide
+    fsize *= (mxrange/pxrange)*(screenres/72.f);
+    }
+  else{// tall/thin
+    fsize *= (myrange/pyrange)*(screenres/72.f);
+    }
+
+
+  FXString fname=font->getName();
+  if(fname=="times"){
+    fname="Times";
+    }
+  else if(fname=="helvetica"){
+    fname="Helvetica";
+    }
+  else if(fname=="courier"){
+    fname="Courier";
+    }
+  else{
+    fname="Courier";
+    }
+  if(font->getWeight()==FONTWEIGHT_BOLD){
+    if(font->getSlant()==FONTSLANT_ITALIC){
+      fname+="-BoldItalic";
+      }
+    else if(font->getSlant()==FONTSLANT_OBLIQUE){
+      fname+="-BoldOblique";
+      }
+    else {
+      fname+="-Bold";
+      }
+    }
+  else{
+    if(font->getSlant()==FONTSLANT_ITALIC){
+      fname+="-Italic";
+      }
+    else if(font->getSlant()==FONTSLANT_OBLIQUE){
+      fname+="-Oblique";
+      }
+    }
+  if(fname=="Times"){
+    fname+="-Roman";
+    }
+
+
+  //outf("(%s) %g %g %d /Courier drawText\n",string,xx,yy,(int)fsize);
+  outf("(%s) %g %g %d /%s drawText\n",string,xx,yy,(int)fsize,fname.text());
   }
 
 
