@@ -3,7 +3,7 @@
 *                     D i r e c t o r y   L i s t   O b j e c t                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDirList.cpp,v 1.128 2003/10/23 04:19:44 fox Exp $                      *
+* $Id: FXDirList.cpp,v 1.130 2004/02/08 17:29:06 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -142,8 +142,8 @@ FXDirList::FXDirList(){
 
 
 // Directory List Widget
-FXDirList::FXDirList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
-  FXTreeList(p,nvis,tgt,sel,opts,x,y,w,h),pattern("*"){
+FXDirList::FXDirList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+  FXTreeList(p,tgt,sel,opts,x,y,w,h),pattern("*"){
   flags|=FLAG_ENABLED|FLAG_DROPTARGET;
   open_folder=new FXGIFIcon(getApp(),minifolderopen);
   closed_folder=new FXGIFIcon(getApp(),minifolder);
