@@ -3,7 +3,7 @@
 *      F i l e   I n f o r m a t i o n   a n d   M a n i p u l a t i o n        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFile.cpp,v 1.171 2003/10/13 20:20:43 fox Exp $                         *
+* $Id: FXFile.cpp,v 1.174 2004/04/16 14:25:33 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -518,31 +518,33 @@ FXString FXFile::simplify(const FXString& file){
 // Build absolute pathname
 FXString FXFile::absolute(const FXString& file){
   FXString pathfile=FXFile::expand(file);
+  if(pathfile.empty()) return FXFile::getCurrentDirectory();
 #ifndef WIN32
   if(ISPATHSEP(pathfile[0])) return FXFile::simplify(pathfile);
 #else
   if(ISPATHSEP(pathfile[0])){
     if(ISPATHSEP(pathfile[1])) return FXFile::simplify(pathfile);   // UNC
-    return FXFile::simplify(getCurrentDrive()+pathfile);
+    return FXFile::simplify(FXFile::getCurrentDrive()+pathfile);
     }
   if(isalpha((FXuchar)pathfile[0]) && pathfile[1]==':'){
     if(ISPATHSEP(pathfile[2])) return FXFile::simplify(pathfile);
     return FXFile::simplify(pathfile.mid(0,2)+PATHSEPSTRING+pathfile.mid(2,2147483647));
     }
 #endif
-  return FXFile::simplify(getCurrentDirectory()+PATHSEPSTRING+pathfile);
+  return FXFile::simplify(FXFile::getCurrentDirectory()+PATHSEPSTRING+pathfile);
   }
 
 
 // Build absolute pathname from parts
 FXString FXFile::absolute(const FXString& base,const FXString& file){
   FXString pathfile=FXFile::expand(file);
+  if(pathfile.empty()) return FXFile::absolute(base);
 #ifndef WIN32
   if(ISPATHSEP(pathfile[0])) return FXFile::simplify(pathfile);
 #else
   if(ISPATHSEP(pathfile[0])){
     if(ISPATHSEP(pathfile[1])) return FXFile::simplify(pathfile);   // UNC
-    return FXFile::simplify(getCurrentDrive()+pathfile);
+    return FXFile::simplify(FXFile::getCurrentDrive()+pathfile);
     }
   if(isalpha((FXuchar)pathfile[0]) && pathfile[1]==':'){
     if(ISPATHSEP(pathfile[2])) return FXFile::simplify(pathfile);
@@ -569,7 +571,7 @@ FXString FXFile::root(const FXString& file){
 FXString FXFile::root(const FXString& file){
   if(ISPATHSEP(file[0])){
     if(ISPATHSEP(file[1])) return PATHSEPSTRING PATHSEPSTRING;   // UNC
-    return getCurrentDrive()+PATHSEPSTRING;
+    return FXFile::getCurrentDrive()+PATHSEPSTRING;
     }
   if(isalpha((FXuchar)file[0]) && file[1]==':'){
     if(ISPATHSEP(file[2])) return file.left(3);
@@ -1198,7 +1200,7 @@ FXTime FXFile::touched(const FXString& file){
 
 
 // List all the files in directory
-FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pattern,FXuint flags){
+FXint FXFile::listFiles(FXString*& filelist,const FXString& path,const FXString& pattern,FXuint flags){
   FXuint matchmode=FILEMATCH_FILE_NAME|FILEMATCH_NOESCAPE;
   FXString pathname;
   FXString name;
@@ -1210,11 +1212,11 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
   struct stat inf;
 
   // Initialize to empty
-  list=NULL;
+  filelist=NULL;
 /*
   // One single root under Unix
   if(path.empty()){
-    list=new FXString[2];
+    filelist=new FXString[2];
     list[count++]=PATHSEPSTRING;
     return count;
     }
@@ -1255,13 +1257,13 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
       if(count+1>=size){
         size=size?(size<<1):256;
         newlist=new FXString [size];
-        for(int i=0; i<count; i++) newlist[i]=list[i];
-        delete [] list;
-        list=newlist;
+        for(int i=0; i<count; i++) newlist[i]=filelist[i];
+        delete [] filelist;
+        filelist=newlist;
         }
 
       // Add to list
-      list[count++]=name;
+      filelist[count++]=name;
       }
     closedir(dirp);
     }
@@ -1273,7 +1275,7 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
 
 
 // List all the files in directory
-FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pattern,FXuint flags){
+FXint FXFile::listFiles(FXString*& filelist,const FXString& path,const FXString& pattern,FXuint flags){
   FXuint matchmode=FILEMATCH_FILE_NAME|FILEMATCH_NOESCAPE;
   FXString pathname;
   FXString name;
@@ -1286,7 +1288,7 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
   FXchar server[200];
 
   // Initialize to empty
-  list=NULL;
+  filelist=NULL;
 
 /*
   // Each drive is a root on windows
@@ -1296,11 +1298,11 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
     letter[1]=':';
     letter[2]=PATHSEP;
     letter[3]='\0';
-    list=new FXString[28];
+    filelist=new FXString[28];
     for(DWORD mask=GetLogicalDrives(); mask; mask>>=1,letter[0]++){
       if(mask&1) list[count++]=letter;
       }
-    list[count++]=PATHSEPSTRING PATHSEPSTRING;    // UNC for file shares
+    filelist[count++]=PATHSEPSTRING PATHSEPSTRING;    // UNC for file shares
     return count;
     }
 */
@@ -1344,12 +1346,12 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
             size=size?(size<<1):256;
             newlist=new FXString[size];
             for(j=0; j<count; j++) newlist[j]=list[j];
-            delete [] list;
-            list=newlist;
+            delete [] filelist;
+            filelist=newlist;
             }
 
           // Add remote name to list
-          list[count]=resource[i].lpRemoteName;
+          filelist[count]=resource[i].lpRemoteName;
           count++;
           }
         }
@@ -1386,13 +1388,13 @@ FXint FXFile::listFiles(FXString*& list,const FXString& path,const FXString& pat
       if(count+1>=size){
         size=size?(size<<1):256;
         newlist=new FXString[size];
-        for(int f=0; f<count; f++) newlist[f]=list[f];
-        delete [] list;
-        list=newlist;
+        for(int f=0; f<count; f++) newlist[f]=filelist[f];
+        delete [] filelist;
+        filelist=newlist;
         }
 
       // Add to list
-      list[count++]=name;
+      filelist[count++]=name;
       }
     while(FindNextFile(hFindFile,&ffData));
     FindClose(hFindFile);
