@@ -3,7 +3,7 @@
 *                    F o l d i n g   L i s t   W i d g e t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFoldingList.cpp,v 1.27 2003/10/23 04:19:44 fox Exp $                   *
+* $Id: FXFoldingList.cpp,v 1.39 2004/04/30 03:44:51 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -57,11 +57,12 @@
 */
 
 
-#define ICON_SPACING        4         // Spacing between parent and child in x direction
-#define TEXT_SPACING        4         // Spacing between icon and text
-#define SIDE_SPACING        4         // Spacing between side and item
-
-#define DEFAULT_INDENT      8         // Indent between parent and child
+#define ICON_SPACING        4   // Spacing between parent and child in x direction
+#define TEXT_SPACING        4   // Spacing between icon and text
+#define SIDE_SPACING        4   // Spacing between side and item
+#define DEFAULT_INDENT      8   // Indent between parent and child
+#define HALFBOX_SIZE        4   // Half box size
+#define BOX_FUDGE           3   // Fudge border around box
 
 
 #define SELECT_MASK         (FOLDINGLIST_SINGLESELECT|FOLDINGLIST_BROWSESELECT)
@@ -84,29 +85,29 @@ void FXFoldingItem::draw(const FXFoldingList* list,FXDC& dc,FXint x,FXint y,FXin
   register FXHeader *header=list->getHeader();
   register FXIcon *icon=(state&OPENED)?openIcon:closedIcon;
   register FXFont *font=list->getFont();
-  register FXint th=0,tw=0,ih=0,iw=0,yt,xb,beg,end,hi,drw,space,used,dw;
+  register FXint th=0,tw=0,ih=0,iw=0,yt,xb,beg,end,hi,drw,space,used,dw,xx;
   if(header->getNumItems()==0) return;
-  x+=SIDE_SPACING/2;
+  xx=x+SIDE_SPACING/2;
   if(icon){
     iw=icon->getWidth();
     ih=icon->getHeight();
-    dc.setClipRectangle(header->getX(),y,header->getItemSize(0),h);
-    dc.drawIcon(icon,x,y+(h-ih)/2);
+    dc.setClipRectangle(header->getItemOffset(0),y,header->getItemSize(0),h);
+    dc.drawIcon(icon,xx,y+(h-ih)/2);
     dc.clearClipRectangle();
-    x+=ICON_SPACING+iw;
+    xx+=ICON_SPACING+iw;
     }
   if(!label.empty()){
     th=font->getFontHeight();
     dw=font->getTextWidth("...",3);
-    xb=header->getX()+header->getItemSize(0);
-    if(xb>x) xb=x;
+    xb=header->getItemOffset(0)+header->getItemSize(0);
+    if(xb>xx) xb=xx;
     yt=y+(h-th-4)/2;
     if(isSelected()){
       dc.setForeground(list->getSelBackColor());
-      dc.fillRectangle(xb,y,header->getWidth()-xb,h);
+      dc.fillRectangle(xb,y,header->getTotalSize()-xb,h);
       }
     if(hasFocus()){
-      dc.drawFocusRectangle(xb+1,y+1,header->getWidth()-xb-2,h-2);
+      dc.drawFocusRectangle(xb+1,y+1,header->getTotalSize()-xb-2,h-2);
       }
     if(!isEnabled())
       dc.setForeground(makeShadowColor(list->getBackColor()));
@@ -114,7 +115,7 @@ void FXFoldingItem::draw(const FXFoldingList* list,FXDC& dc,FXint x,FXint y,FXin
       dc.setForeground(list->getSelTextColor());
     else
       dc.setForeground(list->getTextColor());
-    used=x-header->getX();
+    used=xx-header->getItemOffset(0);
     for(hi=beg=0; beg<label.length() && hi<header->getNumItems(); hi++,beg=end+1){
       space=header->getItemSize(hi)-used;
       for(end=beg; end<label.length() && label[end]!='\t'; end++);
@@ -123,16 +124,16 @@ void FXFoldingItem::draw(const FXFoldingList* list,FXDC& dc,FXint x,FXint y,FXin
         tw=font->getTextWidth(&label[beg],drw);
         if(tw>space-4){
           while((tw=font->getTextWidth(&label[beg],drw))+dw>space-4 && drw>1) drw--;
-          dc.setClipRectangle(x,y,space,h);
-          dc.drawText(x+2,yt+font->getFontAscent()+2,&label[beg],drw);
-          dc.drawText(x+tw+2,yt+font->getFontAscent()+2,"...",3);
+          dc.setClipRectangle(xx,y,space,h);
+          dc.drawText(xx+2,yt+font->getFontAscent()+2,&label[beg],drw);
+          dc.drawText(xx+tw+2,yt+font->getFontAscent()+2,"...",3);
           dc.clearClipRectangle();
           }
         else{
-          dc.drawText(x+2,yt+font->getFontAscent()+2,&label[beg],drw);
+          dc.drawText(xx+2,yt+font->getFontAscent()+2,&label[beg],drw);
           }
         }
-      x+=space;
+      xx+=space;
       used=0;
       }
     }
@@ -214,6 +215,12 @@ void FXFoldingItem::setIconOwned(FXuint owned){
   }
 
 
+// Change has items flag
+void FXFoldingItem::setHasItems(FXbool flag){
+  if(flag) state|=HASITEMS; else state&=~HASITEMS;
+  }
+
+
 // Create icon
 void FXFoldingItem::create(){
   if(openIcon) openIcon->create();
@@ -280,19 +287,7 @@ FXbool FXFoldingItem::isParentOf(const FXFoldingItem* item) const {
 
 
 // Get item width
-FXint FXFoldingItem::getWidth(const FXFoldingList* list) const {        // FIXME maybe add index of section which to measure
-/*
-  register FXint w=0,oiw=0,ciw=0;
-  if(list->getHeader()->getNumItems()) return list->getHeader()->getDefaultWidth();
-  if(openIcon)   oiw=openIcon->getWidth();
-  if(closedIcon) ciw=closedIcon->getWidth();
-  w=FXMAX(oiw,ciw);
-  if(!label.empty()){
-    if(w) w+=ICON_SPACING;
-    w+=4+list->getFont()->getTextWidth(label.extract(0,'\t').text(),label.extract(0,'\t').length());
-    }
-  return SIDE_SPACING+w;
-*/
+FXint FXFoldingItem::getWidth(const FXFoldingList*) const {
   return SIDE_SPACING;
   }
 
@@ -399,7 +394,7 @@ FXFoldingList::FXFoldingList(){
   currentitem=NULL;
   extentitem=NULL;
   cursoritem=NULL;
-  font=(FXFont*)-1;
+  font=(FXFont*)-1L;
   sortfunc=NULL;
   textColor=0;
   selbackColor=0;
@@ -416,7 +411,7 @@ FXFoldingList::FXFoldingList(){
 
 
 // Tree List
-FXFoldingList::FXFoldingList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FXFoldingList::FXFoldingList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
   FXScrollArea(p,opts,x,y,w,h){
   flags|=FLAG_ENABLED;
   header=new FXHeader(this,this,FXFoldingList::ID_HEADER_CHANGE,HEADER_TRACKING|HEADER_BUTTON|FRAME_RAISED|FRAME_THICK);
@@ -436,7 +431,7 @@ FXFoldingList::FXFoldingList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector
   lineColor=getApp()->getShadowColor();
   treeWidth=0;
   treeHeight=0;
-  visible=FXMAX(nvis,0);
+  visible=0;
   indent=DEFAULT_INDENT;
   grabx=0;
   graby=0;
@@ -516,7 +511,7 @@ void FXFoldingList::moveContents(FXint x,FXint y){
   FXint dy=y-pos_y;
   pos_x=x;
   pos_y=y;
-  header->move(x,0);
+  header->setPosition(x);
   scroll(0,header->getHeight(),viewport_w,viewport_h,dx,dy);
   }
 
@@ -590,19 +585,12 @@ FXint FXFoldingList::getContentHeight(){
 
 // Recalculate layout
 void FXFoldingList::layout(){
-  FXint ww,hh;
-
-  // Repaint when content size changed
-  //if(flags&FLAG_RECALC) update();
 
   // Calculate contents
   FXScrollArea::layout();
 
-  // Show or hide header
-  ww=header->getDefaultWidth();
-  hh=header->getDefaultHeight();
-  if(ww<viewport_w) ww=viewport_w;
-  header->position(pos_x,0,ww,hh);
+  // Place header control
+  header->position(0,0,viewport_w,header->getDefaultHeight());
 
   // Set line size based on item size
   if(firstitem){
@@ -870,10 +858,10 @@ FXint FXFoldingList::hitItem(const FXFoldingItem* item,FXint x,FXint y) const {
     iy=item->y+hh;
     ih=item->getHeight(this);
     if(iy<=y && y<iy+ih){
-      if((options&FOLDINGLIST_SHOWS_BOXES) && ((item->state&FXFoldingItem::HASITEMS) || item->first)){
+      if((options&FOLDINGLIST_SHOWS_BOXES) && (item->hasItems() || item->getFirst())){
         xh=ix-indent+(SIDE_SPACING/2);
         yh=iy+ih/2;
-        if(xh-4<=x && x<=xh+4 && yh-4<=y && y<=yh+4) return 3;
+        if(xh-HALFBOX_SIZE-BOX_FUDGE<=x && x<=xh+HALFBOX_SIZE+BOX_FUDGE && yh-HALFBOX_SIZE-BOX_FUDGE<=y && y<=yh+HALFBOX_SIZE+BOX_FUDGE) return 3;
         }
       hit=item->hitItem(this,x-ix,y-iy);
       }
@@ -1191,7 +1179,7 @@ long FXFoldingList::onQueryTip(FXObject* sender,FXSelector,void*){
     getCursorPosition(x,y,state);
     FXFoldingItem *item=getItemAt(x,y);
     if(item){
-      FXString string=item->getText();
+      FXString string=item->getText().section('\t',0);
       sender->handle(this,FXSEL(SEL_COMMAND,ID_SETSTRINGVALUE),(void*)&string);
       return 1;
       }
@@ -1240,7 +1228,11 @@ long FXFoldingList::onPaint(FXObject*,FXSelector,void* ptr){
   FXint yh,xh,x,y,w,h,xp,hh;
   FXDCWindow dc(this,event);
   dc.setFont(font);
-  if(header->getNumItems()==0) return 1;
+  if(header->getNumItems()==0){
+    dc.setForeground(backColor);
+    dc.fillRectangle(0,0,width,height);
+    return 1;
+    }
   x=pos_x;
   y=pos_y+header->getHeight();
   if(options&FOLDINGLIST_ROOT_BOXES) x+=(4+indent);
@@ -1271,9 +1263,9 @@ long FXFoldingList::onPaint(FXObject*,FXSelector,void* ptr){
             if(p->next) dc.fillRectangle(xp,y,1,h);
             p=p->parent;
             }
-          if((options&FOLDINGLIST_SHOWS_BOXES) && ((item->state&FXFoldingItem::HASITEMS) || item->first)){
-            if(item->prev || item->parent) dc.fillRectangle(xh,y,1,yh-y-4);
-            if(item->next) dc.fillRectangle(xh,yh+4,1,y+h-yh-4);
+          if((options&FOLDINGLIST_SHOWS_BOXES) && (item->hasItems() || item->getFirst())){
+            if(item->prev || item->parent) dc.fillRectangle(xh,y,1,yh-y-HALFBOX_SIZE);
+            if(item->next) dc.fillRectangle(xh,yh+HALFBOX_SIZE,1,y+h-yh-HALFBOX_SIZE);
             }
           else{
             if(item->prev || item->parent) dc.fillRectangle(xh,y,1,hh);
@@ -1284,15 +1276,15 @@ long FXFoldingList::onPaint(FXObject*,FXSelector,void* ptr){
           }
 
         // Boxes before items for expand/collapse of item
-        if((options&FOLDINGLIST_SHOWS_BOXES) && ((item->state&FXFoldingItem::HASITEMS) || item->first)){
+        if((options&FOLDINGLIST_SHOWS_BOXES) && (item->hasItems() || item->getFirst())){
           dc.setFillStyle(FILL_STIPPLED);
           dc.fillRectangle(xh+4,yh,(SIDE_SPACING/2)-2,1);
           dc.setFillStyle(FILL_SOLID);
-          dc.drawRectangle(xh-4,yh-4,8,8);
+          dc.drawRectangle(xh-HALFBOX_SIZE,yh-HALFBOX_SIZE,HALFBOX_SIZE+HALFBOX_SIZE,HALFBOX_SIZE+HALFBOX_SIZE);
           dc.setForeground(textColor);
-          dc.fillRectangle(xh-2,yh,5,1);
+          dc.fillRectangle(xh-HALFBOX_SIZE+2,yh,HALFBOX_SIZE+HALFBOX_SIZE-3,1);
           if(!(options&FOLDINGLIST_AUTOSELECT) && !item->isExpanded()){
-            dc.fillRectangle(xh,yh-2,1,5);
+            dc.fillRectangle(xh,yh-HALFBOX_SIZE+2,1,HALFBOX_SIZE+HALFBOX_SIZE-3);
             }
           }
         dc.clearClipRectangle();
@@ -1382,7 +1374,7 @@ long FXFoldingList::onKeyPress(FXObject*,FXSelector,void* ptr){
     case KEY_Right:                       // Move right/down and open subtree
     case KEY_KP_Right:
       if(item){
-        if(!(options&FOLDINGLIST_AUTOSELECT) && !item->isExpanded() && ((item->state&FXFoldingItem::HASITEMS) || item->first)){
+        if(!(options&FOLDINGLIST_AUTOSELECT) && !item->isExpanded() && (item->hasItems() || item->getFirst())){
           expandTree(item,TRUE);
           }
         else if(item->first){
@@ -1397,7 +1389,7 @@ long FXFoldingList::onKeyPress(FXObject*,FXSelector,void* ptr){
     case KEY_Left:                        // Move left/up and close subtree
     case KEY_KP_Left:
       if(item){
-        if(!(options&FOLDINGLIST_AUTOSELECT) && item->isExpanded() && ((item->state&FXFoldingItem::HASITEMS) || item->first)){
+        if(!(options&FOLDINGLIST_AUTOSELECT) && item->isExpanded() && (item->hasItems() || item->getFirst())){
           collapseTree(item,TRUE);
           }
         else if(item->parent){
