@@ -3,7 +3,7 @@
 *                    O p e n G L   C a n v a s   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCanvas.cpp,v 1.48 2003/10/23 04:19:44 fox Exp $                      *
+* $Id: FXGLCanvas.cpp,v 1.51.2.1 2004/05/19 03:35:41 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -197,8 +197,8 @@ FXbool FXGLCanvas::makeCurrent(){
     return glXMakeCurrent((Display*)getApp()->getDisplay(),xid,(GLXContext)ctx);
 #else
     HDC hdc=::GetDC((HWND)xid);
-    if(visual->hPalette){
-      SelectPalette(hdc,(HPALETTE)visual->hPalette,FALSE);
+    if(visual->colormap){
+      SelectPalette(hdc,(HPALETTE)visual->colormap,FALSE);
       RealizePalette(hdc);
       }
     BOOL bStatus=wglMakeCurrent(hdc,(HGLRC)ctx);
@@ -230,14 +230,28 @@ FXbool FXGLCanvas::makeNonCurrent(){
   }
 
 
-//  Return TRUE if context is current
+// Return current context, if any
+void* FXGLCanvas::getCurrentContext(){
+#ifdef HAVE_GL_H
+#ifndef WIN32
+  return (void*)glXGetCurrentContext();
+#else
+  return (void*)wglGetCurrentContext();
+#endif
+#else
+  return NULL;
+#endif
+  }
+
+
+//  Return TRUE if this window's context is current
 FXbool FXGLCanvas::isCurrent() const {
 #ifdef HAVE_GL_H
   if(ctx){
 #ifndef WIN32
-    return glXGetCurrentContext()!=NULL;
+    return (glXGetCurrentContext() == (GLXContext)ctx);
 #else
-    return wglGetCurrentContext()!=NULL;
+    return (wglGetCurrentContext() == (HGLRC)ctx);
 #endif
     }
 #endif
