@@ -3,7 +3,7 @@
 *                      O p e n G L   C o n e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCone.cpp,v 1.20 2003/10/23 04:19:44 fox Exp $                        *
+* $Id: FXGLCone.cpp,v 1.22 2004/02/20 16:29:39 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -32,7 +32,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -69,9 +69,9 @@ FXIMPLEMENT(FXGLCone,FXGLShape,NULL,0)
 // Create cone
 FXGLCone::FXGLCone():height(1.0f),radius(1.0f){
   FXTRACE((100,"FXGLCone::FXGLCone\n"));
-  range[0][0]=-radius; range[0][1]=radius;
-  range[1][0]=0.0f;    range[1][1]=height;
-  range[2][0]=-radius; range[2][1]=radius;
+  range.lower.x=-radius; range.upper.x=radius;
+  range.lower.y=0.0f;    range.upper.y=height;
+  range.lower.z=-radius; range.upper.z=radius;
   }
 
 
@@ -79,9 +79,9 @@ FXGLCone::FXGLCone():height(1.0f),radius(1.0f){
 FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r):
   FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),height(h),radius(r){
   FXTRACE((100,"FXGLCone::FXGLCone\n"));
-  range[0][0]=-radius; range[0][1]=radius;
-  range[1][0]=0.0f;    range[1][1]=height;
-  range[2][0]=-radius; range[2][1]=radius;
+  range.lower.x=-radius; range.upper.x=radius;
+  range.lower.y=0.0f;    range.upper.y=height;
+  range.lower.z=-radius; range.upper.z=radius;
   }
 
 
@@ -89,9 +89,9 @@ FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r):
 FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h, FXfloat r,const FXMaterial& mtl):
   FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),height(h),radius(r){
   FXTRACE((100,"FXGLCone::FXGLCone\n"));
-  range[0][0]=-radius; range[0][1]=radius;
-  range[1][0]=0.0f;    range[1][1]=height;
-  range[2][0]=-radius; range[2][1]=radius;
+  range.lower.x=-radius; range.upper.x=radius;
+  range.lower.y=0.0f;    range.upper.y=height;
+  range.lower.z=-radius; range.upper.z=radius;
   }
 
 
