@@ -3,7 +3,7 @@
 *                      O p e n G L   C u b e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLCube.cpp,v 1.19 2003/10/23 04:19:44 fox Exp $                        *
+* $Id: FXGLCube.cpp,v 1.21 2004/02/20 16:29:39 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -32,7 +32,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -59,9 +59,9 @@ FXIMPLEMENT(FXGLCube,FXGLShape,NULL,0)
 // Create cube
 FXGLCube::FXGLCube():width(1.0f),height(1.0f),depth(1.0f){
   FXTRACE((100,"FXGLCube::FXGLCube\n"));
-  range[0][0]=-0.5f*width;  range[0][1]=0.5f*width;
-  range[1][0]=-0.5f*height; range[1][1]=0.5f*height;
-  range[2][0]=-0.5f*depth;  range[2][1]=0.5f*depth;
+  range.lower.x=-0.5f*width;  range.upper.x=0.5f*width;
+  range.lower.y=-0.5f*height; range.upper.y=0.5f*height;
+  range.lower.z=-0.5f*depth;  range.upper.z=0.5f*depth;
   }
 
 
@@ -69,9 +69,9 @@ FXGLCube::FXGLCube():width(1.0f),height(1.0f),depth(1.0f){
 FXGLCube::FXGLCube(FXfloat x,FXfloat y,FXfloat z,FXfloat w,FXfloat h,FXfloat d):
   FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),width(w),height(h),depth(d){
   FXTRACE((100,"FXGLCube::FXGLCube\n"));
-  range[0][0]=-0.5f*width;  range[0][1]=0.5f*width;
-  range[1][0]=-0.5f*height; range[1][1]=0.5f*height;
-  range[2][0]=-0.5f*depth;  range[2][1]=0.5f*depth;
+  range.lower.x=-0.5f*width;  range.upper.x=0.5f*width;
+  range.lower.y=-0.5f*height; range.upper.y=0.5f*height;
+  range.lower.z=-0.5f*depth;  range.upper.z=0.5f*depth;
   }
 
 
@@ -79,9 +79,9 @@ FXGLCube::FXGLCube(FXfloat x,FXfloat y,FXfloat z,FXfloat w,FXfloat h,FXfloat d):
 FXGLCube::FXGLCube(FXfloat x,FXfloat y,FXfloat z,FXfloat w,FXfloat h,FXfloat d,const FXMaterial& mtl):
   FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),width(w),height(h),depth(d){
   FXTRACE((100,"FXGLCube::FXGLCube\n"));
-  range[0][0]=-0.5f*width;  range[0][1]=0.5f*width;
-  range[1][0]=-0.5f*height; range[1][1]=0.5f*height;
-  range[2][0]=-0.5f*depth;  range[2][1]=0.5f*depth;
+  range.lower.x=-0.5f*width;  range.upper.x=0.5f*width;
+  range.lower.y=-0.5f*height; range.upper.y=0.5f*height;
+  range.lower.z=-0.5f*depth;  range.upper.z=0.5f*depth;
   }
 
 
