@@ -3,7 +3,7 @@
 *                           O p e n G L   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLObject.cpp,v 1.25 2003/10/23 04:19:44 fox Exp $                      *
+* $Id: FXGLObject.cpp,v 1.28 2004/03/15 06:49:46 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -30,7 +30,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -112,8 +112,10 @@ FXIMPLEMENT(FXGLObject,FXObject,NULL,0)
 
 
 // Get bounding box
-void FXGLObject::bounds(FXRange& box){
-  box[0][0]=box[0][1]=box[1][0]=box[1][1]=box[2][0]=box[2][1]=0.0;
+void FXGLObject::bounds(FXRangef& box){
+  box.upper.x=box.lower.x=0.0f;
+  box.upper.y=box.lower.y=0.0f;
+  box.upper.z=box.lower.z=0.0f;
   }
 
 
@@ -155,16 +157,17 @@ FXIMPLEMENT(FXGLGroup,FXGLObject,NULL,0)
 
 
 // Get bounding box
-void FXGLGroup::bounds(FXRange& box){
-  if(list.no()==0){
-    box[0][0]=box[0][1]=box[1][0]=box[1][1]=box[2][0]=box[2][1]=0.0;
-    }
-  else{
-    box=FXRange(FLT_MAX,-FLT_MAX,FLT_MAX,-FLT_MAX,FLT_MAX,-FLT_MAX);
-    for(FXint i=0; i<list.no(); i++){
-      FXRange r;
-      list[i]->bounds(r);
-      box.include(r);
+void FXGLGroup::bounds(FXRangef& box){
+  register FXint i;
+  FXRangef b;
+  box.lower.x=box.lower.y=box.lower.z=0.0f;
+  box.upper.x=box.upper.y=box.upper.z=0.0f;
+  if(0<list.no()){
+    box.lower.x=box.lower.y=box.lower.z= FLT_MAX;
+    box.upper.x=box.upper.y=box.upper.z=-FLT_MAX;
+    for(i=0; i<list.no(); i++){
+      list[i]->bounds(b);
+      box.include(b);
       }
     }
   }
@@ -260,10 +263,10 @@ FXGLPoint::FXGLPoint(FXfloat x,FXfloat y,FXfloat z):pos(x,y,z){
 
 
 // Get bounding box
-void FXGLPoint::bounds(FXRange& box){
-  box[0][0]=box[0][1]=pos[0];
-  box[1][0]=box[1][1]=pos[1];
-  box[2][0]=box[2][1]=pos[2];
+void FXGLPoint::bounds(FXRangef& box){
+  box.upper.x=box.lower.x=pos.x;
+  box.upper.y=box.lower.y=pos.y;
+  box.upper.z=box.lower.z=pos.z;
   }
 
 
@@ -330,10 +333,10 @@ FXGLLine::FXGLLine(FXfloat fx,FXfloat fy,FXfloat fz,FXfloat tx,FXfloat ty,FXfloa
 
 
 // Get bounding box
-void FXGLLine::bounds(FXRange& box){
-  FXMINMAX(box[0][0],box[0][1],fm.pos[0],to.pos[0]);
-  FXMINMAX(box[1][0],box[1][1],fm.pos[1],to.pos[1]);
-  FXMINMAX(box[2][0],box[2][1],fm.pos[2],to.pos[2]);
+void FXGLLine::bounds(FXRangef& box){
+  FXMINMAX(box.lower.x,box.upper.x,fm.pos.x,to.pos.x);
+  FXMINMAX(box.lower.y,box.upper.y,fm.pos.y,to.pos.y);
+  FXMINMAX(box.lower.z,box.upper.z,fm.pos.z,to.pos.z);
   }
 
 
