@@ -3,7 +3,7 @@
 *               O p e n G L   T r i a n g l e   M e s h   O b j e c t           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLTriangleMesh.cpp,v 1.21 2003/10/23 04:19:44 fox Exp $                *
+* $Id: FXGLTriangleMesh.cpp,v 1.23 2004/02/20 16:29:39 fox Exp $                *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -32,7 +32,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -75,9 +75,9 @@ FXIMPLEMENT(FXGLTriangleMesh,FXGLShape,NULL,0)
 FXGLTriangleMesh::FXGLTriangleMesh():
   vertexBuffer(NULL),colorBuffer(NULL),normalBuffer(NULL),textureBuffer(NULL),vertexNumber(0){
   FXTRACE((100,"FXGLTriangleMesh::FXGLTriangleMesh\n"));
-  range[0][0]=0.0f; range[0][1]=0.0f;
-  range[1][0]=0.0f; range[1][1]=0.0f;
-  range[2][0]=0.0f; range[2][1]=0.0f;
+  range.lower.x=range.upper.x=0.0f;
+  range.lower.y=range.upper.y=0.0f;
+  range.lower.z=range.upper.z=0.0f;
   }
 
 
@@ -123,23 +123,23 @@ void FXGLTriangleMesh::setVertexBuffer(FXfloat *vertices){
 void FXGLTriangleMesh::recomputerange(){
   register FXint i,n;
   register FXfloat t;
-  range[0][0]=0.0f; range[0][1]=0.0f;
-  range[1][0]=0.0f; range[1][1]=0.0f;
-  range[2][0]=0.0f; range[2][1]=0.0f;
+  range.lower.x=range.upper.x=0.0f;
+  range.lower.y=range.upper.y=0.0f;
+  range.lower.z=range.upper.z=0.0f;
   if(vertexBuffer && vertexNumber>0){
-    range[0][0]=range[0][1]=vertexBuffer[0];
-    range[1][0]=range[1][1]=vertexBuffer[1];
-    range[2][0]=range[2][1]=vertexBuffer[2];
+    range.lower.x=range.upper.x=vertexBuffer[0];
+    range.lower.y=range.upper.y=vertexBuffer[0];
+    range.lower.z=range.upper.z=vertexBuffer[0];
     for(i=0,n=0; n<vertexNumber; n++){
       t=vertexBuffer[i++];
-      if(t<range[0][0]) range[0][0]=t;
-      if(t>range[0][1]) range[0][1]=t;
+      if(t<range.lower.x) range.lower.x=t;
+      if(t>range.upper.x) range.upper.x=t;
       t=vertexBuffer[i++];
-      if(t<range[1][0]) range[1][0]=t;
-      if(t>range[1][1]) range[1][1]=t;
+      if(t<range.lower.y) range.lower.y=t;
+      if(t>range.upper.y) range.upper.y=t;
       t=vertexBuffer[i++];
-      if(t<range[2][0]) range[2][0]=t;
-      if(t>range[2][1]) range[2][1]=t;
+      if(t<range.lower.z) range.lower.z=t;
+      if(t>range.upper.z) range.upper.z=t;
       }
     }
   }
