@@ -3,7 +3,7 @@
 *                           O p e n G L   V i e w e r                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGLViewer.cpp,v 1.134 2003/10/23 04:19:44 fox Exp $                     *
+* $Id: FXGLViewer.cpp,v 1.139 2004/03/05 22:56:25 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -31,7 +31,7 @@
 #include "FXVec4f.h"
 #include "FXQuatf.h"
 #include "FXMat4f.h"
-#include "FXRange.h"
+#include "FXRangef.h"
 #include "FXString.h"
 #include "FXSize.h"
 #include "FXPoint.h"
@@ -342,8 +342,8 @@ void FXGLViewer::initialize(){
   updateProjection();                           // Initial projection
   updateTransform();                            // Set transformation
   maxhits=512;                                  // Maximum hit buffer size
-  background[0][0]=0.4f;                        // Top background
-  background[0][1]=0.4f;
+  background[0][0]=0.5f;                        // Top background
+  background[0][1]=0.5f;
   background[0][2]=1.0f;
   background[0][3]=1.0f;
   background[1][0]=1.0f;                        // Bottom background
@@ -410,7 +410,7 @@ void FXGLViewer::initialize(){
 
 // Create window
 void FXGLViewer::create(){
-  FXRange r(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
+  FXRangef r(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
 
   // We would like to have this be true
 #ifdef HAVE_GL_H
@@ -1015,11 +1015,11 @@ void FXGLViewer::updateTransform(){
 
 
 // Set model bounding box
-FXbool FXGLViewer::setBounds(const FXRange& r){
-//   FXTRACE((100,"xlo=%g xhi=%g ylo=%g yhi=%g zlo=%g zhi=%g\n",r[0][0],r[0][1],r[1][0],r[1][1],r[2][0],r[2][1]));
+FXbool FXGLViewer::setBounds(const FXRangef& r){
+//   FXTRACE((100,"xlo=%g xhi=%g ylo=%g yhi=%g zlo=%g zhi=%g\n",r.lower.x,r.upper.x,r.lower.y,r.upper.y,r.lower.z,r.upper.z));
 
   // Model center
-  center=boxCenter(r);
+  center=r.center();
 
   // Model size
   diameter=r.longest();
@@ -1038,24 +1038,19 @@ FXbool FXGLViewer::setBounds(const FXRange& r){
 
 
 // Fit view to new bounds
-FXbool FXGLViewer::fitToBounds(const FXRange& box){
-  FXRange r(FLT_MAX,-FLT_MAX,FLT_MAX,-FLT_MAX,FLT_MAX,-FLT_MAX);
-  FXVec3f corner[8],v;
+FXbool FXGLViewer::fitToBounds(const FXRangef& box){
+  FXRangef r(FLT_MAX,-FLT_MAX,FLT_MAX,-FLT_MAX,FLT_MAX,-FLT_MAX);
+  FXVec3f corner;
   FXMat4f m;
-  register int i;
-
-  // Get corners
-  boxCorners(corner,box);
 
   // Get rotation of model
   m.eye();
   m.rot(rotation);
-  m.trans(-boxCenter(box));
+  m.trans(-box.center());
 
   // Transform box
-  for(i=0; i<8; i++){
-    v=corner[i]*m;
-    r.include(v[0],v[1],v[2]);
+  for(int i=0; i<8; i++){
+    r.include(box.corner(i)*m);
     }
 
   setBounds(r);
@@ -1086,13 +1081,13 @@ void FXGLViewer::getMaterial(FXMaterial &mtl) const {
 void FXGLViewer::eyeToScreen(FXint& sx,FXint& sy,FXVec3f e){
   register double xp,yp;
   if(projection==PERSPECTIVE){
-    if(e[2]==0.0f){ fxerror("%s::eyeToScreen: cannot transform point.\n",getClassName()); }
-    xp=-distance*e[0]/e[2];
-    yp=-distance*e[1]/e[2];
+    if(e.z==0.0f){ fxerror("%s::eyeToScreen: cannot transform point.\n",getClassName()); }
+    xp=-distance*e.x/e.z;
+    yp=-distance*e.y/e.z;
     }
   else{
-    xp=e[0];
-    yp=e[1];
+    xp=e.x;
+    yp=e.y;
     }
   sx=(int)((xp-ax)/worldpx);
   sy=(int)((ay-yp)/worldpx);
@@ -1107,14 +1102,14 @@ FXVec3f FXGLViewer::screenToEye(FXint sx,FXint sy,FXfloat eyez){
   yp=(float)(ay-worldpx*sy);
   if(projection==PERSPECTIVE){
     FXASSERT(distance>0.0);
-    e[0]=(FXfloat)(-eyez*xp/distance);
-    e[1]=(FXfloat)(-eyez*yp/distance);
-    e[2]=eyez;
+    e.x=(FXfloat)(-eyez*xp/distance);
+    e.y=(FXfloat)(-eyez*yp/distance);
+    e.z=eyez;
     }
   else{
-    e[0]=xp;
-    e[1]=yp;
-    e[2]=eyez;
+    e.x=xp;
+    e.y=yp;
+    e.z=eyez;
     }
   return e;
   }
@@ -1134,7 +1129,7 @@ FXVec3f FXGLViewer::worldToEye(FXVec3f w){
 
 // Get eye Z-coordinate of world point
 FXfloat FXGLViewer::worldToEyeZ(FXVec3f w){
-  return w[0]*transform[0][2]+w[1]*transform[1][2]+w[2]*transform[2][2]+transform[3][2];
+  return w.x*transform[0][2]+w.y*transform[1][2]+w.z*transform[2][2]+transform[3][2];
   }
 
 
@@ -1219,27 +1214,26 @@ void FXGLViewer::setTipText(const FXString& text){
 
 // Translate point into unit-sphere coordinate
 FXVec3f FXGLViewer::spherePoint(FXint px,FXint py){
-  FXdouble d,t,screenmin;
+  FXfloat d,t,screenmin;
   FXVec3f v;
   if(wvt.w>wvt.h)
     screenmin=wvt.h;
   else
     screenmin=wvt.w;
-  FXASSERT(screenmin>0.0);
-  v[0]=(FXfloat)(2.0*(px-0.5*wvt.w)/screenmin);
-  v[1]=(FXfloat)(2.0*(0.5*wvt.h-py)/screenmin);
-  d=v[0]*v[0]+v[1]*v[1];
+  v.x=2.0f*(px-0.5f*wvt.w)/screenmin;
+  v.y=2.0f*(0.5f*wvt.h-py)/screenmin;
+  d=v.x*v.x+v.y*v.y;
   if(d<0.75){
-    v[2]=(FXfloat)sqrt(1.0-d);
+    v.z=sqrtf(1.0-d);
     }
-  else if(d<3.0){
-    d=1.7320508008-sqrt(d);
-    t=1.0-d*d;
-    if(t<0.0) t=0.0;
-    v[2]=(FXfloat)(1.0-sqrt(t));
+  else if(d<3.0f){
+    d=1.7320508008f-sqrtf(d);
+    t=1.0f-d*d;
+    if(t<0.0f) t=0.0f;
+    v.z=1.0f-sqrtf(t);
     }
   else{
-    v[2]=0.0;
+    v.z=0.0f;
     }
   return normalize(v);
   }
@@ -1253,12 +1247,12 @@ FXQuatf FXGLViewer::turn(FXint fx,FXint fy,FXint tx,FXint ty){
   oldsp=spherePoint(fx,fy);
   newsp=spherePoint(tx,ty);
   q=arc(oldsp,newsp);
-  q[0]*=0.5f;
-  q[1]*=0.5f;
-  q[2]*=0.5f;
-  t=1.0f-(q[0]*q[0]+q[1]*q[1]+q[2]*q[2]);
+  q.x*=0.5f;
+  q.y*=0.5f;
+  q.z*=0.5f;
+  t=1.0f-(q.x*q.x+q.y*q.y+q.z*q.z);
   if(t<0.0f) t=0.0f;
-  q[3]=sqrtf(t);
+  q.w=sqrtf(t);
   return q;
   }
 
@@ -2188,7 +2182,7 @@ long FXGLViewer::onUpdBottom(FXObject* sender,FXSelector,void*){
 
 // Reset view
 long FXGLViewer::onCmdResetView(FXObject*,FXSelector,void*){
-  FXRange r(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
+  FXRangef r(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
   rotation=FXQuatf(0.0f,0.0f,0.0f,1.0f);
   zoom=1.0;
   scale=FXVec3f(1.0f,1.0f,1.0f);
@@ -2203,7 +2197,7 @@ long FXGLViewer::onCmdResetView(FXObject*,FXSelector,void*){
 
 // Fit view
 long FXGLViewer::onCmdFitView(FXObject*,FXSelector,void*){
-  FXRange r(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
+  FXRangef r(-1.0f,1.0f,-1.0f,1.0f,-1.0f,1.0f);
   if(scene) scene->bounds(r);
   setBounds(r);
   update();
