@@ -3,7 +3,7 @@
 *                       H a s h   T a b l e   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003 by Jeroen van der Zijp.   All Rights Reserved.             *
+* Copyright (C) 2003,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,9 +19,8 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXHash.cpp,v 1.9 2003/10/24 20:23:13 fox Exp $                           *
+* $Id: FXHash.cpp,v 1.20 2004/09/21 00:58:17 fox Exp $                          *
 ********************************************************************************/
-#include "xincs.h"
 #include "fxver.h"
 #include "fxdefs.h"
 #include "FXHash.h"
@@ -33,14 +32,14 @@
     in the table which are used and which are free.
   - When an item is inserted, used is incremented if the item isn't in the table
     yet, and free is decremented if a free slot is used; if an empty slot is
-    used, free stays the same.  If the table exceeds the load factor, its 
+    used, free stays the same.  If the table exceeds the load factor, its
     size is doubled.
   - When an item is removed, used is decremented but free stays the same
     because the slot remains marked as empty instead of free; when the
     number of used items drops below some minimum, the table's size is
     halved.
   - If the table is resized, the empty slots all become free slots since
-    the empty holes are not compied into the table.  All used items will
+    the empty holes are not copied into the table; only used items will
     be rehashed into the new table.
 */
 
@@ -57,10 +56,14 @@ namespace FX {
 
 // Make empty table
 FXHash::FXHash(){
-  FXCALLOC(&table,FXEntry,2);
-  max=1;
+  FXMALLOC(&table,FXEntry,2);
+  table[0].key=NULL;
+  table[0].val=NULL;
+  table[1].key=NULL;
+  table[1].val=NULL;
   used=0;
   free=2;
+  max=1;
   }
 
 
@@ -87,29 +90,53 @@ void FXHash::resize(FXuint m){
   }
 
 
-// Insert or replace association into the table
+// Insert key into the table
 void* FXHash::insert(void* key,void* val){
-  register FXuint p,pp,x,xx;
+  register FXuint p,pp,x;
   if(key){
-    //FXTRACE((1,"ins key=%p max=%u used=%u free=%u\n",key,max,used,free));
-    if((free<<1)<=max) resize((max<<1)|1);
+    if((free<<1)<=max+1) resize((max<<1)|1);
     p=pp=HASH1(key,max);
-    x=xx=HASH2(key,max);
+    x=HASH2(key,max);
     while(table[p].key){
-      if(table[p].key==key) goto y;             // Replace existing
+      if(table[p].key==key) goto y;             // Return existing
       p=(p+x)&max;
       }
     p=pp;
-    x=xx;
     while(table[p].key){
       if(table[p].key==(void*)-1L) goto x;      // Put it in empty slot
       p=(p+x)&max;
       }
     free--;
 x:  used++;
-y:  table[p].key=key;
+    table[p].key=key;
     table[p].val=val;
-    return val;
+y:  return table[p].val;
+    }
+  return NULL;
+  }
+
+
+// Replace key in the table
+void* FXHash::replace(void* key,void* val){
+  register FXuint p,pp,x;
+  if(key){
+    if((free<<1)<=max+1) resize((max<<1)|1);
+    p=pp=HASH1(key,max);
+    x=HASH2(key,max);
+    while(table[p].key){
+      if(table[p].key==key) goto y;             // Replace existing
+      p=(p+x)&max;
+      }
+    p=pp;
+    while(table[p].key){
+      if(table[p].key==(void*)-1L) goto x;      // Put it in empty slot
+      p=(p+x)&max;
+      }
+    free--;
+x:  used++;
+    table[p].key=key;
+y:  table[p].val=val;
+    return table[p].val;
     }
   return NULL;
   }
@@ -120,7 +147,6 @@ void* FXHash::remove(void* key){
   register FXuint p,x;
   register void* val;
   if(key){
-    //FXTRACE((1,"rem key=%p max=%u used=%u free=%u\n",key,max,used,free));
     p=HASH1(key,max);
     x=HASH2(key,max);
     while(table[p].key!=key){
@@ -131,7 +157,7 @@ void* FXHash::remove(void* key){
     table[p].key=(void*)-1L;                    // Empty but not free
     table[p].val=NULL;
     used--;
-    if((used<<2)<=max) resize(max>>1);
+    if(used<((max+1)>>2)) resize(max>>1);
     return val;
     }
 x:return NULL;
@@ -154,11 +180,24 @@ x:return NULL;
   }
 
 
+// Clear hash table
+void FXHash::clear(){
+  FXRESIZE(&table,FXEntry,2);
+  table[0].key=NULL;
+  table[0].val=NULL;
+  table[1].key=NULL;
+  table[1].val=NULL;
+  used=0;
+  free=2;
+  max=1;
+  }
+
+
 // Destroy table
 FXHash::~FXHash(){
-  //FXTRACE((1,"del max=%u used=%u free=%u\n",max,used,free));
   FXFREE(&table);
   table=(FXEntry*)-1L;
   }
 
 }
+
