@@ -3,7 +3,7 @@
 *                               H e a d e r   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXHeader.cpp,v 1.66 2003/10/23 04:19:44 fox Exp $                        *
+* $Id: FXHeader.cpp,v 1.83 2004/02/08 17:29:06 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -47,13 +47,16 @@
   - Allow some header items to be stretchable.
   - Add minimum, maximum size constraints to items.
   - Should up/down arrows go sideways when vertically oriented?
-  - Perhaps maintain button state in item.
   - Perhaps perform drawing of border in item also.
-  - If icon or text of item changes, need to recalc().
+  - Like for FXScrollArea, pos is always <=0 when scrolled.
+  - Maybe handy feature to initialize size to default item width
+    if initial size = 0.
+  - Maybe allow attach from right instead of only from left; perhaps
+    also attach both (or none).
 */
 
 
-#define FUDGE         8
+#define FUDGE         4
 #define ICON_SPACING  4
 #define HEADER_MASK   (HEADER_BUTTON|HEADER_TRACKING|HEADER_VERTICAL)
 
@@ -164,7 +167,7 @@ void FXHeaderItem::draw(const FXHeader* header,FXDC& dc,FXint x,FXint y,FXint w,
     }
 
   // Offset a bit when pressed
-//  if(state&PRESSED){ tx++; ty++; ix++; iy++; }
+  if(state&PRESSED){ tx++; ty++; ix++; iy++; }
 
   // Paint icon
   if(icon){
@@ -231,56 +234,56 @@ void FXHeaderItem::setIconPosition(FXuint mode){
   }
 
 
+// Set button state
+void FXHeaderItem::setPressed(FXbool pressed){
+  if(pressed) state|=PRESSED; else state&=~PRESSED;
+  }
+
+
 // Get width of item
 FXint FXHeaderItem::getWidth(const FXHeader* header) const {
+  register FXint ml=header->getPadLeft()+header->getBorderWidth();
+  register FXint mr=header->getPadRight()+header->getBorderWidth();
   register FXFont *font=header->getFont();
-  register FXint beg,end,tw,iw,s,t,ml,mr,w;
-  if(header->getHeaderStyle()&HEADER_VERTICAL){
-    ml=header->getPadLeft()+header->getBorderWidth();
-    mr=header->getPadRight()+header->getBorderWidth();
-    tw=iw=beg=s=0;
-    if(icon) iw=icon->getWidth();
-    do{
-      end=beg;
-      while(end<label.length() && label[end]!='\n') end++;
-      if((t=font->getTextWidth(&label[beg],end-beg))>tw) tw=t;
-      beg=end+1;
-      }
-    while(end<label.length());
-    if(iw && tw) s=4;
-    if(state&(BEFORE|AFTER))
-      w=iw+tw+s;
-    else
-      w=FXMAX(iw,tw);
-    return ml+mr+w;
+  register FXint beg,end,tw,iw,s,t,w;
+  tw=iw=beg=s=0;
+  if(icon) iw=icon->getWidth();
+  do{
+    end=beg;
+    while(end<label.length() && label[end]!='\n') end++;
+    if((t=font->getTextWidth(&label[beg],end-beg))>tw) tw=t;
+    beg=end+1;
     }
-  return size;
+  while(end<label.length());
+  if(iw && tw) s=4;
+  if(state&(BEFORE|AFTER))
+    w=iw+tw+s;
+  else
+    w=FXMAX(iw,tw);
+  return ml+mr+w;
   }
 
 
 // Get height of item
 FXint FXHeaderItem::getHeight(const FXHeader* header) const {
+  register FXint mt=header->getPadTop()+header->getBorderWidth();
+  register FXint mb=header->getPadBottom()+header->getBorderWidth();
   register FXFont *font=header->getFont();
-  register FXint beg,end,th,ih,h,mt,mb;
-  if(!(header->getHeaderStyle()&HEADER_VERTICAL)){
-    mt=header->getPadTop()+header->getBorderWidth();
-    mb=header->getPadBottom()+header->getBorderWidth();
-    th=ih=beg=0;
-    if(icon) ih=icon->getHeight();
-    do{
-      end=beg;
-      while(end<label.length() && label[end]!='\n') end++;
-      th+=font->getFontHeight();
-      beg=end+1;
-      }
-    while(end<label.length());
-    if(state&(ABOVE|BELOW))
-      h=ih+th;
-    else
-      h=FXMAX(ih,th);
-    return h+mt+mb;
+  register FXint beg,end,th,ih,h;
+  th=ih=beg=0;
+  if(icon) ih=icon->getHeight();
+  do{
+    end=beg;
+    while(end<label.length() && label[end]!='\n') end++;
+    th+=font->getFontHeight();
+    beg=end+1;
     }
-  return size;
+  while(end<label.length());
+  if(state&(ABOVE|BELOW))
+    h=ih+th;
+  else
+    h=FXMAX(ih,th);
+  return h+mt+mb;
   }
 
 
@@ -331,12 +334,12 @@ FXHeader::FXHeader(){
   items=NULL;
   nitems=0;
   textColor=0;
-  state=FALSE;
-  font=(FXFont*)-1L;
+  font=NULL;
+  pos=0;
   active=-1;
   activepos=0;
   activesize=0;
-  activeoffset=0;
+  offset=0;
   }
 
 
@@ -350,11 +353,11 @@ FXHeader::FXHeader(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
   nitems=0;
   textColor=getApp()->getForeColor();
   font=getApp()->getNormalFont();
-  state=FALSE;
+  pos=0;
   active=-1;
   activepos=0;
   activesize=0;
-  activeoffset=0;
+  offset=0;
   }
 
 
@@ -362,10 +365,8 @@ FXHeader::FXHeader(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint
 void FXHeader::create(){
   register FXint i;
   FXFrame::create();
+  for(i=0; i<nitems; i++){items[i]->create();}
   font->create();
-  for(i=0; i<nitems; i++){
-    if(items[i]->getIcon()){ items[i]->getIcon()->create(); }
-    }
   }
 
 
@@ -373,21 +374,23 @@ void FXHeader::create(){
 void FXHeader::detach(){
   register FXint i;
   FXFrame::detach();
+  for(i=0; i<nitems; i++){items[i]->detach();}
   font->detach();
-  for(i=0; i<nitems; i++){
-    if(items[i]->getIcon()){ items[i]->getIcon()->detach(); }
-    }
   }
 
 
 // Get default width
 FXint FXHeader::getDefaultWidth(){
-  register FXint w,i,t;
+  register FXint i,t,w=0;
   if(options&HEADER_VERTICAL){
-    for(i=0,w=0; i<nitems; i++){if((t=items[i]->getWidth(this))>w) w=t;}
+    for(i=0; i<nitems; i++){
+      if((t=items[i]->getWidth(this))>w) w=t;
+      }
     }
   else{
-    for(i=0,w=0; i<nitems; i++){w+=items[i]->getWidth(this);}
+    for(i=0; i<nitems; i++){
+      w+=items[i]->getSize();
+      }
     }
   return w;
   }
@@ -395,17 +398,28 @@ FXint FXHeader::getDefaultWidth(){
 
 // Get default height
 FXint FXHeader::getDefaultHeight(){
-  register FXint h,i,t;
+  register FXint i,t,h=0;
   if(options&HEADER_VERTICAL){
-    for(i=0,h=0; i<nitems; i++){h+=items[i]->getHeight(this);}
+    for(i=0; i<nitems; i++){
+      h+=items[i]->getSize();
+      }
     }
   else{
-    for(i=0,h=0; i<nitems; i++){if((t=items[i]->getHeight(this))>h) h=t;}
+    for(i=0; i<nitems; i++){
+      if((t=items[i]->getHeight(this))>h) h=t;
+      }
     }
   return h;
   }
 
 
+
+// Return total size
+FXint FXHeader::getTotalSize() const {
+  return nitems ? items[nitems-1]->getPos()+items[nitems-1]->getSize()-items[0]->getPos() : 0;
+  }
+
+
 // Create custom item
 FXHeaderItem *FXHeader::createItem(const FXString& text,FXIcon* icon,FXint size,void* ptr){
   return new FXHeaderItem(text,icon,size,ptr);
@@ -614,20 +628,21 @@ FXint FXHeader::getItemSize(FXint index) const {
 // Get item's offset
 FXint FXHeader::getItemOffset(FXint index) const {
   if(index<0 || nitems<=index){ fxerror("%s::getItemOffset: index out of range.\n",getClassName()); }
-  return items[index]->getPos();
+  return pos+items[index]->getPos();
   }
 
 
 // Get index of item at offset
-FXint FXHeader::getItemAt(FXint offset) const {
+FXint FXHeader::getItemAt(FXint coord) const {
   register FXint h=nitems-1,l=0,m;
   if(l<=h){
-    if(offset<items[l]->getPos()) return -1;
-    if(offset>items[h]->getPos()+items[h]->getSize()) return nitems;
+    coord=coord-pos;
+    if(coord<items[l]->getPos()) return -1;
+    if(coord>=items[h]->getPos()+items[h]->getSize()) return nitems;
     do{
       m=(h+l)>>1;
-      if(offset<items[m]->getPos()) h=m-1;
-      else if(items[m]->getPos()+items[m]->getSize()<=offset) l=m+1;
+      if(coord<items[m]->getPos()) h=m-1;
+      else if(coord>=items[m]->getPos()+items[m]->getSize()) l=m+1;
       else break;
       }
     while(h>=l);
@@ -656,7 +671,7 @@ void FXHeader::setArrowDir(FXint index,FXbool dir){
   if(index<0 || nitems<=index){ fxerror("%s::setArrowDir: index out of range.\n",getClassName()); }
   if(items[index]->getArrowDir()!=dir){
     items[index]->setArrowDir(dir);
-    update();
+    updateItem(index);
     }
   }
 
@@ -673,7 +688,7 @@ void FXHeader::setItemJustify(FXint index,FXuint justify){
   if(index<0 || nitems<=index){ fxerror("%s::setItemJustify: index out of range.\n",getClassName()); }
   if(items[index]->getJustify()!=justify){
     items[index]->setJustify(justify);
-    update();
+    updateItem(index);
     }
   }
 
@@ -690,7 +705,7 @@ void FXHeader::setItemIconPosition(FXint index,FXuint mode){
   if(index<0 || nitems<=index){ fxerror("%s::setItemIconPosition: index out of range.\n",getClassName()); }
   if(items[index]->getIconPosition()!=mode){
     items[index]->setIconPosition(mode);
-    update();
+    recalc();
     }
   }
 
@@ -702,6 +717,51 @@ FXuint FXHeader::getItemIconPosition(FXint index) const {
   }
 
 
+// Changed button item's pressed state
+void FXHeader::setItemPressed(FXint index,FXbool pressed){
+  if(index<0 || nitems<=index){ fxerror("%s::setItemPressed: index out of range.\n",getClassName()); }
+  if(pressed!=items[index]->isPressed()){
+    items[index]->setPressed(pressed);
+    updateItem(index);
+    }
+  }
+
+
+// Return TRUE if button item is pressed in
+FXbool FXHeader::isItemPressed(FXint index) const {
+  if(index<0 || nitems<=index){ fxerror("%s::isItemPressed: index out of range.\n",getClassName()); }
+  return items[index]->isPressed();
+  }
+
+
+// Scroll to make given item visible
+void FXHeader::makeItemVisible(FXint index){
+  register FXint newpos,ioffset,isize,space;
+  if(xid){
+    newpos=pos;
+    if(0<=index && index<nitems){
+      space=(options&HEADER_VERTICAL)?height:width;
+      ioffset=items[index]->getPos();
+      isize=items[index]->getSize();
+      newpos=pos;
+      if(newpos+ioffset+isize>=space) newpos=space-ioffset-isize;
+      if(newpos+ioffset<=0) newpos=-ioffset;
+      }
+    setPosition(newpos);
+    }
+  }
+
+
+// Repaint cell at index
+void FXHeader::updateItem(FXint index) const {
+  if(index<0 || nitems<=index){ fxerror("%s::updateItem: index out of range.\n",getClassName()); }
+  if(options&HEADER_VERTICAL)
+    update(0,pos+items[index]->getPos(),width,items[index]->getSize());
+  else
+    update(pos+items[index]->getPos(),0,items[index]->getSize(),height);
+  }
+
+
 // Do layout
 void FXHeader::layout(){
 
@@ -733,35 +793,43 @@ long FXHeader::onPaint(FXObject*,FXSelector,void* ptr){
 
       // Fragment below first item
       if(ilo<0){
-        y=items[0]->getPos();
+        y=pos+items[0]->getPos();
         if(0<y){
-          if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,0,width,y);
-          else drawRaisedRectangle(dc,0,0,width,y);
+          if(options&FRAME_THICK)
+            drawDoubleRaisedRectangle(dc,0,0,width,y);
+          else
+            drawRaisedRectangle(dc,0,0,width,y);
           }
         ilo=0;
         }
 
       // Fragment above last item
       if(ihi>=nitems){
-        y=items[nitems-1]->getPos()+items[nitems-1]->getSize();
+        y=pos+items[nitems-1]->getPos()+items[nitems-1]->getSize();
         if(y<height){
-          if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,y,width,height-y);
-          else drawRaisedRectangle(dc,0,y,width,height-y);
+          if(options&FRAME_THICK)
+            drawDoubleRaisedRectangle(dc,0,y,width,height-y);
+          else
+            drawRaisedRectangle(dc,0,y,width,height-y);
           }
         ihi=nitems-1;
         }
 
       // Draw only affected items
       for(i=ilo; i<=ihi; i++){
-        y=items[i]->getPos();
+        y=pos+items[i]->getPos();
         h=items[i]->getSize();
-        if(i==active && state){
-          if(options&FRAME_THICK) drawDoubleSunkenRectangle(dc,0,y,width,h);
-          else drawSunkenRectangle(dc,0,y,width,h);
+        if(items[i]->isPressed()){
+          if(options&FRAME_THICK)
+            drawDoubleSunkenRectangle(dc,0,y,width,h);
+          else
+            drawSunkenRectangle(dc,0,y,width,h);
           }
         else{
-          if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,y,width,h);
-          else drawRaisedRectangle(dc,0,y,width,h);
+          if(options&FRAME_THICK)
+            drawDoubleRaisedRectangle(dc,0,y,width,h);
+          else
+            drawRaisedRectangle(dc,0,y,width,h);
           }
         items[i]->draw(this,dc,0,y,width,h);
         }
@@ -774,35 +842,43 @@ long FXHeader::onPaint(FXObject*,FXSelector,void* ptr){
 
       // Fragment below first item
       if(ilo<0){
-        x=items[0]->getPos();
+        x=pos+items[0]->getPos();
         if(0<x){
-          if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,0,x,height);
-          else drawRaisedRectangle(dc,0,0,x,height);
+          if(options&FRAME_THICK)
+            drawDoubleRaisedRectangle(dc,0,0,x,height);
+          else
+            drawRaisedRectangle(dc,0,0,x,height);
           }
         ilo=0;
         }
 
       // Fragment above last item
       if(ihi>=nitems){
-        x=items[nitems-1]->getPos()+items[nitems-1]->getSize();
+        x=pos+items[nitems-1]->getPos()+items[nitems-1]->getSize();
         if(x<width){
-          if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,x,0,width-x,height);
-          else drawRaisedRectangle(dc,x,0,width-x,height);
+          if(options&FRAME_THICK)
+            drawDoubleRaisedRectangle(dc,x,0,width-x,height);
+          else
+            drawRaisedRectangle(dc,x,0,width-x,height);
           }
         ihi=nitems-1;
         }
 
       // Draw only the affected items
       for(i=ilo; i<=ihi; i++){
-        x=items[i]->getPos();
+        x=pos+items[i]->getPos();
         w=items[i]->getSize();
-        if(i==active && state){
-          if(options&FRAME_THICK) drawDoubleSunkenRectangle(dc,x,0,w,height);
-          else drawSunkenRectangle(dc,x,0,w,height);
+        if(items[i]->isPressed()){
+          if(options&FRAME_THICK)
+            drawDoubleSunkenRectangle(dc,x,0,w,height);
+          else
+            drawSunkenRectangle(dc,x,0,w,height);
           }
         else{
-          if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,x,0,w,height);
-          else drawRaisedRectangle(dc,x,0,w,height);
+          if(options&FRAME_THICK)
+            drawDoubleRaisedRectangle(dc,x,0,w,height);
+          else
+            drawRaisedRectangle(dc,x,0,w,height);
           }
         items[i]->draw(this,dc,x,0,w,height);
         }
@@ -850,68 +926,40 @@ long FXHeader::onTipTimer(FXObject*,FXSelector,void*){
 
 // Button being pressed
 long FXHeader::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
-  FXEvent* ev=(FXEvent*)ptr;
+  FXEvent* event=(FXEvent*)ptr;
+  FXint coord;
   flags&=~FLAG_TIP;
   handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr);
   if(isEnabled()){
     grab();
+
+    // First change callback
     if(target && target->handle(this,FXSEL(SEL_LEFTBUTTONPRESS,message),ptr)) return 1;
 
-    // Vertically oriented
-    if(options&HEADER_VERTICAL){
-      active=getItemAt(ev->win_y);
-      if(0<=active){
-        if(active<nitems && items[active]->getPos()+items[active]->getSize()-FUDGE<ev->win_y){
-          activepos=items[active]->getPos();
-          activesize=items[active]->getSize();
-          activeoffset=ev->win_y-activepos-activesize;
-          setDragCursor(getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR));
-          flags|=FLAG_PRESSED|FLAG_TRYDRAG;
-          }
-        else if(0<active && ev->win_y<items[active-1]->getPos()+items[active-1]->getSize()+FUDGE){
-          active--;
-          activepos=items[active]->getPos();
-          activesize=items[active]->getSize();
-          activeoffset=ev->win_y-activepos-activesize;
-          setDragCursor(getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR));
-          flags|=FLAG_PRESSED|FLAG_TRYDRAG;
-          }
-        else if(active<nitems){
-          activepos=items[active]->getPos();
-          activesize=items[active]->getSize();
-          state=TRUE;
-          update(0,activepos,width,activesize);
-          flags|=FLAG_PRESSED;
-          }
+    // Where clicked
+    coord=(options&HEADER_VERTICAL)?event->win_y:event->win_x;
+    active=getItemAt(coord);
+    if(0<=active){
+      if(active<nitems && pos+items[active]->getPos()+items[active]->getSize()-FUDGE<coord){
+        activepos=pos+items[active]->getPos();
+        activesize=items[active]->getSize();
+        offset=coord-activepos-activesize;
+        setDragCursor((options&HEADER_VERTICAL)?getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR):getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR));
+        flags|=FLAG_PRESSED|FLAG_TRYDRAG;
         }
-      }
-
-    // Horizontally oriented
-    else{
-      active=getItemAt(ev->win_x);
-      if(0<=active){
-        if(active<nitems && items[active]->getPos()+items[active]->getSize()-FUDGE<ev->win_x){
-          activepos=items[active]->getPos();
-          activesize=items[active]->getSize();
-          activeoffset=ev->win_x-activepos-activesize;
-          setDragCursor(getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR));
-          flags|=FLAG_PRESSED|FLAG_TRYDRAG;
-          }
-        else if(0<active && ev->win_x<items[active-1]->getPos()+items[active-1]->getSize()+FUDGE){
-          active--;
-          activepos=items[active]->getPos();
-          activesize=items[active]->getSize();
-          activeoffset=ev->win_x-activepos-activesize;
-          setDragCursor(getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR));
-          flags|=FLAG_PRESSED|FLAG_TRYDRAG;
-          }
-        else if(active<nitems){
-          activepos=items[active]->getPos();
-          activesize=items[active]->getSize();
-          state=TRUE;
-          update(activepos,0,activesize,height);
-          flags|=FLAG_PRESSED;
-          }
+      else if(0<active && coord<pos+items[active-1]->getPos()+items[active-1]->getSize()+FUDGE){
+        active--;
+        activepos=pos+items[active]->getPos();
+        activesize=items[active]->getSize();
+        offset=coord-activepos-activesize;
+        setDragCursor((options&HEADER_VERTICAL)?getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR):getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR));
+        flags|=FLAG_PRESSED|FLAG_TRYDRAG;
+        }
+      else if(active<nitems){
+        activepos=pos+items[active]->getPos();
+        activesize=items[active]->getSize();
+        setItemPressed(active,TRUE);
+        flags|=FLAG_PRESSED;
         }
       }
     flags&=~FLAG_UPDATE;
@@ -923,35 +971,42 @@ long FXHeader::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
 
 // Button being released
 long FXHeader::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
-  FXEvent* ev=(FXEvent*)ptr;
   FXuint flg=flags;
   if(isEnabled()){
     ungrab();
     flags|=FLAG_UPDATE;
     flags&=~(FLAG_PRESSED|FLAG_DODRAG|FLAG_TRYDRAG);
+
+    // First chance callback
     if(target && target->handle(this,FXSEL(SEL_LEFTBUTTONRELEASE,message),ptr)) return 1;
+
+    // Set cursor back
     setDragCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
-    if(!ev->moved && (flg&FLAG_TRYDRAG)){
+
+    // Clicked on split
+    if(flg&FLAG_TRYDRAG){
       if(target) target->handle(this,FXSEL(SEL_CLICKED,message),(void*)(FXival)active);
+      return 1;
       }
-    else if(flg&FLAG_DODRAG){
+
+    // Dragged split
+    if(flg&FLAG_DODRAG){
       if(!(options&HEADER_TRACKING)){
         drawSplit(activepos+activesize);
         setItemSize(active,activesize);
         if(target) target->handle(this,FXSEL(SEL_CHANGED,message),(void*)(FXival)active);
         }
+      return 1;
       }
-    else{
-      if(state){
-        state=FALSE;
-        if(options&HEADER_VERTICAL)
-          update(0,activepos,width,activesize);
-        else
-          update(activepos,0,activesize,height);
+
+    // Pressed button
+    if(flg&FLAG_PRESSED){
+      if(items[active]->isPressed()){
+        setItemPressed(active,FALSE);
         if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)active);
         }
+      return 1;
       }
-    return 1;
     }
   return 0;
   }
@@ -959,7 +1014,7 @@ long FXHeader::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
 
 // Button being moved
 long FXHeader::onMotion(FXObject*,FXSelector,void* ptr){
-  FXEvent* ev=(FXEvent*)ptr;
+  FXEvent* event=(FXEvent*)ptr;
   FXint oldsplit,newsplit,index;
   FXuint flg=flags;
 
@@ -969,97 +1024,80 @@ long FXHeader::onMotion(FXObject*,FXSelector,void* ptr){
   // Kill the tip timer
   getApp()->removeTimeout(this,ID_TIPTIMER);
 
+  // Tentatively dragging split
+  if(flags&FLAG_TRYDRAG){
+    if(!(options&HEADER_TRACKING)) drawSplit(activepos+activesize);
+    flags&=~FLAG_TRYDRAG;
+    flags|=FLAG_DODRAG;
+    return 1;
+    }
+
+  // Dragging split
+  if(flags&FLAG_DODRAG){
+    oldsplit=activepos+activesize;
+    if(options&HEADER_VERTICAL)
+      activesize=event->win_y-offset-activepos;
+    else
+      activesize=event->win_x-offset-activepos;
+    if(activesize<0) activesize=0;
+    newsplit=activepos+activesize;
+    if(newsplit!=oldsplit){
+      if(!(options&HEADER_TRACKING)){
+        drawSplit(oldsplit);
+        drawSplit(newsplit);
+        }
+      else{
+        setItemSize(active,activesize);
+        if(target) target->handle(this,FXSEL(SEL_CHANGED,message),(void*)(FXival)active);
+        }
+      }
+    return 1;
+    }
+
   // Had the button pressed
   if(flags&FLAG_PRESSED){
-
-    // Dragging
-    if(flags&FLAG_TRYDRAG){
-      if(!(options&HEADER_TRACKING)) drawSplit(activepos+activesize);
-      flags&=~FLAG_TRYDRAG;
-      flags|=FLAG_DODRAG;
-      }
-
-    // We were dragging a split
-    else if(flags&FLAG_DODRAG){
-      oldsplit=activepos+activesize;
-      if(options&HEADER_VERTICAL)
-        activesize=ev->win_y-activeoffset-activepos;
-      else
-        activesize=ev->win_x-activeoffset-activepos;
-      if(activesize<0) activesize=0;
-      newsplit=activepos+activesize;
-      if(newsplit!=oldsplit){
-        if(!(options&HEADER_TRACKING)){
-          drawSplit(oldsplit);
-          drawSplit(newsplit);
-          }
-        else{
-          setItemSize(active,activesize);
-          if(target) target->handle(this,FXSEL(SEL_CHANGED,message),(void*)(FXival)active);
-          }
-        }
-      }
-
-    // We pressed the button
-    else{
-      if(options&HEADER_VERTICAL){
-        if(activepos<=ev->win_y && ev->win_y<activepos+activesize && 0<=ev->win_x && ev->win_x<width){
-          if(!state){
-            state=TRUE;
-            update(0,activepos,width,activesize);
-            }
-          }
-        else{
-          if(state){
-            state=FALSE;
-            update(0,activepos,width,activesize);
-            }
-          }
-        }
-      else{
-        if(activepos<=ev->win_x && ev->win_x<activepos+activesize && 0<=ev->win_y && ev->win_y<height){
-          if(!state){
-            state=TRUE;
-            update(activepos,0,activesize,height);
-            }
-          }
-        else{
-          if(state){
-            state=FALSE;
-            update(activepos,0,activesize,height);
-            }
-          }
-        }
-      }
-    }
-
-  // Just hovering over the widget
-  else{
-
-    // When hovering over a split, show the split cursor
     if(options&HEADER_VERTICAL){
-      index=getItemAt(ev->win_y-FUDGE);
-      if(0<=index && index<nitems && items[index]->getPos()+items[index]->getSize()-FUDGE<ev->win_y){
-        setDefaultCursor(getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR));
+      if(activepos<=event->win_y && event->win_y<activepos+activesize && 0<=event->win_x && event->win_x<width){
+        setItemPressed(active,TRUE);
         }
       else{
-        setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+        setItemPressed(active,FALSE);
         }
       }
     else{
-      index=getItemAt(ev->win_x-FUDGE);
-      if(0<=index && index<nitems && items[index]->getPos()+items[index]->getSize()-FUDGE<ev->win_x){
-        setDefaultCursor(getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR));
+      if(activepos<=event->win_x && event->win_x<activepos+activesize && 0<=event->win_y && event->win_y<height){
+        setItemPressed(active,TRUE);
         }
       else{
-        setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+        setItemPressed(active,FALSE);
         }
       }
-
-    // Reset tip timer if nothing's going on
-    getApp()->addTimeout(this,ID_TIPTIMER,getApp()->getMenuPause());
+    return 1;
     }
 
+  // When hovering over a split, show the split cursor
+  if(options&HEADER_VERTICAL){
+    index=getItemAt(event->win_y-FUDGE);
+    if(0<=index && index<nitems && pos+items[index]->getPos()+items[index]->getSize()-FUDGE<event->win_y){
+      setDefaultCursor(getApp()->getDefaultCursor(DEF_VSPLIT_CURSOR));
+      }
+    else{
+      setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+      }
+    }
+  else{
+    index=getItemAt(event->win_x-FUDGE);
+    if(0<=index && index<nitems && pos+items[index]->getPos()+items[index]->getSize()-FUDGE<event->win_x){
+      setDefaultCursor(getApp()->getDefaultCursor(DEF_HSPLIT_CURSOR));
+      }
+    else{
+      setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
+      }
+    }
+
+  // Reset tip timer if nothing's going on
+  getApp()->addTimeout(this,ID_TIPTIMER,getApp()->getMenuPause());
+
   // Force GUI update only when needed
   return (flg&FLAG_TIP);
   }
@@ -1091,6 +1129,18 @@ void FXHeader::drawSplit(FXint pos){
   }
 
 
+// Set position, scrolling contents
+void FXHeader::setPosition(FXint p){
+  if(pos!=p){
+    if(options&HEADER_VERTICAL)
+      scroll(0,0,width,height,0,p-pos);
+    else
+      scroll(0,0,width,height,p-pos,0);
+    pos=p;
+    }
+  }
+
+
 // Change the font
 void FXHeader::setFont(FXFont* fnt){
   if(!fnt){ fxerror("%s::setFont: NULL font specified.\n",getClassName()); }
@@ -1139,10 +1189,11 @@ void FXHeader::save(FXStream& store) const {
   register FXint i;
   FXFrame::save(store);
   store << nitems;
-  for(i=0; i<nitems; i++){store<<items[i];}
+  for(i=0; i<nitems; i++){ store << items[i]; }
   store << textColor;
   store << font;
   store << help;
+  store << pos;
   }
 
 
@@ -1153,10 +1204,11 @@ void FXHeader::load(FXStream& store){
   FXFrame::load(store);
   store >> nitems;
   FXRESIZE(&items,FXHeaderItem*,nitems);
-  for(i=0; i<nitems; i++){store>>items[i];}
+  for(i=0; i<nitems; i++){ store >> items[i]; }
   store >> textColor;
   store >> font;
   store >> help;
+  store >> pos;
   }
 
 
