@@ -3,7 +3,7 @@
 *                        I C O   I c o n   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2003 by Janusz Ganczarski.   All Rights Reserved.          *
+* Copyright (C) 2001,2004 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXICOIcon.cpp,v 1.15 2003/10/23 04:19:45 fox Exp $                       *
+* $Id: FXICOIcon.cpp,v 1.17 2004/02/08 17:29:06 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -64,15 +64,16 @@ FXICOIcon::FXICOIcon(FXApp* a,const void *pix,FXColor clr,FXuint opts,FXint w,FX
 
 // Save object to stream
 FXbool FXICOIcon::savePixels(FXStream& store) const {
-  if(!fxsaveICO(store,data,width,height)) return FALSE;
+  if(!fxsaveICO(store,data,width,height,0,0)) return FALSE;
   return TRUE;
   }
 
 
 // Load object from stream
 FXbool FXICOIcon::loadPixels(FXStream& store){
+  FXint hotx,hoty;
   if(options&IMAGE_OWNED){FXFREE(&data);}
-  if(!fxloadICO(store,data,width,height)) return FALSE;
+  if(!fxloadICO(store,data,width,height,hotx,hoty)) return FALSE;
   if(options&IMAGE_ALPHAGUESS) transp=guesstransp();
   options|=IMAGE_OWNED;
   return TRUE;
