@@ -3,7 +3,7 @@
 *                               I c o n - O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXIcon.cpp,v 1.59 2003/10/23 04:19:45 fox Exp $                          *
+* $Id: FXIcon.cpp,v 1.62.2.1 2004/08/28 01:10:02 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -203,7 +203,7 @@ void FXIcon::render(){
     register FXint x,y;
     XGCValues values;
     GC gc;
-#ifdef HAVE_XSHM
+#ifdef HAVE_XSHM_H
     XShmSegmentInfo shminfo;
 #endif
 
@@ -219,12 +219,12 @@ void FXIcon::render(){
       vis=(Visual*)visual->visual;
 
       // Turn it on iff both supported and desired
-#ifdef HAVE_XSHM
+#ifdef HAVE_XSHM_H
       if(options&IMAGE_SHMI) shmi=getApp()->shmi;
 #endif
 
       // First try XShm
-#ifdef HAVE_XSHM
+#ifdef HAVE_XSHM_H
       if(shmi){
         xim=XShmCreateImage(DISPLAY(getApp()),vis,1,ZPixmap,NULL,&shminfo,width,height);
         if(!xim){ shmi=0; }
@@ -273,7 +273,7 @@ void FXIcon::render(){
       FXTRACE((150,"bm bits_per_pixel = %d\n",xim->bits_per_pixel));
 
       // Fill shape mask
-      if(options&IMAGE_OPAQUE){                 // Opaque image
+      if(options&IMAGE_OPAQUE){                                 // Opaque image
         FXTRACE((150,"Shape rectangle\n"));
         memset(xim->data,0xff,xim->bytes_per_line*height);
         }
@@ -287,7 +287,7 @@ void FXIcon::render(){
           img+=width;
           }
         }
-      else{                                     // Transparency channel
+      else{                                                     // Transparency channel
         FXTRACE((150,"Shape from alpha-channel\n"));
         img=data;
         for(y=0; y<height; y++){
@@ -299,7 +299,7 @@ void FXIcon::render(){
         }
 
       // Transfer image
-#ifdef HAVE_XSHM
+#ifdef HAVE_XSHM_H
       if(shmi){
         XShmPutImage(DISPLAY(getApp()),shape,gc,xim,0,0,0,0,width,height,False);
         XSync(DISPLAY(getApp()),False);
@@ -310,7 +310,7 @@ void FXIcon::render(){
         }
 
       // Fill etch image
-      if(options&IMAGE_OPAQUE){                 // Opaque image
+      if(options&IMAGE_OPAQUE){                                 // Opaque image
         img=data;
         for(y=0; y<height; y++){
           for(x=0; x<width; x++){
@@ -328,7 +328,7 @@ void FXIcon::render(){
           img+=width;
           }
         }
-      else{                                     // Transparency channel
+      else{                                                     // Transparency channel
         img=data;
         for(y=0; y<height; y++){
           for(x=0; x<width; x++){
@@ -339,7 +339,7 @@ void FXIcon::render(){
         }
 
       // Transfer image
-#ifdef HAVE_XSHM
+#ifdef HAVE_XSHM_H
       if(shmi){
         XShmPutImage(DISPLAY(getApp()),etch,gc,xim,0,0,0,0,width,height,False);
         XSync(DISPLAY(getApp()),False);
@@ -350,7 +350,7 @@ void FXIcon::render(){
         }
 
       // Clean up
-#ifdef HAVE_XSHM
+#ifdef HAVE_XSHM_H
       if(shmi){
         FXTRACE((150,"Bitmap XSHM detached at memory=%p (%d bytes)\n",xim->data,xim->bytes_per_line*xim->height));
         XShmDetach(DISPLAY(getApp()),&shminfo);
@@ -382,10 +382,11 @@ struct BITMAPINFO2 {
 // Render Icon MS-Windows
 void FXIcon::render(){
   if(xid){
-    register FXuchar *maskdata,*etchdata,*msk,*ets;
+    register FXint bytes_per_line,x,y;
+    register FXuchar *msk,*ets;
     register FXColor *img;
-    register FXint x,y;
-    register FXuint bytes_per_line;
+    FXuchar *maskdata;
+    FXuchar *etchdata;
     BITMAPINFO2 bmi;
     HDC hdcmsk;
 
