@@ -3,7 +3,7 @@
 *                          I c o n L i s t   O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXIconList.cpp,v 1.158 2003/10/23 04:19:45 fox Exp $                     *
+* $Id: FXIconList.cpp,v 1.164 2004/02/08 17:29:06 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -69,6 +69,8 @@
   - When XDND, autoscrolling happens a bit too fast because we get timers
     from motion as well as dnd-motion events; probably, it should not
     autoscroll when dragging icons.
+  - Perhaps drawDetails() should ignore x coordinate and just look at getItemOffest()
+    from the header instead.
 */
 
 
@@ -212,23 +214,23 @@ void FXIconItem::drawMiniIcon(const FXIconList* list,FXDC& dc,FXint x,FXint y,FX
 void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h) const {
   register FXHeader *header=list->getHeader();
   register FXFont *font=list->getFont();
-  register FXint iw=0,ih=0,tw=0,th=0,yt,beg,end,hi,drw,space,used,dw;
+  register FXint iw=0,ih=0,tw=0,th=0,yt,beg,end,hi,drw,space,used,dw,xx;
   if(header->getNumItems()==0) return;
   if(isSelected()){
     dc.setForeground(list->getSelBackColor());
-    dc.fillRectangle(x,y,header->getWidth(),h);
+    dc.fillRectangle(x,y,header->getTotalSize(),h);
     }
   if(hasFocus()){
-    dc.drawFocusRectangle(x+1,y+1,header->getWidth()-2,h-2);
+    dc.drawFocusRectangle(x+1,y+1,header->getTotalSize()-2,h-2);
     }
-  x+=SIDE_SPACING/2;
+  xx=x+SIDE_SPACING/2;
   if(miniIcon){
     iw=miniIcon->getWidth();
     ih=miniIcon->getHeight();
-    dc.setClipRectangle(header->getX(),y,header->getItemSize(0),h);
-    dc.drawIcon(miniIcon,x,y+(h-ih)/2);
+    dc.setClipRectangle(x,y,header->getItemSize(0),h);
+    dc.drawIcon(miniIcon,xx,y+(h-ih)/2);
     dc.clearClipRectangle();
-    x+=iw+DETAIL_TEXT_SPACING;
+    xx+=iw+DETAIL_TEXT_SPACING;
     }
   if(!label.empty()){
     th=font->getFontHeight();
@@ -249,16 +251,16 @@ void FXIconItem::drawDetails(const FXIconList* list,FXDC& dc,FXint x,FXint y,FXi
         tw=font->getTextWidth(&label[beg],drw);
         if(tw>space-4){
           while((tw=font->getTextWidth(&label[beg],drw))+dw>space-4 && drw>1) drw--;
-          dc.setClipRectangle(x,y,space,h);
-          dc.drawText(x+2,yt+font->getFontAscent()+2,&label[beg],drw);
-          dc.drawText(x+tw+2,yt+font->getFontAscent()+2,"...",3);
+          dc.setClipRectangle(xx,y,space,h);
+          dc.drawText(xx+2,yt+font->getFontAscent()+2,&label[beg],drw);
+          dc.drawText(xx+tw+2,yt+font->getFontAscent()+2,"...",3);
           dc.clearClipRectangle();
           }
         else{
-          dc.drawText(x+2,yt+font->getFontAscent()+2,&label[beg],drw);
+          dc.drawText(xx+2,yt+font->getFontAscent()+2,&label[beg],drw);
           }
         }
-      x+=space;
+      xx+=space;
       used=0;
       }
     }
@@ -623,7 +625,7 @@ void FXIconList::moveContents(FXint x,FXint y){
   pos_y=y;
   if(!(options&(ICONLIST_MINI_ICONS|ICONLIST_BIG_ICONS))){
     top=header->getDefaultHeight();
-    header->move(x,0);
+    header->setPosition(x);
     }
   scroll(0,top,viewport_w,viewport_h,dx,dy);
   }
@@ -724,19 +726,13 @@ FXint FXIconList::getContentHeight(){
 
 // Recalculate layout
 void FXIconList::layout(){
-  FXint ww;
-
-  // Repaint when content size changed
-  //if(flags&FLAG_RECALC) update();
 
   // Update scroll bars
   FXScrollArea::layout();
 
   // In detail mode
   if(!(options&(ICONLIST_MINI_ICONS|ICONLIST_BIG_ICONS))){
-    ww=header->getDefaultWidth();
-    if(ww<viewport_w) ww=viewport_w;
-    header->position(pos_x,0,ww,header->getDefaultHeight());
+    header->position(0,0,viewport_w,header->getDefaultHeight());
     header->show();
     }
   else{
@@ -1027,8 +1023,7 @@ FXbool FXIconList::isItemVisible(FXint index) const {
 // Make item fully visible
 void FXIconList::makeItemVisible(FXint index){
   register FXint x,y,hh,px,py;
-  if(xid==0) return;
-  if(0<=index && index<nitems){
+  if(xid && 0<=index && index<nitems){
     px=pos_x;
     py=pos_y;
     if(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS)){
@@ -1563,6 +1558,8 @@ long FXIconList::onPaint(FXObject*,FXSelector,void* ptr){
 
   // Set font
   dc.setFont(font);
+//dc.setForeground(FXRGB(255,0,0));
+//dc.fillRectangle(0,0,width,height);
 
   // Icon mode
   if(options&(ICONLIST_BIG_ICONS|ICONLIST_MINI_ICONS)){
