@@ -3,7 +3,7 @@
 *                      J P E G   I m a g e   O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2003 by David Tyree.   All Rights Reserved.                *
+* Copyright (C) 2000,2004 by David Tyree.   All Rights Reserved.                *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXJPGImage.cpp,v 1.16 2003/10/23 04:19:45 fox Exp $                      *
+* $Id: FXJPGImage.cpp,v 1.18 2004/02/08 17:29:06 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -72,17 +72,10 @@ FXbool FXJPGImage::savePixels(FXStream& store) const {
   return TRUE;
   }
 
-/*
-extern FXlong fxgetticks();
-static FXlong __starttick__,__endtick__;
-__starttick__=fxgetticks();
-__endtick__ =fxgetticks();
-fprintf(stderr,"ticks=%lld\n",__endtick__-__starttick__);
-*/
 
 // Load pixels only
 FXbool FXJPGImage::loadPixels(FXStream& store){
-  if(options&IMAGE_OWNED){ FXFREE(&data); }
+  if(options&IMAGE_OWNED){FXFREE(&data);}
   if(!fxloadJPG(store,data,width,height,quality)) return FALSE;
   options|=IMAGE_OWNED;
   return TRUE;
