@@ -3,7 +3,7 @@
 *                            L a b e l   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXLabel.cpp,v 1.46 2003/10/23 17:53:17 fox Exp $                         *
+* $Id: FXLabel.cpp,v 1.49 2004/04/22 20:51:04 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -63,6 +63,7 @@ FXDEFMAP(FXLabel) FXLabelMap[]={
   FXMAPFUNC(SEL_PAINT,0,FXLabel::onPaint),
   FXMAPFUNC(SEL_KEYPRESS,FXLabel::ID_HOTKEY,FXLabel::onHotKeyPress),
   FXMAPFUNC(SEL_KEYRELEASE,FXLabel::ID_HOTKEY,FXLabel::onHotKeyRelease),
+  FXMAPFUNC(SEL_COMMAND,FXLabel::ID_SETVALUE,FXLabel::onCmdSetValue),
   FXMAPFUNC(SEL_COMMAND,FXLabel::ID_SETSTRINGVALUE,FXLabel::onCmdSetStringValue),
   FXMAPFUNC(SEL_COMMAND,FXLabel::ID_GETSTRINGVALUE,FXLabel::onCmdGetStringValue),
   FXMAPFUNC(SEL_COMMAND,FXLabel::ID_SETICONVALUE,FXLabel::onCmdSetIconValue),
@@ -280,6 +281,13 @@ FXint FXLabel::getDefaultHeight(){
   }
 
 
+// Update value from a message
+long FXLabel::onCmdSetValue(FXObject*,FXSelector,void* ptr){
+  setText((const FXchar*)ptr);
+  return 1;
+  }
+
+
 // Update value from a message
 long FXLabel::onCmdSetStringValue(FXObject*,FXSelector,void* ptr){
   setText(*((FXString*)ptr));
@@ -397,8 +405,8 @@ long FXLabel::onCmdGetTip(FXObject*,FXSelector,void* ptr){
   *((FXString*)ptr)=getTipText();
   return 1;
   }
-  
-  
+
+
 // We were asked about status text
 long FXLabel::onQueryHelp(FXObject* sender,FXSelector,void*){
   if(!help.empty() && (flags&FLAG_HELP)){
@@ -498,18 +506,6 @@ FXuint FXLabel::getIconPosition() const {
   }
 
 
-// Change help text
-void FXLabel::setHelpText(const FXString& text){
-  help=text;
-  }
-
-
-// Change tip text
-void FXLabel::setTipText(const FXString& text){
-  tip=text;
-  }
-
-
 // Save object to stream
 void FXLabel::save(FXStream& store) const {
   FXFrame::save(store);
