@@ -3,7 +3,7 @@
 *          M u l t i p l e   D o c u m e n t   C h i l d   W i n d o w          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMDIChild.cpp,v 1.78 2003/10/23 04:19:45 fox Exp $                      *
+* $Id: FXMDIChild.cpp,v 1.80 2004/02/08 17:29:06 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -1015,10 +1015,9 @@ long FXMDIChild::onUpdMenuMinimize(FXObject* sender,FXSelector,void*){
   }
 
 
-// Close window after asking target if its allowed
+// Close window after asking FXMDIChild's target; returns 1 if closed
 long FXMDIChild::onCmdClose(FXObject*,FXSelector,void*){
-  close(TRUE);
-  return 1;
+  return close(TRUE);
   }
 
 
