@@ -3,7 +3,7 @@
 *                   M a t r i x   C o n t a i n e r   O b j e c t               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMatrix.cpp,v 1.25 2003/10/23 04:19:45 fox Exp $                        *
+* $Id: FXMatrix.cpp,v 1.28 2004/02/17 21:13:14 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -231,26 +231,32 @@ long FXMatrix::onFocusRight(FXObject*,FXSelector,void* ptr){
 // Set number of rows (if possible)
 void FXMatrix::setNumRows(FXint nr){
   if(nr<1 || nr>=MAXNUM){ fxerror("%s::setNumRows: bad number of rows specified.\n",getClassName()); }
-  if(!(options&MATRIX_BY_COLUMNS)) num=nr;
+  if(!(options&MATRIX_BY_COLUMNS) && num!=nr){
+    num=nr;
+    recalc();
+    }
   }
 
 
 // Get number of rows
 FXint FXMatrix::getNumRows() const {
-  return (options&MATRIX_BY_COLUMNS) ? (numChildren()+num-1)/num : num;
+  return (num && (options&MATRIX_BY_COLUMNS)) ? (numChildren()+num-1)/num : num;
   }
 
 
 // Set number of columns (if possible)
 void FXMatrix::setNumColumns(FXint nc){
   if(nc<1 || nc>=MAXNUM){ fxerror("%s::setNumColumns: bad number of columns specified.\n",getClassName()); }
-  if(options&MATRIX_BY_COLUMNS) num=nc;
+  if((options&MATRIX_BY_COLUMNS) && num!=nc){
+    num=nc;
+    recalc();
+    }
   }
 
 
 // Get number of columns
 FXint FXMatrix::getNumColumns() const {
-  return (options&MATRIX_BY_COLUMNS) ? num : (numChildren()+num-1)/num;
+  return (num && !(options&MATRIX_BY_COLUMNS)) ? (numChildren()+num-1)/num : num;
   }
 
 
