@@ -3,7 +3,7 @@
 *                         M e s s a g e   B o x e s                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMessageBox.cpp,v 1.27 2003/10/23 04:19:45 fox Exp $                    *
+* $Id: FXMessageBox.cpp,v 1.29 2004/02/08 17:29:06 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -159,10 +159,22 @@ FXuint FXMessageBox::error(FXWindow* owner,FXuint opts,const char* caption,const
   va_start(arguments,message);
   FXMessageBox box(owner,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
   va_end(arguments);
-  return box.execute();
+  return box.execute(PLACEMENT_OWNER);
   }
 
 
+// Show a modal error message, in free floating window
+FXuint FXMessageBox::error(FXApp* app,FXuint opts,const char* caption,const char* message,...){
+  FXGIFIcon icon(app,erroricon);
+  va_list arguments;
+  va_start(arguments,message);
+  FXMessageBox box(app,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
+  va_end(arguments);
+  return box.execute(PLACEMENT_SCREEN);
+  }
+
+
+
 // Show a modal warning message
 FXuint FXMessageBox::warning(FXWindow* owner,FXuint opts,const char* caption,const char* message,...){
   FXGIFIcon icon(owner->getApp(),warningicon);
@@ -170,7 +182,18 @@ FXuint FXMessageBox::warning(FXWindow* owner,FXuint opts,const char* caption,con
   va_start(arguments,message);
   FXMessageBox box(owner,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
   va_end(arguments);
-  return box.execute();
+  return box.execute(PLACEMENT_OWNER);
+  }
+
+
+// Show a modal warning message, in free floating window
+FXuint FXMessageBox::warning(FXApp* app,FXuint opts,const char* caption,const char* message,...){
+  FXGIFIcon icon(app,warningicon);
+  va_list arguments;
+  va_start(arguments,message);
+  FXMessageBox box(app,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
+  va_end(arguments);
+  return box.execute(PLACEMENT_SCREEN);
   }
 
 
@@ -181,7 +204,18 @@ FXuint FXMessageBox::question(FXWindow* owner,FXuint opts,const char* caption,co
   va_start(arguments,message);
   FXMessageBox box(owner,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
   va_end(arguments);
-  return box.execute();
+  return box.execute(PLACEMENT_OWNER);
+  }
+
+
+// Show a modal question dialog, in free floating window
+FXuint FXMessageBox::question(FXApp* app,FXuint opts,const char* caption,const char* message,...){
+  FXGIFIcon icon(app,questionicon);
+  va_list arguments;
+  va_start(arguments,message);
+  FXMessageBox box(app,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
+  va_end(arguments);
+  return box.execute(PLACEMENT_SCREEN);
   }
 
 
@@ -192,8 +226,18 @@ FXuint FXMessageBox::information(FXWindow* owner,FXuint opts,const char* caption
   va_start(arguments,message);
   FXMessageBox box(owner,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
   va_end(arguments);
-  return box.execute();
+  return box.execute(PLACEMENT_OWNER);
   }
 
+
+// Show a modal information dialog, in free floating window
+FXuint FXMessageBox::information(FXApp* app,FXuint opts,const char* caption,const char* message,...){
+  FXGIFIcon icon(app,infoicon);
+  va_list arguments;
+  va_start(arguments,message);
+  FXMessageBox box(app,caption,FXStringVFormat(message,arguments),&icon,opts|DECOR_TITLE|DECOR_BORDER);
+  va_end(arguments);
+  return box.execute(PLACEMENT_SCREEN);
+  }
 }
 
