@@ -3,7 +3,7 @@
 *                            O b j e c t   L i s t                              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXObjectList.cpp,v 1.27 2003/10/22 12:02:42 fox Exp $                    *
+* $Id: FXObjectList.cpp,v 1.30.2.1 2004/06/12 05:09:53 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -73,6 +73,7 @@ void FXObjectList::no(FXint num){
       else{
         data=1+((FXObject**)realloc(data-1,ROUNDUP(num)*sizeof(FXObject*)+sizeof(FXObject*)));
         }
+      if(num>old){memset(data+old,0,(num-old)*sizeof(FXObject*));}
       *((FXint*)(data-1))=num;
       }
     else if(data!=EMPTY){
@@ -140,10 +141,8 @@ FXObjectList& FXObjectList::assign(FXObject* object){
 
 // Assign n objects to list
 FXObjectList& FXObjectList::assign(FXObject** objects,FXint n){
-  if(data!=objects){
-    no(n);
-    memcpy(data,objects,n*sizeof(FXObject*));
-    }
+  no(n);
+  if(0<n){memmove(data,objects,n*sizeof(FXObject*));}
   return *this;
   }
 
