@@ -3,7 +3,7 @@
 *                P a c k e r   C o n t a i n e r   O b j e c t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPacker.cpp,v 1.35 2003/10/23 04:19:45 fox Exp $                        *
+* $Id: FXPacker.cpp,v 1.38 2004/02/08 17:29:07 fox Exp $                        *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -106,81 +106,105 @@ void FXPacker::drawBorderRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint
 
 
 void FXPacker::drawRaisedRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setForeground(shadowColor);
-  dc.fillRectangle(x,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y,1,h);
-  dc.setForeground(hiliteColor);
-  dc.fillRectangle(x,y,w,1);
-  dc.fillRectangle(x,y,1,h);
+  if(0<w && 0<h){
+    dc.setForeground(shadowColor);
+    dc.fillRectangle(x,y+h-1,w,1);
+    dc.fillRectangle(x+w-1,y,1,h);
+    dc.setForeground(hiliteColor);
+    dc.fillRectangle(x,y,w,1);
+    dc.fillRectangle(x,y,1,h);
+    }
   }
 
 
 void FXPacker::drawSunkenRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setForeground(shadowColor);
-  dc.fillRectangle(x,y,w,1);
-  dc.fillRectangle(x,y,1,h);
-  dc.setForeground(hiliteColor);
-  dc.fillRectangle(x,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y,1,h);
+  if(0<w && 0<h){
+    dc.setForeground(shadowColor);
+    dc.fillRectangle(x,y,w,1);
+    dc.fillRectangle(x,y,1,h);
+    dc.setForeground(hiliteColor);
+    dc.fillRectangle(x,y+h-1,w,1);
+    dc.fillRectangle(x+w-1,y,1,h);
+    }
   }
 
 
 void FXPacker::drawRidgeRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setForeground(hiliteColor);
-  dc.fillRectangle(x,y,w,1);
-  dc.fillRectangle(x,y,1,h);
-  dc.fillRectangle(x+1,y+h-2,w-2,1);
-  dc.fillRectangle(x+w-2,y+1,1,h-2);
-  dc.setForeground(shadowColor);
-  dc.fillRectangle(x+1,y+1,w-3,1);
-  dc.fillRectangle(x+1,y+1,1,h-3);
-  dc.fillRectangle(x,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y,1,h);
+  if(0<w && 0<h){
+    dc.setForeground(hiliteColor);
+    dc.fillRectangle(x,y,w,1);
+    dc.fillRectangle(x,y,1,h);
+    dc.setForeground(shadowColor);
+    dc.fillRectangle(x,y+h-1,w,1);
+    dc.fillRectangle(x+w-1,y,1,h);
+    if(1<w && 1<h){
+      dc.setForeground(hiliteColor);
+      dc.fillRectangle(x+1,y+h-2,w-2,1);
+      dc.fillRectangle(x+w-2,y+1,1,h-2);
+      dc.setForeground(shadowColor);
+      dc.fillRectangle(x+1,y+1,w-3,1);
+      dc.fillRectangle(x+1,y+1,1,h-3);
+      }
+    }
   }
 
 
 void FXPacker::drawGrooveRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setForeground(shadowColor);
-  dc.fillRectangle(x,y,w,1);
-  dc.fillRectangle(x,y,1,h);
-  dc.fillRectangle(x+1,y+h-2,w-2,1);
-  dc.fillRectangle(x+w-2,y+1,1,h-2);
-  dc.setForeground(hiliteColor);
-  dc.fillRectangle(x+1,y+1,w-3,1);
-  dc.fillRectangle(x+1,y+1,1,h-3);
-  dc.fillRectangle(x,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y,1,h);
+  if(0<w && 0<h){
+    dc.setForeground(shadowColor);
+    dc.fillRectangle(x,y,w,1);
+    dc.fillRectangle(x,y,1,h);
+    dc.setForeground(hiliteColor);
+    dc.fillRectangle(x,y+h-1,w,1);
+    dc.fillRectangle(x+w-1,y,1,h);
+    if(1<w && 1<h){
+      dc.setForeground(shadowColor);
+      dc.fillRectangle(x+1,y+h-2,w-2,1);
+      dc.fillRectangle(x+w-2,y+1,1,h-2);
+      dc.setForeground(hiliteColor);
+      dc.fillRectangle(x+1,y+1,w-3,1);
+      dc.fillRectangle(x+1,y+1,1,h-3);
+      }
+    }
   }
 
 
 void FXPacker::drawDoubleRaisedRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setForeground(hiliteColor);
-  dc.fillRectangle(x,y,w-1,1);
-  dc.fillRectangle(x,y,1,h-1);
-  dc.setForeground(baseColor);
-  dc.fillRectangle(x+1,y+1,w-2,1);
-  dc.fillRectangle(x+1,y+1,1,h-2);
-  dc.setForeground(shadowColor);
-  dc.fillRectangle(x+1,y+h-2,w-2,1);
-  dc.fillRectangle(x+w-2,y+1,1,h-1);
-  dc.setForeground(borderColor);
-  dc.fillRectangle(x,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y,1,h);
+  if(0<w && 0<h){
+    dc.setForeground(borderColor);
+    dc.fillRectangle(x,y+h-1,w,1);
+    dc.fillRectangle(x+w-1,y,1,h);
+    dc.setForeground(hiliteColor);
+    dc.fillRectangle(x,y,w-1,1);
+    dc.fillRectangle(x,y,1,h-1);
+    if(1<w && 1<h){
+      dc.setForeground(baseColor);
+      dc.fillRectangle(x+1,y+1,w-2,1);
+      dc.fillRectangle(x+1,y+1,1,h-2);
+      dc.setForeground(shadowColor);
+      dc.fillRectangle(x+1,y+h-2,w-2,1);
+      dc.fillRectangle(x+w-2,y+1,1,h-2);
+      }
+    }
   }
 
 void FXPacker::drawDoubleSunkenRectangle(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h){
-  dc.setForeground(shadowColor);
-  dc.fillRectangle(x,y,w-1,1);
-  dc.fillRectangle(x,y,1,h-1);
-  dc.setForeground(borderColor);
-  dc.fillRectangle(x+1,y+1,w-3,1);
-  dc.fillRectangle(x+1,y+1,1,h-3);
-  dc.setForeground(hiliteColor);
-  dc.fillRectangle(x,y+h-1,w,1);
-  dc.fillRectangle(x+w-1,y,1,h);
-  dc.setForeground(baseColor);
-  dc.fillRectangle(x+1,y+h-2,w-2,1);
-  dc.fillRectangle(x+w-2,y+1,1,h-2);
+  if(0<w && 0<h){
+    dc.setForeground(hiliteColor);
+    dc.fillRectangle(x,y+h-1,w,1);
+    dc.fillRectangle(x+w-1,y,1,h);
+    dc.setForeground(shadowColor);
+    dc.fillRectangle(x,y,w-1,1);
+    dc.fillRectangle(x,y,1,h-1);
+    if(1<w && 1<h){
+      dc.setForeground(borderColor);
+      dc.fillRectangle(x+1,y+1,w-3,1);
+      dc.fillRectangle(x+1,y+1,1,h-3);
+      dc.setForeground(baseColor);
+      dc.fillRectangle(x+1,y+h-2,w-2,1);
+      dc.fillRectangle(x+w-2,y+1,1,h-2);
+      }
+    }
   }
 
 
