@@ -3,7 +3,7 @@
 *                     P o p u p   W i n d o w   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXPopup.cpp,v 1.66 2003/10/23 04:19:45 fox Exp $                         *
+* $Id: FXPopup.cpp,v 1.73.2.1 2004/08/13 05:16:16 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -162,44 +162,56 @@ FXWindow* FXPopup::getGrabOwner() const {
 // Get width
 FXint FXPopup::getDefaultWidth(){
   register FXWindow* child;
-  register FXint w,wmax,wcum,n;
+  register FXint w,wmax,wcum;
   register FXuint hints;
-  wmax=wcum=n=0;
+  wmax=wcum=0;
   for(child=getFirst(); child; child=child->getNext()){
     if(child->shown()){
       hints=child->getLayoutHints();
       if(hints&LAYOUT_FIX_WIDTH) w=child->getWidth();
       else w=child->getDefaultWidth();
       if(wmax<w) wmax=w;
-      wcum+=w;
-      n++;
       }
     }
-  if(options&PACK_UNIFORM_WIDTH) wcum=n*wmax;
-  if(options&POPUP_HORIZONTAL) wmax=wcum;
-  return wmax+(border<<1);
+  for(child=getFirst(); child; child=child->getNext()){
+    if(child->shown()){
+      hints=child->getLayoutHints();
+      if(hints&LAYOUT_FIX_WIDTH) w=child->getWidth();
+      else if(options&PACK_UNIFORM_WIDTH) w=wmax;
+      else w=child->getDefaultWidth();
+      wcum+=w;
+      }
+    }
+  if(!(options&POPUP_HORIZONTAL)) wcum=wmax;
+  return wcum+(border<<1);
   }
 
 
 // Get height
 FXint FXPopup::getDefaultHeight(){
   register FXWindow* child;
-  register FXint h,hmax,hcum,n;
+  register FXint h,hmax,hcum;
   register FXuint hints;
-  hmax=hcum=n=0;
+  hmax=hcum=0;
   for(child=getFirst(); child; child=child->getNext()){
     if(child->shown()){
       hints=child->getLayoutHints();
       if(hints&LAYOUT_FIX_HEIGHT) h=child->getHeight();
       else h=child->getDefaultHeight();
       if(hmax<h) hmax=h;
-      hcum+=h;
-      n++;
       }
     }
-  if(options&PACK_UNIFORM_HEIGHT) hcum=n*hmax;
-  if(!(options&POPUP_HORIZONTAL)) hmax=hcum;
-  return hmax+(border<<1);
+  for(child=getFirst(); child; child=child->getNext()){
+    if(child->shown()){
+      hints=child->getLayoutHints();
+      if(hints&LAYOUT_FIX_HEIGHT) h=child->getHeight();
+      else if(options&PACK_UNIFORM_HEIGHT) h=hmax;
+      else h=child->getDefaultHeight();
+      hcum+=h;
+      }
+    }
+  if(options&POPUP_HORIZONTAL) hcum=hmax;
+  return hcum+(border<<1);
   }
 
 
@@ -207,8 +219,7 @@ FXint FXPopup::getDefaultHeight(){
 void FXPopup::layout(){
   register FXWindow *child;
   register FXuint hints;
-  register FXint w,h,x,y,remain,t;
-  register FXint mh=0,mw=0;
+  register FXint w,h,x,y,remain,t,mw,mh;
   register FXint sumexpand=0;
   register FXint numexpand=0;
   register FXint e=0;
@@ -222,6 +233,16 @@ void FXPopup::layout(){
     // Space available
     remain=width-(border<<1);
 
+    // Get maximum size
+    for(child=getFirst(),mw=0; child; child=child->getNext()){
+      if(child->shown()){
+        hints=child->getLayoutHints();
+        if(hints&LAYOUT_FIX_WIDTH) w=child->getWidth();
+        else w=child->getDefaultWidth();
+        if(mw<w) mw=w;
+        }
+      }
+
     // Find number of paddable children and total space remaining
     for(child=getFirst(); child; child=child->getNext()){
       if(child->shown()){
@@ -241,7 +262,7 @@ void FXPopup::layout(){
       }
 
     // Do the layout
-    for(x=border,child=getFirst(); child; child=child->getNext()){
+    for(child=getFirst(),x=border; child; child=child->getNext()){
       if(child->shown()){
         hints=child->getLayoutHints();
         if(hints&LAYOUT_FIX_WIDTH) w=child->getWidth();
@@ -271,12 +292,19 @@ void FXPopup::layout(){
   // Vertical
   else{
 
-    // Get maximum size if uniform packed
-    if(options&PACK_UNIFORM_HEIGHT) mh=maxChildHeight();
-
     // Space available
     remain=height-(border<<1);
 
+    // Get maximum size
+    for(child=getFirst(),mh=0; child; child=child->getNext()){
+      if(child->shown()){
+        hints=child->getLayoutHints();
+        if(hints&LAYOUT_FIX_HEIGHT) h=child->getHeight();
+        else h=child->getDefaultHeight();
+        if(mh<h) mh=h;
+        }
+      }
+
     // Find number of paddable children and total space remaining
     for(child=getFirst(); child; child=child->getNext()){
       if(child->shown()){
@@ -296,7 +324,7 @@ void FXPopup::layout(){
       }
 
     // Do the layout
-    for(y=border,child=getFirst(); child; child=child->getNext()){
+    for(child=getFirst(),y=border; child; child=child->getNext()){
       if(child->shown()){
         hints=child->getLayoutHints();
         if(hints&LAYOUT_FIX_HEIGHT) h=child->getHeight();
@@ -656,6 +684,7 @@ void FXPopup::hide(){
   }
 
 
+/*
 // Popup the menu at some location
 void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
 #ifndef WIN32
@@ -664,12 +693,30 @@ void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
   FXint rw=getRoot()->getWidth();
   FXint rh=getRoot()->getHeight();
 #else
+  OSVERSIONINFO version;
   RECT rect;
-  SystemParametersInfo(SPI_GETWORKAREA,sizeof(RECT),&rect,0);
-  FXint rx=rect.left;
-  FXint ry=rect.top;
-  FXint rw=rect.right-rect.left;
-  FXint rh=rect.bottom-rect.top;
+  FXint rx,ry,rw,rh;
+  version.dwOSVersionInfoSize=sizeof(OSVERSIONINFO);
+  GetVersionEx (&version);
+
+  // Patch from "Rafael de Pelegrini Soares" <Rafael@enq.ufrgs.br>
+  // Older Microsoft Operating Systems, Win95 and NT4 or below
+  if(version.dwMajorVersion<5 && version.dwMinorVersion<10){
+    SystemParametersInfo(SPI_GETWORKAREA,sizeof(RECT),&rect,0);
+    rx=rect.left;
+    ry=rect.top;
+    rw=rect.right-rect.left;
+    rh=rect.bottom-rect.top;
+    }
+
+  // Later Microsoft Operating Systems
+  // Patch from Brian Hook <hook_l@pyrogon.com>
+  else{
+    rx=GetSystemMetrics(SM_XVIRTUALSCREEN);
+    ry=GetSystemMetrics(SM_YVIRTUALSCREEN);
+    rw=GetSystemMetrics(SM_CXVIRTUALSCREEN);
+    rh=GetSystemMetrics(SM_CYVIRTUALSCREEN);
+    }
 #endif
   FXTRACE((150,"%s::popup %p\n",getClassName(),this));
   grabowner=grabto;
@@ -685,6 +732,82 @@ void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
   setFocus();
   if(!grabowner) grab();
   }
+*/
+
+
+// Popup the menu at some location
+void FXPopup::popup(FXWindow* grabto,FXint x,FXint y,FXint w,FXint h){
+  FXint rx,ry,rw,rh;
+#ifndef WIN32
+  rx=getRoot()->getX();
+  ry=getRoot()->getY();
+  rw=getRoot()->getWidth();
+  rh=getRoot()->getHeight();
+#else
+  OSVERSIONINFO vinfo;
+  RECT rect;
+  memset(&vinfo,0,sizeof(vinfo));
+  vinfo.dwOSVersionInfoSize=sizeof(vinfo);
+  GetVersionEx(&vinfo);
+
+#if (WINVER >= 0x500) || ((defined _WIN32_WINDOWS) && (_WIN32_WINDOWS >= 0x410))
+
+  HINSTANCE user32;
+  typedef BOOL (WINAPI* PFN_GETMONITORINFOA)(HMONITOR, LPMONITORINFO);
+  typedef HMONITOR (WINAPI* PFN_MONITORFROMRECTA)(LPRECT, DWORD);
+  PFN_GETMONITORINFOA GetMonitorInfoA;
+  PFN_MONITORFROMRECTA MonitorFromRectA;
+
+  // Suggested by "Daniel Gehriger" <gehriger@linkcad.com>
+  // The API does not exist on older Windows NT and 95, so
+  // We can't even link it, let alone call it.
+  // The solution is to ask the DLL if the function exists.
+  if((user32=LoadLibrary("User32")) && (GetMonitorInfoA=reinterpret_cast<PFN_GETMONITORINFOA>(GetProcAddress(user32,"GetMonitorInfoA"))) && (MonitorFromRectA=reinterpret_cast<PFN_MONITORFROMRECTA>(GetProcAddress(user32,"MonitorFromRectA")))){
+    MONITORINFOEX minfo;
+    HMONITOR hMon;
+    rect.left=x;
+    rect.right=x+w;
+    rect.top=y;
+    rect.bottom=y+h;
+    hMon=MonitorFromRectA(&rect,MONITOR_DEFAULTTOPRIMARY);
+    memset(&minfo,0,sizeof(minfo));
+    minfo.cbSize=sizeof(minfo);
+    GetMonitorInfoA(hMon,&minfo);
+    rx=minfo.rcWork.left;
+    ry=minfo.rcWork.top;
+    rw=minfo.rcWork.right;
+    rh=minfo.rcWork.bottom;
+    }
+
+  else
+
+#endif
+
+    {
+    // On Win95 and WinNT, we have to use the following
+    SystemParametersInfo(SPI_GETWORKAREA,sizeof(RECT),&rect,0);
+    rx=rect.left;
+    ry=rect.top;
+    rw=rect.right-rect.left;
+    rh=rect.bottom-rect.top;
+    }
+
+#endif
+
+  FXTRACE((150,"%s::popup %p\n",getClassName(),this));
+  grabowner=grabto;
+  if((options&POPUP_SHRINKWRAP) || w<=1) w=getDefaultWidth();
+  if((options&POPUP_SHRINKWRAP) || h<=1) h=getDefaultHeight();
+  if(x+w>rw) x=rw-w;
+  if(y+h>rh) y=rh-h;
+  if(x<rx) x=rx;
+  if(y<ry) y=ry;
+  position(x,y,w,h);
+  show();
+  raise();
+  setFocus();
+  if(!grabowner) grab();
+  }
 
 
 // Pops down menu and its submenus
