@@ -3,7 +3,7 @@
 *              D o u b l e - P r e c i s i o n  Q u a t e r n i o n             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1994,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1994,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXQuatd.cpp,v 1.4 2003/08/26 23:08:50 fox Exp $                          *
+* $Id: FXQuatd.cpp,v 1.7.2.1 2004/06/24 13:57:24 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -66,17 +66,17 @@ void FXQuatd::setAxisAngle(const FXVec3d& axis,FXdouble phi){
 // for unit quaternion |q| == 1
 void FXQuatd::getAxisAngle(FXVec3d& axis,FXdouble& phi) const {
   register FXdouble n=sqrt(x*x+y*y+z*z);
-  if(n>0.0f){
+  if(n>0.0){
     axis.x=x/n;
     axis.y=y/n;
     axis.z=z/n;
-    phi=2.0f*acos(w);
+    phi=2.0*acos(w);
     }
   else{
-    axis.x=1.0f;
-    axis.y=0.0f;
-    axis.z=0.0f;
-    phi=0.0f;
+    axis.x=1.0;
+    axis.y=0.0;
+    axis.z=0.0;
+    phi=0.0;
     }
   }
 
@@ -175,8 +175,13 @@ FXQuatd log(const FXQuatd& q){
 // Invert quaternion
 FXQuatd invert(const FXQuatd& q){
   register FXdouble n=q.x*q.x+q.y*q.y+q.z*q.z+q.w*q.w;
-  FXASSERT(n>0.0);
-  return FXQuatd(-q.x/n,-q.y/n,-q.z/n,-q.w/n);
+  return FXQuatd(-q.x/n,-q.y/n,-q.z/n,q.w/n);
+  }
+
+
+// Invert unit quaternion
+FXQuatd unitinvert(const FXQuatd& q){
+  return FXQuatd(-q.x,-q.y,-q.z,q.w);
   }
 
 
@@ -195,6 +200,27 @@ FXQuatd operator*(const FXQuatd& p,const FXQuatd& q){
   }
 
 
+// Rotation of a vector by a quaternion; this is defined as q.v.q*
+// where q* is the conjugate of q.
+FXVec3d operator*(const FXQuatd& quat,const FXVec3d& vec){
+  register FXdouble tx=2.0*quat.x;
+  register FXdouble ty=2.0*quat.y;
+  register FXdouble tz=2.0*quat.z;
+  register FXdouble twx=tx*quat.w;
+  register FXdouble twy=ty*quat.w;
+  register FXdouble twz=tz*quat.w;
+  register FXdouble txx=tx*quat.x;
+  register FXdouble txy=ty*quat.x;
+  register FXdouble txz=tz*quat.x;
+  register FXdouble tyy=ty*quat.y;
+  register FXdouble tyz=tz*quat.y;
+  register FXdouble tzz=tz*quat.z;
+
+  return FXVec3d(vec.x*(1.0-tyy-tzz)+vec.y*(txy-twz)+vec.z*(txz-twy),
+                 vec.x*(txy+twz)+vec.y*(1.0-txx-tzz)+vec.z*(tyz-twx),
+                 vec.x*(txz-twy)+vec.y*(tyz+twx)+vec.z*(1.0-txx-tyy));
+  }
+
 
 // Construct quaternion from arc a->b on unit sphere
 FXQuatd arc(const FXVec3d& f,const FXVec3d& t){
