@@ -3,7 +3,7 @@
 *              S i n g l e - P r e c i s i o n  Q u a t e r n i o n             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1994,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1994,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXQuatf.cpp,v 1.7 2003/08/26 23:08:50 fox Exp $                          *
+* $Id: FXQuatf.cpp,v 1.11 2004/02/27 23:30:45 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -175,8 +175,13 @@ FXQuatf log(const FXQuatf& q){
 // Invert quaternion
 FXQuatf invert(const FXQuatf& q){
   register FXfloat n=q.x*q.x+q.y*q.y+q.z*q.z+q.w*q.w;
-  FXASSERT(n>0.0f);
-  return FXQuatf(-q.x/n,-q.y/n,-q.z/n,-q.w/n);
+  return FXQuatf(-q.x/n,-q.y/n,-q.z/n,q.w/n);
+  }
+
+
+// Invert unit quaternion
+FXQuatf unitinvert(const FXQuatf& q){
+  return FXQuatf(-q.x,-q.y,-q.z,q.w);
   }
 
 
@@ -196,6 +201,28 @@ FXQuatf operator*(const FXQuatf& p,const FXQuatf& q){
 
 
 
+// Rotation of a vector by a quaternion; this is defined as q.v.q*
+// where q* is the conjugate of q.
+FXVec3f operator*(const FXQuatf& quat,const FXVec3f& vec){
+  register FXfloat tx=2.0f*quat.x;
+  register FXfloat ty=2.0f*quat.y;
+  register FXfloat tz=2.0f*quat.z;
+  register FXfloat twx=tx*quat.w;
+  register FXfloat twy=ty*quat.w;
+  register FXfloat twz=tz*quat.w;
+  register FXfloat txx=tx*quat.x;
+  register FXfloat txy=ty*quat.x;
+  register FXfloat txz=tz*quat.x;
+  register FXfloat tyy=ty*quat.y;
+  register FXfloat tyz=tz*quat.y;
+  register FXfloat tzz=tz*quat.z;
+
+  return FXVec3f(vec.x*(1.0f-tyy-tzz)+vec.y*(txy-twz)+vec.z*(txz-twy),
+                 vec.x*(txy+twz)+vec.y*(1.0f-txx-tzz)+vec.z*(tyz-twx),
+                 vec.x*(txz-twy)+vec.y*(tyz+twx)+vec.z*(1.0f-txx-tyy));
+  }
+
+
 // Construct quaternion from arc a->b on unit sphere
 FXQuatf arc(const FXVec3f& f,const FXVec3f& t){
   return FXQuatf(f.y*t.z-f.z*t.y, f.z*t.x-f.x*t.z, f.x*t.y-f.y*t.x, f.x*t.x+f.y*t.y+f.z*t.z);
