@@ -3,7 +3,7 @@
 *                  R a d i o   B u t t o n    O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRadioButton.cpp,v 1.50 2003/10/23 04:19:45 fox Exp $                   *
+* $Id: FXRadioButton.cpp,v 1.52 2004/02/17 21:06:02 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -87,20 +87,22 @@ FXIMPLEMENT(FXRadioButton,FXLabel,FXRadioButtonMap,ARRAYNUMBER(FXRadioButtonMap)
 
 // Deserialization
 FXRadioButton::FXRadioButton(){
+  radioColor=0;
+  diskColor=0;
   check=FALSE;
   oldcheck=FALSE;
-  radioColor=0;
   }
 
 
 // Make a check button
 FXRadioButton::FXRadioButton(FXComposite* p,const FXString& text,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h,FXint pl,FXint pr,FXint pt,FXint pb):
   FXLabel(p,text,NULL,opts,x,y,w,h,pl,pr,pt,pb){
+  radioColor=getApp()->getForeColor();
+  diskColor=getApp()->getBackColor();
   target=tgt;
   message=sel;
   check=FALSE;
   oldcheck=FALSE;
-  radioColor=getApp()->getBackColor();
   }
 
 
@@ -378,7 +380,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr){
   if(!isEnabled())                   // fix by Daniel Gehriger (gehriger@linkcad.com)
     dc.setForeground(baseColor);
   else
-    dc.setForeground(radioColor);
+    dc.setForeground(diskColor);
   dc.fillRectangles(recs,5);
 
   // Top left outside
@@ -427,7 +429,7 @@ long FXRadioButton::onPaint(FXObject*,FXSelector,void* ptr){
     recs[1].x=ix+4; recs[1].y=iy+5; recs[1].w=4; recs[1].h=2;
     recs[2].x=ix+5; recs[2].y=iy+7; recs[2].w=2; recs[2].h=1;
     if(isEnabled())
-      dc.setForeground(textColor);
+      dc.setForeground(radioColor);
     else
       dc.setForeground(shadowColor);
     dc.fillRectangles(recs,3);
@@ -485,6 +487,15 @@ void FXRadioButton::setRadioColor(FXColor clr){
   }
 
 
+// Set disk color
+void FXRadioButton::setDiskColor(FXColor clr){
+  if(clr!=diskColor){
+    diskColor=clr;
+    update();
+    }
+  }
+
+
 // Change radio button style
 void FXRadioButton::setRadioButtonStyle(FXuint style){
   FXuint opts=(options&~RADIOBUTTON_MASK) | (style&RADIOBUTTON_MASK);
@@ -505,6 +516,7 @@ FXuint FXRadioButton::getRadioButtonStyle() const {
 void FXRadioButton::save(FXStream& store) const {
   FXLabel::save(store);
   store << radioColor;
+  store << diskColor;
   }
 
 
@@ -512,6 +524,7 @@ void FXRadioButton::save(FXStream& store) const {
 void FXRadioButton::load(FXStream& store){
   FXLabel::load(store);
   store >> radioColor;
+  store >> diskColor;
   }
 
 }
