@@ -3,7 +3,7 @@
 *                           R e g i s t r y   C l a s s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRegistry.cpp,v 1.37 2003/05/12 09:00:01 fox Exp $                      *
+* $Id: FXRegistry.cpp,v 1.40 2004/04/16 15:00:13 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -554,22 +554,12 @@ FXbool FXRegistry::writeToRegistryGroup(void* org,const char* groupname){
   FXStringDict *group;
   if(RegCreateKeyEx((HKEY)org,groupname,0,REG_NONE,REG_OPTION_NON_VOLATILE,KEY_WRITE|KEY_READ,NULL,&groupkey,&disp)==ERROR_SUCCESS){
 
-/*    
-    // First, purge all existing sections
-    sectionindex=0;
-    sectionsize=MAXNAME;
-    while(RegEnumKeyEx(groupkey,sectionindex,section,&sectionsize,NULL,NULL,NULL,&writetime)==ERROR_SUCCESS){
-      RegDeleteKey(groupkey,section);
-      sectionsize=MAXNAME;
-      sectionindex++;
-      }
-*/      
-    // First, purge all existing sections
+    // First, purge all existing sections 
     while(1){
       sectionindex=0;
       sectionsize=MAXNAME;
       if(RegEnumKeyEx(groupkey,sectionindex,section,&sectionsize,NULL,NULL,NULL,&writetime)!=ERROR_SUCCESS) break;
-      RegDeleteKey(groupkey,section);
+      if(RegDeleteKey(groupkey,section)!=ERROR_SUCCESS) break;
       }
 
     // Dump the registry, writing only marked entries
