@@ -3,7 +3,7 @@
 *                         S c r o l l b a r   O b j e c t s                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXScrollBar.cpp,v 1.13 2003/10/23 04:19:45 fox Exp $                     *
+* $Id: FXScrollBar.cpp,v 1.16 2004/02/08 17:29:07 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -47,15 +47,9 @@
 */
 
 
-#define THUMB_MINIMUM        8
-#define BAR_SIZE            15
-#define PRESSED_INC          1
-#define PRESSED_DEC          2
-#define PRESSED_PAGEINC      4
-#define PRESSED_PAGEDEC      8
-#define PRESSED_THUMB       16
-#define PRESSED_FINETHUMB   32
-#define SCROLLBAR_MASK      (SCROLLBAR_HORIZONTAL|SCROLLBAR_WHEELJUMP)
+#define THUMB_MINIMUM   8
+#define BAR_SIZE        15
+#define SCROLLBAR_MASK  (SCROLLBAR_HORIZONTAL|SCROLLBAR_WHEELJUMP)
 
 using namespace FX;
 
@@ -95,7 +89,7 @@ FXScrollBar::FXScrollBar(){
   thumbpos=BAR_SIZE;
   thumbsize=THUMB_MINIMUM;
   dragpoint=0;
-  pressed=0;
+  mode=MODE_NONE;
   }
 
 
@@ -117,7 +111,7 @@ FXScrollBar::FXScrollBar(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts
   page=1;
   line=1;
   pos=0;
-  pressed=0;
+  mode=MODE_NONE;
   }
 
 
@@ -189,65 +183,64 @@ long FXScrollBar::onLeftBtnPress(FXObject*,FXSelector,void* ptr){
     flags&=~FLAG_UPDATE;
     if(options&SCROLLBAR_HORIZONTAL){     // Horizontal scrollbar
       if(event->win_x<height){                   // Left arrow
-        pressed=PRESSED_DEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-line);
         p=pos-line;
         update();
+        mode=MODE_DEC;
         }
       else if(width-height<=event->win_x){       // Right arrow
-        pressed=PRESSED_INC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)line);
         p=pos+line;
         update();
+        mode=MODE_INC;
         }
       else if(event->win_x<thumbpos){             // Page left
-        pressed=PRESSED_PAGEDEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-page);
         p=pos-page;
         update();
+        mode=MODE_PAGE_DEC;
         }
       else if(thumbpos+thumbsize<=event->win_x){  // Page right
-        pressed=PRESSED_PAGEINC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)page);
         p=pos+page;
         update();
+        mode=MODE_PAGE_INC;
         }
       else{                                       // Grabbed the puck
-        pressed=PRESSED_THUMB;
+        if(event->state&(CONTROLMASK|SHIFTMASK|ALTMASK)) mode=MODE_FINE_DRAG;
         dragpoint=event->win_x-thumbpos;
-        flags|=FLAG_PRESSED;
+        mode=MODE_DRAG;
         }
       }
     else{                                 // Vertical scrollbar
       if(event->win_y<width){                   // Up arrow
-        pressed=PRESSED_DEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-line);
         p=pos-line;
         update();
+        mode=MODE_DEC;
         }
       else if(height-width<=event->win_y){      // Down arrow
-        pressed=PRESSED_INC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)line);
         p=pos+line;
         update();
+        mode=MODE_INC;
         }
       else if(event->win_y<thumbpos){             // Page up
-        pressed=PRESSED_PAGEDEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-page);
         p=pos-page;
         update();
+        mode=MODE_PAGE_DEC;
         }
       else if(thumbpos+thumbsize<=event->win_y){  // Page down
-        pressed=PRESSED_PAGEINC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)page);
         p=pos+page;
         update();
+        mode=MODE_PAGE_INC;
         }
       else{                                       // Grabbed the puck
-        pressed=PRESSED_THUMB;
-        if(event->state&(CONTROLMASK|SHIFTMASK|ALTMASK)) pressed=PRESSED_FINETHUMB;
+        if(event->state&(CONTROLMASK|SHIFTMASK|ALTMASK)) mode=MODE_FINE_DRAG;
         dragpoint=event->win_y-thumbpos;
-        flags|=FLAG_PRESSED;
+        mode=MODE_DRAG;
         }
       }
     if(p<0) p=0;
@@ -268,11 +261,10 @@ long FXScrollBar::onLeftBtnRelease(FXObject*,FXSelector,void* ptr){
   FXuint flgs=flags;
   if(isEnabled()){
     ungrab();
-    flags&=~FLAG_PRESSED;
     flags&=~FLAG_CHANGED;
     flags|=FLAG_UPDATE;
     dragpoint=0;
-    pressed=0;
+    mode=MODE_NONE;
     setPosition(pos);
     update();
     getApp()->removeTimeout(this,ID_TIMEWHEEL);
@@ -297,8 +289,7 @@ long FXScrollBar::onMiddleBtnPress(FXObject*,FXSelector,void* ptr){
     getApp()->removeTimeout(this,ID_TIMEWHEEL);
     getApp()->removeTimeout(this,ID_AUTOSCROLL);
     if(target && target->handle(this,FXSEL(SEL_MIDDLEBUTTONPRESS,message),ptr)) return 1;
-    pressed=PRESSED_THUMB;
-    flags|=FLAG_PRESSED;
+    mode=MODE_DRAG;
     flags&=~FLAG_UPDATE;
     dragpoint=thumbsize/2;
     if(options&SCROLLBAR_HORIZONTAL){
@@ -343,11 +334,10 @@ long FXScrollBar::onMiddleBtnRelease(FXObject*,FXSelector,void* ptr){
   FXuint flgs=flags;
   if(isEnabled()){
     ungrab();
-    flags&=~FLAG_PRESSED;
     flags&=~FLAG_CHANGED;
     flags|=FLAG_UPDATE;
     dragpoint=0;
-    pressed=0;
+    mode=MODE_NONE;
     setPosition(pos);
     update();
     getApp()->removeTimeout(this,ID_TIMEWHEEL);
@@ -374,63 +364,62 @@ long FXScrollBar::onRightBtnPress(FXObject*,FXSelector,void* ptr){
     flags&=~FLAG_UPDATE;
     if(options&SCROLLBAR_HORIZONTAL){     // Horizontal scrollbar
       if(event->win_x<height){                   // Left arrow
-        pressed=PRESSED_DEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-1);
         p=pos-1;
         update();
+        mode=MODE_DEC;
         }
       else if(width-height<=event->win_x){       // Right arrow
-        pressed=PRESSED_INC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)1);
         p=pos+1;
         update();
+        mode=MODE_INC;
         }
       else if(event->win_x<thumbpos){             // Page left
-        pressed=PRESSED_PAGEDEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-line);
         p=pos-line;
         update();
+        mode=MODE_PAGE_DEC;
         }
       else if(thumbpos+thumbsize<=event->win_x){  // Page right
-        pressed=PRESSED_PAGEINC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)line);
         p=pos+line;
         update();
+        mode=MODE_PAGE_INC;
         }
       else{                                       // Grabbed the puck
-        pressed=PRESSED_FINETHUMB;
-        dragpoint=event->win_x;
-        flags|=FLAG_PRESSED;
+        dragpoint=event->win_x-thumbpos;
+        mode=MODE_FINE_DRAG;
         }
       }
     else{                                 // Vertical scrollbar
       if(event->win_y<width){                   // Up arrow
-        pressed=PRESSED_DEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-1);
         p=pos-1;
         update();
+        mode=MODE_DEC;
         }
       else if(height-width<=event->win_y){      // Down arrow
-        pressed=PRESSED_INC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)1);
         p=pos+1;
         update();
+        mode=MODE_INC;
         }
       else if(event->win_y<thumbpos){             // Page up
-        pressed=PRESSED_PAGEDEC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)-line);
         p=pos-line;
         update();
+        mode=MODE_PAGE_DEC;
         }
       else if(thumbpos+thumbsize<=event->win_y){  // Page down
-        pressed=PRESSED_PAGEINC;
         getApp()->addTimeout(this,ID_AUTOSCROLL,getApp()->getScrollDelay(),(void*)(FXival)line);
         p=pos+line;
         update();
+        mode=MODE_PAGE_INC;
         }
       else{                                       // Grabbed the puck
-        pressed=PRESSED_FINETHUMB;
-        flags|=FLAG_PRESSED;
+        dragpoint=event->win_y-thumbpos;
+        mode=MODE_FINE_DRAG;
         }
       }
     if(p<0) p=0;
@@ -451,11 +440,10 @@ long FXScrollBar::onRightBtnRelease(FXObject*,FXSelector,void* ptr){
   FXuint flgs=flags;
   if(isEnabled()){
     ungrab();
-    flags&=~FLAG_PRESSED;
     flags&=~FLAG_CHANGED;
     flags|=FLAG_UPDATE;
     dragpoint=0;
-    pressed=0;
+    mode=MODE_NONE;
     setPosition(pos);
     update();
     getApp()->removeTimeout(this,ID_TIMEWHEEL);
@@ -475,11 +463,10 @@ long FXScrollBar::onUngrabbed(FXObject* sender,FXSelector sel,void* ptr){
   FXWindow::onUngrabbed(sender,sel,ptr);
   getApp()->removeTimeout(this,ID_TIMEWHEEL);
   getApp()->removeTimeout(this,ID_AUTOSCROLL);
-  flags&=~FLAG_PRESSED;
   flags&=~FLAG_CHANGED;
   flags|=FLAG_UPDATE;
   dragpoint=0;
-  pressed=0;
+  mode=MODE_NONE;
   return 1;
   }
 
@@ -489,10 +476,18 @@ long FXScrollBar::onMotion(FXObject*,FXSelector,void* ptr){
   FXEvent *event=(FXEvent*)ptr;
   FXint travel,hi,lo,t,p;
   if(!isEnabled()) return 0;
-  if(flags&FLAG_PRESSED){
+  if(mode>=MODE_DRAG){
     p=0;
-    if(event->state&(CONTROLMASK|SHIFTMASK|ALTMASK)) pressed=PRESSED_FINETHUMB;
-    if(pressed==PRESSED_THUMB){             // Coarse movements
+
+    // If modifiers down, fine scrolling method goes in effect, if
+    // not, switch back to coarse mode (thanks, Tony <verant@mail.ru>)!
+    if(event->state&(CONTROLMASK|SHIFTMASK|ALTMASK|RIGHTBUTTONMASK))
+      mode=MODE_FINE_DRAG;
+    else
+      mode=MODE_DRAG;
+
+    // Coarse movements
+    if(mode==MODE_DRAG){
       if(options&SCROLLBAR_HORIZONTAL){
         travel=width-height-height-thumbsize;
         t=event->win_x-dragpoint;
@@ -518,7 +513,9 @@ long FXScrollBar::onMotion(FXObject*,FXSelector,void* ptr){
         if(travel>0){ p=(FXint)((((FXdouble)(thumbpos-width))*(range-page)+travel/2)/travel); }
         }
       }
-    else if(pressed==PRESSED_FINETHUMB){    // Fine movements
+
+    // Fine movements
+    else if(mode==MODE_FINE_DRAG){
       if(options&SCROLLBAR_HORIZONTAL){
         travel=width-height-height-thumbsize;
         p=pos+event->win_x-event->last_x;
@@ -544,6 +541,8 @@ long FXScrollBar::onMotion(FXObject*,FXSelector,void* ptr){
           }
         }
       }
+
+    // Clamp range and issue callbacks
     if(p<0) p=0;
     if(p>(range-page)) p=range-page;
     if(pos!=p){
@@ -770,7 +769,7 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr){
       drawButton(dc,thumbpos,0,thumbsize,height,0);
       dc.setStipple(STIPPLE_GRAY);
       dc.setFillStyle(FILL_OPAQUESTIPPLED);
-      if(pressed&PRESSED_PAGEDEC){
+      if(mode==MODE_PAGE_DEC){
         dc.setForeground(backColor);
         dc.setBackground(shadowColor);
         }
@@ -779,7 +778,7 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr){
         dc.setBackground(backColor);
         }
       dc.fillRectangle(height,0,thumbpos-height,height);
-      if(pressed&PRESSED_PAGEINC){
+      if(mode==MODE_PAGE_INC){
         dc.setForeground(backColor);
         dc.setBackground(shadowColor);
         }
@@ -797,10 +796,10 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr){
       dc.fillRectangle(height,0,total,height);
       }
     dc.setFillStyle(FILL_SOLID);
-    drawButton(dc,width-height,0,height,height,(pressed&PRESSED_INC));
-    drawRightArrow(dc,width-height,0,height,height,(pressed&PRESSED_INC));
-    drawButton(dc,0,0,height,height,(pressed&PRESSED_DEC));
-    drawLeftArrow(dc,0,0,height,height,(pressed&PRESSED_DEC));
+    drawButton(dc,width-height,0,height,height,(mode==MODE_INC));
+    drawRightArrow(dc,width-height,0,height,height,(mode==MODE_INC));
+    drawButton(dc,0,0,height,height,(mode==MODE_DEC));
+    drawLeftArrow(dc,0,0,height,height,(mode==MODE_DEC));
     }
   else{
     total=height-width-width;
@@ -808,7 +807,7 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr){
       drawButton(dc,0,thumbpos,width,thumbsize,0);
       dc.setStipple(STIPPLE_GRAY);
       dc.setFillStyle(FILL_OPAQUESTIPPLED);
-      if(pressed&PRESSED_PAGEDEC){
+      if(mode==MODE_PAGE_DEC){
         dc.setForeground(backColor);
         dc.setBackground(shadowColor);
         }
@@ -817,7 +816,7 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr){
         dc.setBackground(backColor);
         }
       dc.fillRectangle(0,width,width,thumbpos-width);
-      if(pressed&PRESSED_PAGEINC){
+      if(mode==MODE_PAGE_INC){
         dc.setForeground(backColor);
         dc.setBackground(shadowColor);
         }
@@ -835,10 +834,10 @@ long FXScrollBar::onPaint(FXObject*,FXSelector,void* ptr){
       dc.fillRectangle(0,width,width,total);
       }
     dc.setFillStyle(FILL_SOLID);
-    drawButton(dc,0,height-width,width,width,(pressed&PRESSED_INC));
-    drawDownArrow(dc,0,height-width,width,width,(pressed&PRESSED_INC));
-    drawButton(dc,0,0,width,width,(pressed&PRESSED_DEC));
-    drawUpArrow(dc,0,0,width,width,(pressed&PRESSED_DEC));
+    drawButton(dc,0,height-width,width,width,(mode==MODE_INC));
+    drawDownArrow(dc,0,height-width,width,width,(mode==MODE_INC));
+    drawButton(dc,0,0,width,width,(mode==MODE_DEC));
+    drawUpArrow(dc,0,0,width,width,(mode==MODE_DEC));
     }
   return 1;
   }
