@@ -3,7 +3,7 @@
 *                             S p i n   B u t t o n                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Lyle Johnson.   All Rights Reserved.               *
+* Copyright (C) 1998,2004 by Lyle Johnson.   All Rights Reserved.               *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSpinner.cpp,v 1.45 2003/10/23 04:19:45 fox Exp $                       *
+* $Id: FXSpinner.cpp,v 1.50 2004/02/19 15:37:45 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -67,6 +67,7 @@ namespace FX {
 FXDEFMAP(FXSpinner) FXSpinnerMap[]={
   FXMAPFUNC(SEL_KEYPRESS,0,FXSpinner::onKeyPress),
   FXMAPFUNC(SEL_KEYRELEASE,0,FXSpinner::onKeyRelease),
+  FXMAPFUNC(SEL_FOCUS_SELF,0,FXSpinner::onFocusSelf),
   FXMAPFUNC(SEL_UPDATE,FXSpinner::ID_ENTRY,FXSpinner::onUpdEntry),
   FXMAPFUNC(SEL_COMMAND,FXSpinner::ID_ENTRY,FXSpinner::onCmdEntry),
   FXMAPFUNC(SEL_CHANGED,FXSpinner::ID_ENTRY,FXSpinner::onChgEntry),
@@ -191,10 +192,12 @@ long FXSpinner::onUpdIncrement(FXObject* sender,FXSelector,void*){
 
 // Respond to increment message
 long FXSpinner::onCmdIncrement(FXObject*,FXSelector,void*){
-  if(!isEnabled()) return 0;
-  increment();
-  if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-  return 1;
+  if(isEnabled() && isEditable()){
+    increment();
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+    return 1;
+    }
+  return 0;
   }
 
 
@@ -210,18 +213,26 @@ long FXSpinner::onUpdDecrement(FXObject* sender,FXSelector,void*){
 
 // Respond to decrement message
 long FXSpinner::onCmdDecrement(FXObject*,FXSelector,void*){
-  if(!isEnabled()) return 0;
-  decrement();
-  if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-  return 1;
+  if(isEnabled() && isEditable()){
+    decrement();
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+    return 1;
+    }
+  return 0;
   }
 
 
 // Rolling mouse wheel in text field works as if hitting up or down buttons
 long FXSpinner::onWheelEntry(FXObject*,FXSelector,void* ptr){
-  if(((FXEvent*)ptr)->code>0) increment(); else decrement();
-  if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-  return 1;
+  if(isEnabled() && isEditable()){
+    if(((FXEvent*)ptr)->code>0) 
+      increment(); 
+    else 
+      decrement();
+    if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+    return 1;
+    }
+  return 0;
   }
 
 
@@ -255,21 +266,32 @@ long FXSpinner::onCmdEntry(FXObject*,FXSelector,void*){
 // Keyboard press
 long FXSpinner::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  if(!isEnabled()) return 0;
-  if(target && target->handle(this,FXSEL(SEL_KEYPRESS,message),ptr)) return 1;
-  switch(event->code){
-    case KEY_Up:
-    case KEY_KP_Up:
-      increment();
-      if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-      return 1;
-    case KEY_Down:
-    case KEY_KP_Down:
-      decrement();
-      if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
-      return 1;
-    default:
-      return textField->handle(sender,sel,ptr);
+  if(isEnabled()){
+    if(target && target->handle(this,FXSEL(SEL_KEYPRESS,message),ptr)) return 1;
+    switch(event->code){
+      case KEY_Up:
+      case KEY_KP_Up:
+        if(isEditable()){
+          increment();
+          if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      case KEY_Down:
+      case KEY_KP_Down:
+        if(isEditable()){
+          decrement();
+          if(target) target->handle(this,FXSEL(SEL_COMMAND,message),(void*)(FXival)pos);
+          }
+        else{
+          getApp()->beep();
+          }
+        return 1;
+      default:
+        return textField->handle(sender,sel,ptr);
+      }
     }
   return 0;
   }
@@ -278,21 +300,28 @@ long FXSpinner::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
 // Keyboard release
 long FXSpinner::onKeyRelease(FXObject* sender,FXSelector sel,void* ptr){
   FXEvent* event=(FXEvent*)ptr;
-  if(!isEnabled()) return 0;
-  if(target && target->handle(this,FXSEL(SEL_KEYRELEASE,message),ptr)) return 1;
-  switch(event->code){
-    case KEY_Up:
-    case KEY_KP_Up:
-    case KEY_Down:
-    case KEY_KP_Down:
-      return 1;
-    default:
-      return textField->handle(sender,sel,ptr);
+  if(isEnabled()){
+    if(target && target->handle(this,FXSEL(SEL_KEYRELEASE,message),ptr)) return 1;
+    switch(event->code){
+      case KEY_Up:
+      case KEY_KP_Up:
+      case KEY_Down:
+      case KEY_KP_Down:
+        return 1;
+      default:
+        return textField->handle(sender,sel,ptr);
+      }
     }
   return 0;
   }
 
 
+// Force focus on the text field
+long FXSpinner::onFocusSelf(FXObject* sender,FXSelector,void* ptr){
+  return textField->handle(sender,FXSEL(SEL_FOCUS_SELF,0),ptr);
+  }
+
+
 // Update value from a message
 long FXSpinner::onCmdSetValue(FXObject*,FXSelector,void* ptr){
   setValue((FXint)(FXival)ptr);
