@@ -3,7 +3,7 @@
 *                S p l i t t e r   W i n d o w   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXSplitter.cpp,v 1.38 2003/10/23 04:19:45 fox Exp $                      *
+* $Id: FXSplitter.cpp,v 1.42 2004/04/05 14:49:33 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -56,6 +56,8 @@
     SPLITTER_REVERSED has been passed) must necessarily be allowed to be
     any size.
   - If we're just re-sizing a split, do we need to incur a GUI-Update?
+  - Do we need to somehow insure that the sum of the sizes of all
+    partitions never exceeds the size of the splitter itself?
 */
 
 // Splitter styles
@@ -177,8 +179,9 @@ FXint FXSplitter::getDefaultHeight(){
 
 // Recompute layout
 void FXSplitter::layout(){
-  FXint pos,w,h;
   FXWindow *child,*stretcher;
+  FXint pos,w,h,t;
+  FXuint hints;
   if(options&SPLITTER_VERTICAL){          // Vertical
     if(options&SPLITTER_REVERSED){
       pos=height;
@@ -191,6 +194,10 @@ void FXSplitter::layout(){
         if(child->shown()){
           w=child->getWidth();
           h=child->getHeight();
+          hints=child->getLayoutHints();
+          if((hints&LAYOUT_FILL_Y)&&(hints&LAYOUT_FIX_HEIGHT)){
+            if((t=child->getDefaultHeight())>h) h=t;
+            }
           if(w<=1 && h<=1) h=child->getDefaultHeight();
           if(child==stretcher){ h=pos; if(h<0) h=0; }
           child->position(0,pos-h,width,h);
@@ -210,6 +217,10 @@ void FXSplitter::layout(){
         if(child->shown()){
           w=child->getWidth();
           h=child->getHeight();
+          hints=child->getLayoutHints();
+          if((hints&LAYOUT_FILL_Y)&&(hints&LAYOUT_FIX_HEIGHT)){
+            if((t=child->getDefaultHeight())>h) h=t;
+            }
           if(w<=1 && h<=1) h=child->getDefaultHeight();
           if(child==stretcher){ h=height-pos; if(h<0) h=0; }
           child->position(0,pos,width,h);
@@ -231,6 +242,10 @@ void FXSplitter::layout(){
         if(child->shown()){
           w=child->getWidth();
           h=child->getHeight();
+          hints=child->getLayoutHints();
+          if((hints&LAYOUT_FILL_X)&&(hints&LAYOUT_FIX_WIDTH)){
+            if((t=child->getDefaultWidth())>w) w=t;
+            }
           if(w<=1 && h<=1) w=child->getDefaultWidth();
           if(child==stretcher){ w=pos; if(w<0) w=0; }
           child->position(pos-w,0,w,height);
@@ -250,6 +265,10 @@ void FXSplitter::layout(){
         if(child->shown()){
           w=child->getWidth();
           h=child->getHeight();
+          hints=child->getLayoutHints();
+          if((hints&LAYOUT_FILL_X)&&(hints&LAYOUT_FIX_WIDTH)){
+            if((t=child->getDefaultWidth())>w) w=t;
+            }
           if(w<=1 && h<=1) w=child->getDefaultWidth();
           if(child==stretcher){ w=width-pos; if(w<0) w=0; }
           child->position(pos,0,w,height);
@@ -569,8 +588,10 @@ long FXSplitter::onFocusUp(FXObject*,FXSelector,void* ptr){
     else
       child=getLast();
     while(child){
-      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-      if(child->handle(this,FXSEL(SEL_FOCUS_UP,0),ptr)) return 1;
+      if(child->shown()){
+        if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+        if(child->handle(this,FXSEL(SEL_FOCUS_UP,0),ptr)) return 1;
+        }
       child=child->getPrev();
       }
     }
@@ -587,8 +608,10 @@ long FXSplitter::onFocusDown(FXObject*,FXSelector,void* ptr){
     else
       child=getFirst();
     while(child){
-      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-      if(child->handle(this,FXSEL(SEL_FOCUS_DOWN,0),ptr)) return 1;
+      if(child->shown()){
+        if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+        if(child->handle(this,FXSEL(SEL_FOCUS_DOWN,0),ptr)) return 1;
+        }
       child=child->getNext();
       }
     }
@@ -605,8 +628,10 @@ long FXSplitter::onFocusLeft(FXObject*,FXSelector,void* ptr){
     else
       child=getLast();
     while(child){
-      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-      if(child->handle(this,FXSEL(SEL_FOCUS_LEFT,0),ptr)) return 1;
+      if(child->shown()){
+        if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+        if(child->handle(this,FXSEL(SEL_FOCUS_LEFT,0),ptr)) return 1;
+        }
       child=child->getPrev();
       }
     }
@@ -623,8 +648,10 @@ long FXSplitter::onFocusRight(FXObject*,FXSelector,void* ptr){
     else
       child=getFirst();
     while(child){
-      if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
-      if(child->handle(this,FXSEL(SEL_FOCUS_RIGHT,0),ptr)) return 1;
+      if(child->shown()){
+        if(child->handle(this,FXSEL(SEL_FOCUS_SELF,0),ptr)) return 1;
+        if(child->handle(this,FXSEL(SEL_FOCUS_RIGHT,0),ptr)) return 1;
+        }
       child=child->getNext();
       }
     }
