@@ -3,7 +3,7 @@
 *                         T o p   W i n d o w   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTopWindow.cpp,v 1.121 2003/10/23 04:19:45 fox Exp $                    *
+* $Id: FXTopWindow.cpp,v 1.127.2.1 2004/08/13 05:16:16 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -252,8 +252,6 @@ void FXTopWindow::create(){
       size.base_height=0;
       if(!(options&DECOR_SHRINKABLE)){          // Can not shrink, so set min size
         size.flags|=PMinSize|PBaseSize;
-        //size.min_width=width;
-        //size.min_height=height;
         size.min_width=getDefaultWidth();
         size.min_height=getDefaultHeight();
         size.base_width=width;
@@ -263,8 +261,6 @@ void FXTopWindow::create(){
       size.max_height=0;
       if(!(options&DECOR_STRETCHABLE)){         // Can not grow, so set max size
         size.flags|=PMaxSize;
-        //size.max_width=width;
-        //size.max_height=height;
         size.max_width=getDefaultWidth();
         size.max_height=getDefaultHeight();
         }
@@ -292,6 +288,16 @@ void FXTopWindow::create(){
 
       // Set icon for X-Windows
       seticons();
+
+      // Tweak needed because the options affect window size
+#ifdef WIN32
+      RECT rect;
+      SetRect(&rect,xpos,ypos,xpos+width,ypos+height);
+      DWORD dwStyle=GetWindowLong((HWND)xid,GWL_STYLE);
+      DWORD dwExStyle=GetWindowLong((HWND)xid,GWL_EXSTYLE);
+      AdjustWindowRectEx(&rect,dwStyle,FALSE,dwExStyle);
+      SetWindowPos((HWND)xid,NULL,rect.left,rect.top,FXMAX(rect.right-rect.left,1),FXMAX(rect.bottom-rect.top,1),SWP_NOZORDER|SWP_NOOWNERZORDER);
+#endif
       }
     }
   }
@@ -398,10 +404,71 @@ void FXTopWindow::place(FXuint placement){
   wh=getHeight();
 
   // Get root window size
+#ifndef WIN32
   rx=getRoot()->getX();
   ry=getRoot()->getY();
   rw=getRoot()->getWidth();
   rh=getRoot()->getHeight();
+#else
+  OSVERSIONINFO vinfo;
+  RECT rect;
+  memset(&vinfo,0,sizeof(vinfo));
+  vinfo.dwOSVersionInfoSize=sizeof(vinfo);
+  GetVersionEx(&vinfo);
+
+#if (WINVER >= 0x500) || ((defined _WIN32_WINDOWS) && (_WIN32_WINDOWS >= 0x410))
+  HINSTANCE user32;
+  typedef BOOL (WINAPI* PFN_GETMONITORINFOA)(HMONITOR, LPMONITORINFO);
+  typedef HMONITOR (WINAPI* PFN_MONITORFROMRECTA)(LPRECT, DWORD);
+  PFN_GETMONITORINFOA GetMonitorInfoA;
+  PFN_MONITORFROMRECTA MonitorFromRectA;
+
+  // Suggested by "Daniel Gehriger" <gehriger@linkcad.com>
+  // The API does not exist on older Windows NT and 95, so
+  // We can't even link it, let alone call it.
+  // The solution is to ask the DLL if the function exists.
+  if((user32=LoadLibrary("User32")) && (GetMonitorInfoA=reinterpret_cast<PFN_GETMONITORINFOA>(GetProcAddress(user32,"GetMonitorInfoA"))) && (MonitorFromRectA=reinterpret_cast<PFN_MONITORFROMRECTA>(GetProcAddress(user32,"MonitorFromRectA")))){
+    MONITORINFOEX minfo;
+    HMONITOR hMon;
+    if(placement == PLACEMENT_CURSOR){
+      // Use mouse position to select screen.
+      getRoot()->getCursorPosition(x,y,state);
+      rect.left=x;
+      rect.right=x+1;
+      rect.top=y;
+      rect.bottom=y+1;
+      }
+    else{
+      // Use owner to select screen.
+      over=getOwner()?getOwner():getRoot();
+      over->translateCoordinatesTo(ox,oy,getRoot(),0,0);
+      ow=over->getWidth();
+      oh=over->getHeight();
+      rect.left=ox;
+      rect.right=ox+ow;
+      rect.top=oy;
+      rect.bottom=oy+oh;
+      }
+    hMon=MonitorFromRectA(&rect,MONITOR_DEFAULTTOPRIMARY);
+    memset(&minfo,0,sizeof(minfo));
+    minfo.cbSize=sizeof(minfo);
+    GetMonitorInfoA(hMon,&minfo);
+    rx=minfo.rcWork.left;
+    ry=minfo.rcWork.top;
+    rw=minfo.rcWork.right;
+    rh=minfo.rcWork.bottom;
+    }
+  else
+#endif
+    {
+    // On Win95 and WinNT, we have to use the following
+    SystemParametersInfo(SPI_GETWORKAREA,sizeof(RECT),&rect,0);
+    rx=rect.left;
+    ry=rect.top;
+    rw=rect.right-rect.left;
+    rh=rect.bottom-rect.top;
+    }
+#endif
 
   // Placement policy
   switch(placement){
@@ -418,7 +485,7 @@ void FXTopWindow::place(FXuint placement){
       // Place such that mouse in the middle, placing it as
       // close as possible in the center of the owner window.
       // Don't move the window unless the mouse is not inside.
-      if((wx==0 && wy==0) || x<wx || y<wy || wx+ww<=x || wy+wh<=y){
+      if(!shown() || x<wx || y<wy || wx+ww<=x || wy+wh<=y){
 
         // Get the owner
         over=getOwner()?getOwner():getRoot();
@@ -635,9 +702,11 @@ void FXTopWindow::setdecorations(){
 
   // Get old style
   DWORD dwStyle=GetWindowLong((HWND)xid,GWL_STYLE);
-  DWORD dwExStyle=GetWindowLong((HWND)xid,GWL_EXSTYLE);
   RECT rect;
 
+  // Moved here just in case the size changes behind our backs
+  SetRect(&rect,0,0,width,height);
+
   // Change style setting; note, under Windows, if we want a minimize,
   // maximize, or close button, we also need a window menu style as well.
   // Also, if you want a title, you will need a border.
@@ -661,8 +730,11 @@ void FXTopWindow::setdecorations(){
       EnableMenuItem(sysmenu,SC_CLOSE,MF_GRAYED);
     }
 
+  // Moved here just in case SetWindowLong GWL_STYLE has changed
+  // the GWL_EXSTYLE behind the scenes...
+  DWORD dwExStyle=GetWindowLong((HWND)xid,GWL_EXSTYLE);
+
   // Adjust non-client area size based on new style
-  SetRect(&rect,0,0,width,height);
   AdjustWindowRectEx(&rect,dwStyle,FALSE,dwExStyle);
   SetWindowPos((HWND)xid,NULL,0,0,FXMAX(rect.right-rect.left,1),FXMAX(rect.bottom-rect.top,1),SWP_NOMOVE|SWP_NOZORDER|SWP_NOOWNERZORDER);
   RedrawWindow((HWND)xid,NULL,NULL,RDW_FRAME|RDW_INVALIDATE);
