@@ -3,7 +3,7 @@
 *                            W i n d o w   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * Major Contributions for Windows NT by Lyle Johnson                            *
 *********************************************************************************
@@ -21,7 +21,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXWindow.cpp,v 1.242 2003/10/23 12:15:30 fox Exp $                       *
+* $Id: FXWindow.cpp,v 1.249 2004/04/30 03:44:51 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -47,7 +47,7 @@
 #include "FXShell.h"
 #include "FXTopWindow.h"
 
-
+#include "FXStatusLine.h"
 
 /*
  Notes:
@@ -201,6 +201,8 @@ const FXDragType FXWindow::imageType=XA_PIXMAP;
 const FXDragType FXWindow::imageType=CF_DIB;
 #endif
 
+// Number of windows
+FXint FXWindow::windowCount=0;
 
 /*******************************************************************************/
 
@@ -208,6 +210,7 @@ const FXDragType FXWindow::imageType=CF_DIB;
 // For deserialization
 FXWindow::FXWindow(){
   FXTRACE((100,"FXWindow::FXWindow %p\n",this));
+  windowCount++;
   parent=(FXWindow*)-1L;
   owner=(FXWindow*)-1L;
   first=(FXWindow*)-1L;
@@ -232,6 +235,7 @@ FXWindow::FXWindow(){
 // Only used for the root window
 FXWindow::FXWindow(FXApp* a,FXVisual *vis):FXDrawable(a,1,1){
   FXTRACE((100,"FXWindow::FXWindow %p\n",this));
+  windowCount++;
   visual=vis;
   parent=NULL;
   owner=NULL;
@@ -255,6 +259,7 @@ FXWindow::FXWindow(FXApp* a,FXVisual *vis):FXDrawable(a,1,1){
 // This constructor is used for shell windows
 FXWindow::FXWindow(FXApp* a,FXWindow* own,FXuint opts,FXint x,FXint y,FXint w,FXint h):FXDrawable(a,w,h){
   FXTRACE((100,"FXWindow::FXWindow %p\n",this));
+  windowCount++;
   parent=a->root;
   owner=own;
   visual=getApp()->getDefaultVisual();
@@ -287,6 +292,7 @@ FXWindow::FXWindow(FXApp* a,FXWindow* own,FXuint opts,FXint x,FXint y,FXint w,FX
 // This constructor is used for all child windows
 FXWindow::FXWindow(FXComposite* p,FXuint opts,FXint x,FXint y,FXint w,FXint h):FXDrawable(p->getApp(),w,h){
   FXTRACE((100,"FXWindow::FXWindow %p\n",this));
+  windowCount++;
   parent=p;
   owner=parent;
   visual=parent->getVisual();
@@ -1253,6 +1259,9 @@ void FXWindow::create(){
         SetProp((HWND)xid,(LPCTSTR)MAKELONG(getApp()->xdndAware,0),propdata);
         }
 
+      // To keep it on top
+      //SetWindowPos((HWND)xid,HWND_TOPMOST,xpos,ypos,FXMAX(width,1),FXMAX(height,1),0);
+
       // Show if it was supposed to be.  Apparently, initial state
       // is neither shown nor hidden, so an explicit hide is needed.
       // Patch thanks to "Glenn Shen" <shen@hks.com>
@@ -1349,7 +1358,7 @@ void FXWindow::destroy(){
   if(xid){
     if(getApp()->isInitialized()){
       FXTRACE((100,"%s::destroy %p\n",getClassName(),this));
-      
+
       // Remove from xid to C++ object mapping
       getApp()->hash.remove((void*)xid);
 
@@ -3099,6 +3108,7 @@ FXbool FXWindow::endDrag(FXbool drop){
 // Delete window
 FXWindow::~FXWindow(){
   FXTRACE((100,"FXWindow::~FXWindow %p\n",this));
+  windowCount--;
   destroy();
   delete accelTable;
   if(prev) prev->next=next; else if(parent) parent->first=next;
@@ -3119,7 +3129,7 @@ FXWindow::~FXWindow(){
   owner=(FXWindow*)-1L;
   first=last=(FXWindow*)-1L;
   next=prev=(FXWindow*)-1L;
-  focus=(FXWindow*)-1;
+  focus=(FXWindow*)-1L;
   defaultCursor=(FXCursor*)-1L;
   dragCursor=(FXCursor*)-1L;
   accelTable=(FXAccelTable*)-1L;
