@@ -3,7 +3,7 @@
 *                        G I F   I n p u t / O u t p u t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxgifio.cpp,v 1.61 2003/08/01 14:51:38 fox Exp $                         *
+* $Id: fxgifio.cpp,v 1.68 2004/04/24 14:12:46 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -27,7 +27,6 @@
 #include "FXStream.h"
 #include "fxpriv.h"
 
-#define USA 1
 
 /*
   Notes:
@@ -48,9 +47,7 @@
         Start     0      4      3      1
         Step      8      8      4      2
 
-  - LZW Patent has expired 6/20/2003; so compression now implemented,
-    at least in the USA; otherwise the default version still uses the
-    non-compressing variety.
+  - LZW Patent has expired 6/20/2003; so compression now implemented.
 */
 
 
@@ -61,6 +58,10 @@ using namespace FX;
 namespace FX {
 
 
+extern FXAPI FXbool fxloadGIF(FXStream& store,FXColor*& data,FXint& width,FXint& height);
+extern FXAPI FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height,FXbool fast=TRUE);
+
+
 // Codes found in the GIF specification
 const FXuchar TAG_EXTENSION   = 0x21;   // Extension block
 const FXuchar TAG_GRAPHIC     = 0xF9;   // Graphic control block
@@ -435,10 +436,8 @@ FXbool fxloadGIF(FXStream& store,FXColor*& data,FXint& width,FXint& height){
 /*******************************************************************************/
 
 
-#ifdef USA              // USA version
-
 // Save a gif file to a stream
-FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height){
+FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height,FXbool fast){
   FXuint   clearcode,endcode,freecode,findcode,prefix,current,outaccu,initcodesize,codesize,hash,step;
   FXint    maxpixels,ncolors,bitsperpixel,colormapsize,outbits,src,dst,i;
   FXuchar  c1,c2,alpha,*pixels,*output;
@@ -459,9 +458,12 @@ FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height){
   // First, try EZ quantization, because it is exact; a previously
   // loaded GIF will be re-saved with exactly the same colors.
   if(!fxezquantize(pixels,data,colormap,ncolors,width,height,256)){
-
-    // Floyd-Steinberg quantize full 24 bpp to 256 colors, organized as 3:3:2
-    fxfsquantize(pixels,data,colormap,ncolors,width,height,256);
+    if(fast){
+      fxfsquantize(pixels,data,colormap,ncolors,width,height,256);
+      }
+    else{
+      fxwuquantize(pixels,data,colormap,ncolors,width,height,256);
+      }
     }
 
   // File signature
@@ -572,7 +574,7 @@ FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height){
     findcode=(current<<12)+prefix;
     hash=findcode%5003;                 // 0<=hash<=5002
     step=findcode%4999+1;               // 1<=step<=4999
-    while(hashtab[hash]!=0xffffffff){   // Occupided slot?
+    while(hashtab[hash]!=0xffffffff){   // Occupied slot?
       if(hashtab[hash]==findcode){      // Existing prefix
         prefix=codetab[hash];           // Code for prefix
         goto nxt;
@@ -649,172 +651,5 @@ nxt:continue;
   }
 
 
-#else                   // International version
-
-
-// Save a gif file to a stream
-FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height){
-  FXuint   clearcode,endcode,prefix,outaccu,initcodesize,codesize,codecounter;
-  FXint    maxpixels,ncolors,bitsperpixel,colormapsize,outbits,src,dst,i;
-  FXuchar  c1,c2,alpha,*pixels,*output;
-  FXColor  colormap[256];
-
-  // Must make sense
-  if(!data || width<=0 || height<=0) return FALSE;
-
-  // How many pixels
-  maxpixels=width*height;
-
-  // Allocate temp buffer for pixels
-  if(!FXMALLOC(&output,FXuchar,(maxpixels<<1))) return FALSE;
-  pixels=output+maxpixels;
-
-  // First, try EZ quantization, because it is exact; a previously
-  // loaded GIF will be re-saved with exactly the same colors.
-  if(!fxezquantize(pixels,data,colormap,ncolors,width,height,256)){
-
-    // Floyd-Steinberg quantize full 24 bpp to 256 colors, organized as 3:3:2
-    fxfsquantize(pixels,data,colormap,ncolors,width,height,256);
-    }
-
-  // File signature
-  store << TAG_SIG1;
-  store << TAG_SIG2;
-  store << TAG_SIG3;
-
-  // File version
-  store << TAG_VER;
-  store << TAG_NEW;
-  store << TAG_SUF;
-
-  // Figure out bits per pixel
-  for(bitsperpixel=1; ncolors>(1<<bitsperpixel); bitsperpixel++);
-
-  // Colormap size
-  colormapsize=1<<bitsperpixel;
-
-  // Screen header
-  c1=width;
-  c2=width>>8;
-  store << c1 << c2;            // Width
-  c1=height;
-  c2=height>>8;
-  store << c1 << c2;            // Height
-  c1=0x80;                      // There is a color map
-  c1|=(bitsperpixel-1)<<4;      // Number of bits of color resolution
-  c1|=(bitsperpixel-1);         // The size (in bits) of the colormap
-  store << c1;                  // Flags
-  store << TAG_ZERO;            // Background color
-  store << TAG_ZERO;            // Aspect Ratio is none
-
-  // Output colormap
-  for(i=0; i<colormapsize; i++){
-    store << ((FXuchar*)(colormap+i))[0]; // Blue
-    store << ((FXuchar*)(colormap+i))[1]; // Green
-    store << ((FXuchar*)(colormap+i))[2]; // Red
-    }
-
-  // Output Graphics Control Extension, if alpha is present
-  for(i=0,alpha=0; i<ncolors; i++){
-    if(((FXuchar*)(colormap+i))[3]==0){
-      alpha=i;
-      store << TAG_EXTENSION;   // Extension Introducer
-      store << TAG_GRAPHIC;     // Graphic Control Label
-      store << TAG_GRAPHICSIZE; // Block Size
-      store << TAG_TRANSPARENT; // Disposal Method
-      store << TAG_ZERO;        // Delay Time
-      store << TAG_ZERO;
-      store << alpha;           // Transparent color index
-      store << TAG_TERMINATOR;  // Block Terminator
-      break;
-      }
-    }
-
-  // Image descriptor
-  store << TAG_IMAGE;           // Image separator
-  store << TAG_ZERO;            // Image offset X
-  store << TAG_ZERO;
-  store << TAG_ZERO;            // Image offset Y
-  store << TAG_ZERO;
-  c1=width;
-  c2=width>>8;
-  store << c1 << c2;            // Width
-  c1=height;
-  c2=height>>8;
-  store << c1 << c2;            // Height
-  store << TAG_IMAGEFLAGS;      // Flags: no local map, no interlace
-
-  // Figure out code size and stuff
-  initcodesize=(bitsperpixel<=1)?2:bitsperpixel;
-  codesize=initcodesize+1;
-  clearcode=1<<(codesize-1);
-  endcode=clearcode+1;
-  codecounter=clearcode+2;
-
-  // Now for the beef...
-  c1=initcodesize;
-  store << c1;                          // Write the Code size
-
-  // Output clear code
-  FXASSERT(clearcode<(1<<codesize));
-  outaccu=clearcode;
-  outbits=codesize;
-
-  // "Compress" image
-  src=dst=0;
-  while(src<maxpixels){
-
-    // Output pixel
-    prefix=pixels[src++];
-    outaccu|=prefix<<outbits;
-    outbits+=codesize;
-
-    // Flush filled out bytes
-    while(outbits>=8){
-      output[dst++]=(FXuchar)outaccu;
-      outaccu>>=8;
-      outbits-=8;
-      }
-
-    // Reset counter again?
-    if(codecounter<((1<<codesize)-1)){
-      codecounter++;
-      }
-    else{
-      outaccu|=clearcode<<outbits;
-      outbits+=codesize;
-      codecounter=clearcode+2;
-      }
-    }
-
-  // Output end code
-  outaccu|=endcode<<outbits;
-  outbits+=codesize;
-
-  // FLush remaining bits out
-  while(outbits>0){
-    output[dst++]=(FXuchar)outaccu;
-    outaccu>>=8;
-    outbits-=8;
-    }
-
-  // Write blocks
-  for(src=0; src<dst; src+=c1){
-    c1=FXMIN(255,(dst-src));
-    store << c1;
-    store.save(&output[src],c1);
-    }
-
-  // Trailer
-  store << TAG_TERMINATOR;      // Block terminator
-  store << TAG_ENDFILE;         // File terminator
-
-  // Free storage
-  FXFREE(&output);
-  return TRUE;
-  }
-
-#endif
-
 }
 
