@@ -20,7 +20,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxicoio.cpp,v 1.18 2003/09/13 20:10:48 fox Exp $                         *
+* $Id: fxicoio.cpp,v 1.22.2.1 2004/08/13 05:16:16 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -50,6 +50,10 @@ using namespace FX;
 
 namespace FX {
 
+extern FXAPI FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
+extern FXAPI FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot=-1,FXint yspot=-1);
+
+
 
 static inline FXuint read16(FXStream& store){
   FXuchar c1,c2;
@@ -66,7 +70,7 @@ static inline FXuint read32(FXStream& store){
 
 
 // Load ICO image from stream
-FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height){
+FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot){
   unsigned long base,header;
   FXColor  colormap[256],*pp;
   FXshort  idReserved;
@@ -76,8 +80,6 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height){
   FXuchar  bHeight;
   FXuchar  bColorCount;
   FXuchar  bReserved;
-  FXshort  wPlanes;
-  FXshort  wBitCount;
   FXint    dwBytesInRes;
   FXint    dwImageOffset;
   FXint    biSize;
@@ -104,29 +106,29 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height){
   base=store.position();
 
   // IconHeader
-  idReserved=read16(store);
-  idType=read16(store);
-  idCount=read16(store);
+  idReserved=read16(store);     // Must be 0
+  idType=read16(store);         // ICO=1, CUR=2
+  idCount=read16(store);        // Number of images
 
   FXTRACE((1,"fxloadICO: idReserved=%d idType=%d idCount=%d\n",idReserved,idType,idCount));
 
   // Check
-  if(idReserved!=0 || idType!=1 || idCount<1) return FALSE;
+  if(idReserved!=0 || (idType!=1 && idType!=2) || idCount<1) return FALSE;
 
   // IconDirectoryEntry
   store >> bWidth;
   store >> bHeight;
   store >> bColorCount;
   store >> bReserved;
-  wPlanes=read16(store);
-  wBitCount=read16(store);
+  xspot = read16(store);
+  yspot = read16(store);
   dwBytesInRes=read32(store);
   dwImageOffset=read32(store);
 
-  FXTRACE((1,"fxloadICO: bWidth=%d bHeight=%d bColorCount=%d bReserved=%d wPlanes=%d wBitCount=%d dwBytesInRes=%d dwImageOffset=%d\n",bWidth,bHeight,bColorCount,bReserved,wPlanes,wBitCount,dwBytesInRes,dwImageOffset));
+  FXTRACE((1,"fxloadICO: bWidth=%d bHeight=%d bColorCount=%d bReserved=%d xspot=%d yspot=%d dwBytesInRes=%d dwImageOffset=%d\n",bWidth,bHeight,bColorCount,bReserved,xspot,yspot,dwBytesInRes,dwImageOffset));
 
-  // Only certain color counts allowed
-  if(bColorCount!=0 && bColorCount!=2 && bColorCount!=8 && bColorCount!=16 && bColorCount!=256) return FALSE;
+  // Only certain color counts allowed; bColorCount=0 means 256 colors supposedly
+  if(bColorCount!=0 && bColorCount!=2 && bColorCount!=4 && bColorCount!=8 && bColorCount!=16) return FALSE;
 
   // Jump to BitmapInfoHeader
   store.position(base+dwImageOffset);
@@ -283,6 +285,7 @@ FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height){
       }
     }
 
+  FXTRACE((1,"OK\n"));
   return TRUE;
   }
 
@@ -308,7 +311,7 @@ static inline void write32(FXStream& store,FXuint i){
 
 
 // Save a ICO file to a stream
-FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height){
+FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height,FXint xspot,FXint yspot){
   const FXint    biSize=40;
   const FXshort  biPlanes=1;
   const FXint    biCompression=BIH_RGB;
@@ -317,16 +320,14 @@ FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height){
   const FXint    biClrUsed=0;
   const FXint    biClrImportant=0;
   const FXshort  idReserved=0;
-  const FXshort  idType=1;
   const FXshort  idCount=1;
   const FXuchar  bReserved=0;
   const FXuchar  bColorCount=0;
   const FXint    dwImageOffset=22;
-  const FXshort  wPlanes=0;
-  const FXshort  wBitCount=0;
   const FXColor *pp;
   const FXuchar  padding[3]={0,0,0};
   FXshort        biBitCount=24;
+  FXshort        idType=2;
   FXint          biSizeImage=width*height*3;
   FXint          dwBytesInRes=biSize+biSizeImage+height*(width>>3);
   FXuchar        bWidth=(FXuchar)width;
@@ -342,9 +343,12 @@ FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height){
     if(((FXuchar*)(data+i))[3]<255){ biBitCount=32; break; }
     }
 
+  // If no hot-spot given, save as an icon instead of a cursor
+  if(xspot<0 || yspot<0){ xspot=yspot=0; idType=1; }
+
   // IconHeader
   write16(store,idReserved);    // Must be zero
-  write16(store,idType);        // Must be 1
+  write16(store,idType);        // Must be 1 or 2
   write16(store,idCount);       // Only one icon
 
   // IconDirectoryEntry
@@ -352,8 +356,8 @@ FXbool fxsaveICO(FXStream& store,const FXColor *data,FXint width,FXint height){
   store << bHeight;
   store << bColorCount;         // 0 for > 8bit/pixel
   store << bReserved;
-  write16(store,wPlanes);
-  write16(store,wBitCount);
+  write16(store,xspot);
+  write16(store,yspot);
   write32(store,dwBytesInRes);  // Total number of bytes in images (including palette data)
   write32(store,dwImageOffset); // Location of image from the beginning of file
 
