@@ -3,7 +3,7 @@
 *              P r i v a t e   I n t e r n a l   F u n c t i o n s              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxpriv.cpp,v 1.30 2003/10/30 22:02:45 fox Exp $                          *
+* $Id: fxpriv.cpp,v 1.32.2.1 2004/08/13 05:16:16 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -340,7 +340,7 @@ void FXApp::clipboardGetTypes(const FXWindow* window,FXDragType*& types,FXuint&
   numtypes=0;
   if(clipboardWindow){
     FXMEMDUP(&types,xcbTypeList,FXDragType,xcbNumTypes);
-    numtypes=xselNumTypes;
+    numtypes=xcbNumTypes;
     }
   else{
     answer=fxsendrequest((Display*)display,window->id(),xcbSelection,ddeAtom,ddeTargets,event.time);
@@ -389,6 +389,32 @@ void FXApp::dragdropGetTypes(const FXWindow*,FXDragType*& types,FXuint& numtypes
   numtypes=ddeNumTypes;
   }
 
+
+// Make GC for given visual and depth; graphics exposures optional
+GC fxmakegc(Display *display,Visual* visual,FXint depth,FXbool gex){
+  XGCValues gval;
+  FXID drawable;
+  GC gg;
+
+  gval.fill_style=FillSolid;
+  gval.graphics_exposures=gex;
+
+  // For default visual; this is easy as we already have a matching window
+  if(visual==DefaultVisual(display,DefaultScreen(display))){
+    gg=XCreateGC(display,XDefaultRootWindow(display),GCFillStyle|GCGraphicsExposures,&gval);
+    }
+
+  // For arbitrary visual; create a temporary pixmap of the same depth as the visual
+  else{
+    drawable=XCreatePixmap(display,XDefaultRootWindow(display),1,1,depth);
+    gg=XCreateGC(display,drawable,GCFillStyle|GCGraphicsExposures,&gval);
+    XFreePixmap(display,drawable);
+    }
+
+  return gg;
+  }
+
+
 /*******************************************************************************/
 
 // MSWIN
