@@ -3,7 +3,7 @@
 *              P r i v a t e   I n t e r n a l   F u n c t i o n s              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxpriv.h,v 1.23 2003/10/29 14:39:00 fox Exp $                            *
+* $Id: fxpriv.h,v 1.26 2004/04/24 02:15:54 fox Exp $                            *
 ********************************************************************************/
 
 namespace FX {
@@ -69,6 +69,10 @@ extern FXbool fxfsquantize(FXuchar* p8,const FXColor* p32,FXColor* colormap,FXin
 // repeatedly loading and saving the same file!
 extern FXbool fxezquantize(FXuchar* dst,const FXColor* src,FXColor* colormap,FXint& actualcolors,FXint w,FXint h,FXint maxcolors);
 
+
+// Xiaolin Wu's quantization method based on recursive partitioning 
+extern FXbool fxwuquantize(FXuchar* dst,const FXColor* src,FXColor* colormap,FXint& actualcolors,FXint w,FXint h,FXint maxcolors);
+
 }
 
 using namespace FX;
@@ -81,6 +85,7 @@ extern FXAPI Atom fxsendtypes(Display *display,Window window,Atom prop,FXDragTyp
 extern FXAPI Atom fxrecvtypes(Display *display,Window window,Atom prop,FXDragType*& types,FXuint& numtypes);
 extern FXAPI Atom fxsenddata(Display *display,Window window,Atom prop,Atom type,FXuchar* data,FXuint size);
 extern FXAPI Atom fxrecvdata(Display *display,Window window,Atom prop,Atom incr,Atom& type,FXuchar*& data,FXuint& size);
+extern FXAPI GC fxmakegc(Display *display,Visual* visual,FXint depth,FXbool gex);
 #endif
 
 // Windows helpers
