@@ -3,7 +3,7 @@
 *                          T I F F   I n p u t / O u t p u t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2003 Eric Gillet.   All Rights Reserved.                   *
+* Copyright (C) 2001,2004 Eric Gillet.   All Rights Reserved.                   *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxtifio.cpp,v 1.23 2003/08/01 14:51:38 fox Exp $                         *
+* $Id: fxtifio.cpp,v 1.27 2004/04/08 16:24:48 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -43,6 +43,7 @@
   - FOX keeps order in FXColor to RGBA (i.e. red at lowest memory
     address, alpha at highest). Currently not known if this does
     or does not require swapping when read in.
+  - Updated for libtiff 3.6.1.
 */
 
 
@@ -56,6 +57,10 @@ using namespace FX;
 namespace FX {
 
 
+extern FXAPI FXbool fxloadTIF(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXushort& codec);
+extern FXAPI FXbool fxsaveTIF(FXStream& store,const FXColor* data,FXint width,FXint height,FXushort codec);
+
+
 #ifdef HAVE_TIFF_H
 
 
@@ -72,7 +77,7 @@ struct tiff_store_handle {
 static void fxerrorhandler(const char* module,const char* format,va_list args){
   FXchar message[1024];
   vsprintf(message,format,args);
-  fxwarning("error: in %s: %s\n",module,message);
+  FXTRACE((100,"error: in %s: %s\n",module,message));
   }
 
 
@@ -80,7 +85,7 @@ static void fxerrorhandler(const char* module,const char* format,va_list args){
 static void fxwarninghandler(const char* module,const char* format,va_list args){
   FXchar message[1024];
   vsprintf(message,format,args);
-  fxwarning("warning: in %s: %s\n",module,message);
+  FXTRACE((100,"warning: in %s: %s\n",module,message));
   }
 
 
@@ -134,6 +139,17 @@ static int tif_close_store(thandle_t){
   }
 
 
+// Dummy map file
+static int tif_map_store(thandle_t, tdata_t*, toff_t*){
+  return 0;
+  }
+
+
+// Dummy unmap file
+static void tif_unmap_store(thandle_t, tdata_t, toff_t){
+  }
+
+
 // Compute size of what's been written
 static toff_t tif_size_store(thandle_t handle){
   tiff_store_handle *h=(tiff_store_handle*)handle;
@@ -167,7 +183,7 @@ FXbool fxloadTIF(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXush
   s_handle.error=FALSE;
 
   // Open image
-  image=TIFFClientOpen("tiff","rm",(thandle_t)&s_handle,tif_read_store,tif_write_store,tif_seek_store,tif_close_store,tif_size_store,NULL,NULL);
+  image=TIFFClientOpen("tiff","rm",(thandle_t)&s_handle,tif_read_store,tif_write_store,tif_seek_store,tif_close_store,tif_size_store,tif_map_store,tif_unmap_store);
   if(!image) return FALSE;
 
   // We try to remember the codec for later when we save the image back out...
@@ -207,18 +223,7 @@ FXbool fxloadTIF(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXush
       for(i=0; i<width; i++){ t=up[i]; up[i]=dn[i]; dn[i]=t; }
       }
     }
-/*
-#if FOX_BIGENDIAN == 1
-  if(ret){
-    FXPixel *pix_data = (FXPixel*)data;
-    size = img.width * img.height;
-    while(size--){
-      *pix_data = TIFF_SWAP(*pix_data);
-      pix_data++;
-      }
-    }
-#endif
-*/
+
   TIFFRGBAImageEnd(&img);
   TIFFClose(image);
   return TRUE;
@@ -258,7 +263,7 @@ FXbool fxsaveTIF(FXStream& store,const FXColor* data,FXint width,FXint height,FX
   s_handle.error=FALSE;
 
   // Open image
-  image=TIFFClientOpen("tiff","w",(thandle_t)&s_handle,tif_dummy_read_store,tif_write_store,tif_seek_store,tif_close_store,tif_size_store,NULL,NULL);
+  image=TIFFClientOpen("tiff","w",(thandle_t)&s_handle,tif_dummy_read_store,tif_write_store,tif_seek_store,tif_close_store,tif_size_store,tif_map_store,tif_unmap_store);
   if(!image) return FALSE;
 
   // Size of a strip is 16kb
