@@ -3,7 +3,7 @@
 *                   V a r a r g s   S c a n f   R o u t i n e s                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2002,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2002,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: vsscanf.cpp,v 1.8 2003/07/25 19:13:35 fox Exp $                          *
+* $Id: vsscanf.cpp,v 1.12.2.2 2004/08/13 05:16:16 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -29,6 +29,14 @@
 /*
   Notes:
   - Needs checking for conformance with standard scanf.
+  - Some POSIX finesse:
+    u,d is equivalent to strtol (strtoul) with base = 10.
+    x   is equivalent to strtoul with base = 16
+    o   is equivalent to strtoul with base = 8
+    i   is equivalent to strtol with base = 0 (which means either
+        octal, hex, or decimal as determined by leading 2 characters).
+  - Rewrite in terms of strtol, strtoul strtod; these are available since we're
+    already using them and have heard no complaints.
 */
 
 #ifndef HAVE_VSSCANF
@@ -47,7 +55,6 @@ extern "C" int vsscanf(const char* str, const char* format, va_list arg_ptr);
 
 /*******************************************************************************/
 
-namespace {
 
 struct arg_scanf {
   void *data;
@@ -60,13 +67,13 @@ struct str_data {
   };
 
 
-int sgetc(struct str_data* sd){
-  register unsigned int ret = *(sd->str++);
-  return (ret)?(int)ret:-1;
+static int sgetc(struct str_data* sd){
+  register unsigned int ret = *sd->str++;
+  return ret ? (int)ret : -1;
   }
 
-int sputc(int c, struct str_data* sd){
-  return (*(--sd->str)==c)?c:-1;
+static int sputc(int c,struct str_data* sd){
+  return (*--sd->str==c)?c:-1;
   }
 
 
@@ -74,7 +81,7 @@ int sputc(int c, struct str_data* sd){
 #define A_PUTC(c,fn)	(--consumed,(fn)->putch((c),(fn)->data))
 
 
-int __v_scanf(arg_scanf* fn,const char *format,va_list arg_ptr){
+static int __v_scanf(arg_scanf* fn,const char *format,va_list arg_ptr){
   int flag_not,flag_dash,flag_width,flag_discard,flag_half,flag_long,flag_longlong;
   unsigned int ch,_div,consumedsofar,consumed;
   unsigned long v;
@@ -93,9 +100,9 @@ int __v_scanf(arg_scanf* fn,const char *format,va_list arg_ptr){
   n=0;
 
   /* get one char */
-  tpch= A_GETC(fn);
+  tpch=A_GETC(fn);
 
-  while((tpch!=-1) && (*format)){
+  while(tpch!=-1 && *format){
     ch=(unsigned int)*format++;
     switch(ch){
       case 0:                                           // End of the format string
@@ -106,7 +113,7 @@ int __v_scanf(arg_scanf* fn,const char *format,va_list arg_ptr){
       case '\v':
       case '\n':
       case '\r':
-        while((*format) && (isspace(*format))) ++format;
+        while(*format && isspace(*format)) ++format;
         while(isspace(tpch)) tpch=A_GETC(fn);
         break;
       case '%':                                         // Format string %
@@ -158,11 +165,11 @@ in_scan:ch=*format++;
           case 'x':                                     // Hexadecimal
             _div+=6;
           case 'd':                                     // Decimal
+          case 'u':
             _div+=2;
           case 'o':                                     // Octal
             _div+=8;
-          case 'u':                                     // These may be decimal, octal, or hex
-          case 'i':
+          case 'i':                                     // 'i' may be decimal, octal, or hex
             v=0;
             consumedsofar=consumed;
             while(isspace(tpch)) tpch=A_GETC(fn);
@@ -171,7 +178,9 @@ in_scan:ch=*format++;
               tpch=A_GETC(fn);
               neg=1;
               }
-            if(tpch=='+') tpch=A_GETC(fn);
+            else if(tpch=='+'){
+              tpch=A_GETC(fn);
+              }
             if((_div==16) && (tpch=='0')) goto scan_hex;
             if(!_div){
               _div=10;
@@ -198,7 +207,7 @@ scan_hex:       tpch=A_GETC(fn);
                 v=(neg)?LONG_MIN:LONG_MAX;
                 }
               else{
-                if(neg) v*=-1;
+                if(neg) v*=-1L;
                 }
               }
             if(!flag_discard){
@@ -228,7 +237,9 @@ scan_hex:       tpch=A_GETC(fn);
               tpch=A_GETC(fn);
               neg=1;
               }
-            if(tpch=='+') tpch=A_GETC(fn);
+            else if(tpch=='+'){
+              tpch=A_GETC(fn);
+              }
             while(isdigit(tpch)){
               d=d*10.0+(tpch-'0');
               tpch=A_GETC(fn);
@@ -269,7 +280,8 @@ scan_hex:       tpch=A_GETC(fn);
                 --exp;
                 }
               }
-exp_out:    if(!flag_discard){
+exp_out:    if(neg) d=-d;
+            if(!flag_discard){
               if(flag_long){
                 pd=(double *)va_arg(arg_ptr,double*);
                 *pd=d;
@@ -312,15 +324,15 @@ exp_out:    if(!flag_discard){
             break;
           case '[':                                     // Character set
             memset(cset,0,sizeof(cset));
-            ch=*format++;
+            ch=*format;
             flag_not=0;
             if(ch=='^'){                                // Negated character set
               flag_not=1;
-              ch=*format++;
+              ch=*++format;
               }
-            if((ch=='-')||(ch==']')){                   // Special case if first is - or ]
+            if(ch=='-' || ch==']'){                     // Special case if first is - or ]
               cset[ch]=1;
-              ch=*format++;
+              ch=*++format;
               }
             flag_dash=0;
             for( ; *format && *format!=']'; ++format){  // Parse set
@@ -338,7 +350,7 @@ exp_out:    if(!flag_discard){
                 }
               }
             if(flag_dash)                               // Last character
-              cset['-']=1;
+              cset[(int)'-']=1;
             else
               cset[ch]=1;
             if(!flag_discard){                          // Copy string if not discarded
@@ -371,9 +383,6 @@ err_out:
   }
 
 
-}
-
-
 // API
 int vfscanf(FILE *stream,const char *format,va_list arg_ptr){
   arg_scanf farg={(void*)stream,(int(*)(void*))fgetc,(int(*)(int,void*))ungetc};
