@@ -5,7 +5,7 @@
 *********************************************************************************
 * Copyright (C) 1997 by Jeroen van der Zijp.   All Rights Reserved.             *
 *********************************************************************************
-* $Id: groupbox.cpp,v 1.73 2003/09/24 17:11:31 fox Exp $                        *
+* $Id: groupbox.cpp,v 1.86 2004/03/25 16:30:25 fox Exp $                        *
 ********************************************************************************/
 #include "fx.h"
 #include <stdio.h>
@@ -29,6 +29,7 @@ protected:
   FXMenuPane*        helpmenu;
   FXMenuPane*        editmenu;
   FXMenuPane*        submenu1;
+  FXScrollPane*      scrollpane;
   FXPopup*           pop;
   FXPopup*           coolpop;
   FXHorizontalFrame* contents;
@@ -124,6 +125,7 @@ FXIMPLEMENT(GroupWindow,FXMainWindow,GroupWindowMap,ARRAYNUMBER(GroupWindowMap))
 
 /*******************************************************************************/
 
+
 const unsigned char minidoc1[]={
   0x47,0x49,0x46,0x38,0x37,0x61,0x10,0x00,0x10,0x00,0xf1,0x00,0x00,0xbf,0xbf,0xbf,
   0x00,0x00,0x00,0xff,0xff,0xff,0x7f,0x7f,0x7f,0x2c,0x00,0x00,0x00,0x00,0x10,0x00,
@@ -211,6 +213,28 @@ GroupWindow::GroupWindow(FXApp* a):
     FXTextField* poptext=new FXTextField(popupmenu,10,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP,0,0,0,0);
     poptext->setText("Popup with text");
 
+  scrollpane=new FXScrollPane(this,10,PACK_UNIFORM_HEIGHT);
+  new FXMenuCommand(scrollpane,"One");
+  new FXMenuCommand(scrollpane,"Two");
+  new FXMenuCommand(scrollpane,"Three");
+  new FXMenuCommand(scrollpane,"Four");
+  new FXMenuCommand(scrollpane,"Five");
+  new FXMenuCommand(scrollpane,"Six");
+  new FXMenuCommand(scrollpane,"Seven");
+  new FXMenuCommand(scrollpane,"Eight");
+  new FXMenuCommand(scrollpane,"Nine");
+  new FXMenuCommand(scrollpane,"Ten");
+  new FXMenuCommand(scrollpane,"Eleven");
+  new FXMenuCommand(scrollpane,"Twelve");
+  new FXMenuCommand(scrollpane,"Thirteen");
+  new FXMenuCommand(scrollpane,"Fourteen");
+  new FXMenuCommand(scrollpane,"Fifteen");
+  new FXMenuCommand(scrollpane,"Sixteen");
+  new FXMenuCommand(scrollpane,"Seventeen");
+  new FXMenuCommand(scrollpane,"Eighteen");
+  new FXMenuCommand(scrollpane,"Nineteen");
+  new FXMenuCommand(scrollpane,"Twenty");
+  new FXMenuTitle(menubar,"&Scroll",NULL,scrollpane);
 
   // Status bar
   FXStatusBar *status=new FXStatusBar(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|STATUSBAR_WITH_DRAGCORNER);
@@ -224,8 +248,8 @@ GroupWindow::GroupWindow(FXApp* a):
   group2=new FXGroupBox(contents,"Slider Tests",GROUPBOX_TITLE_CENTER|FRAME_RIDGE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
   group3=new FXGroupBox(contents,"Title Right",GROUPBOX_TITLE_RIGHT|FRAME_RIDGE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
 
-  FXLabel *testlabel=new FXLabel(group1,"&This is a multi-line\nlabel widget\nwith a big font",NULL,LAYOUT_CENTER_X|JUSTIFY_CENTER_X);
-  testlabel->setFont(new FXFont(getApp(),"helvetica",24,FONTWEIGHT_BOLD,FONTSLANT_ITALIC,FONTENCODING_DEFAULT));
+  FXLabel *testlabel=new FXLabel(group1,"Big Font",NULL,LAYOUT_CENTER_X|JUSTIFY_CENTER_X);
+  testlabel->setFont(new FXFont(getApp(),"helvetica,240,bold,italic"));
 
   new FXButton(group1,"Small &Button",NULL,NULL,0,FRAME_RAISED|FRAME_THICK);
   new FXButton(group1,"Big Fat Wide Button\nComprising\nthree lines",NULL,NULL,0,FRAME_RAISED|FRAME_THICK);
@@ -295,7 +319,8 @@ GroupWindow::GroupWindow(FXApp* a):
   slider=new FXSlider(frame,NULL,0,LAYOUT_FIX_HEIGHT|SLIDER_VERTICAL|SLIDER_ARROW_LEFT|SLIDER_TICKS_LEFT,0,0,30,200);
   slider->setRange(0,10);
   slider=new FXSlider(frame,NULL,0,LAYOUT_FIX_HEIGHT|SLIDER_VERTICAL|SLIDER_INSIDE_BAR|SLIDER_TICKS_LEFT,0,0,20,200);
-  slider->setRange(0,10);
+  slider->setRange(0,7);
+  slider->setTickDelta(7);
   new FXScrollBar(frame,NULL,0,SCROLLBAR_VERTICAL|LAYOUT_FIX_HEIGHT|LAYOUT_FIX_WIDTH,0,0,20,300);
 
   FXVerticalFrame *vframe1=new FXVerticalFrame(frame,LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -332,7 +357,8 @@ GroupWindow::GroupWindow(FXApp* a):
   realspinner->setValue(1.0);
   realspinner->setIncrement(0.1);
 
-  FXComboBox* combobox=new FXComboBox(group3,5,5,NULL,0,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
+  FXComboBox* combobox=new FXComboBox(group3,5,NULL,0,COMBOBOX_INSERT_LAST|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP);
+  combobox->setNumVisible(5);
   combobox->appendItem("Very Wide Item");
   for(int i=0; i<3; i++){
     char name[50];
@@ -340,9 +366,10 @@ GroupWindow::GroupWindow(FXApp* a):
     combobox->appendItem(name);
     }
 
-  FXTreeListBox *treebox=new FXTreeListBox(group3,10,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP,0,0,200,0);
+  FXTreeListBox *treebox=new FXTreeListBox(group3,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP,0,0,200,0);
   FXTreeItem *branch,*twig,*leaf,*topmost,*topmost2;
 
+  treebox->setNumVisible(10);
   topmost=treebox->addItemLast(0,"Top",folder_open,folder_closed);
   topmost2=treebox->addItemLast(0,"Top2",folder_open,folder_closed);
            treebox->addItemLast(topmost2,"First",doc,doc);
@@ -516,12 +543,15 @@ long GroupWindow::onCmdRadio(FXObject*,FXSelector sel,void*){
   return 1;
   }
 
-
+static int full=FALSE;
 // Test of iconify
 long GroupWindow::onCmdIconify(FXObject*,FXSelector,void*){
-  minimize();
-  getApp()->addTimeout(this,ID_DEICONIFY,2000);
-  FXTRACE((1,"iconify\n"));
+//  minimize();
+//  getApp()->addTimeout(this,ID_DEICONIFY,2000);
+//  FXTRACE((1,"iconify\n"));
+		if (full) setDecorations(DECOR_ALL);
+		else setDecorations(DECOR_NONE);
+		full=!full;
   return 1;
   }
 
