@@ -5,7 +5,7 @@
 *********************************************************************************
 * Copyright (C) 1997 by Jeroen van der Zijp.   All Rights Reserved.             *
 *********************************************************************************
-* $Id: table.cpp,v 1.50 2003/08/06 05:06:28 fox Exp $                           *
+* $Id: table.cpp,v 1.61 2004/03/29 15:08:37 fox Exp $                           *
 ********************************************************************************/
 #include "fx.h"
 #include <stdio.h>
@@ -124,18 +124,38 @@ TableWindow::TableWindow(FXApp* a):FXMainWindow(a,"Table Widget Test",NULL,NULL,
   frame=new FXVerticalFrame(contents,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0);
 
   // Table
-  //table=new FXTable(frame,50,13,NULL,0,TABLE_HOR_GRIDLINES|TABLE_VER_GRIDLINES|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 2,2,2,2);
-  table=new FXTable(frame,20,8,this,ID_TABLE,TABLE_COL_SIZABLE|TABLE_ROW_SIZABLE|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 2,2,2,2);
+  table=new FXTable(frame,this,ID_TABLE,TABLE_COL_SIZABLE|TABLE_ROW_SIZABLE|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 2,2,2,2);
+  table->setVisibleRows(20);
+  table->setVisibleColumns(8);
+//  table->setRowHeaderMode(0);
   table->setTableSize(50,14);
+  table->setBackColor(FXRGB(255,255,255));
   table->setCellColor(0,0,FXRGB(255,255,255));
   table->setCellColor(0,1,FXRGB(255,240,240));
   table->setCellColor(1,0,FXRGB(240,255,240));
   table->setCellColor(1,1,FXRGB(240,240,255));
+
+  // Initialize scrollable part of table
+  for(r=0; r<50; r++){
+    for(c=0; c<14; c++){
+      table->setItemText(r,c,"r:"+FXStringVal(r)+" c:"+FXStringVal(c));
+      }
+    }
+
+  // Initialize column headers
+  for(c=0; c<12; c++){
+    table->setColumnText(c,months[c]);
+    }
+
+  // Initialize row headers
+  for(r=0; r<50; r++){
+    table->setRowText(r,"Row"+FXStringVal(r));
+    }
+/*
   table->setLeadingRows(1);
   table->setLeadingColumns(1);
   table->setTrailingRows(1);
   table->setTrailingColumns(1);
-
   // Init corners
   table->setItemText(0,0,FXString::null);
   table->setItemText(0,13,FXString::null);
@@ -159,16 +179,9 @@ TableWindow::TableWindow(FXApp* a):FXMainWindow(a,"Table Widget Test",NULL,NULL,
     table->setItemButton(r,0,TRUE);
     }
   table->setItemButton(49,0,TRUE);
-
-  // Initialize scrollable part of table
-  for(r=1; r<=48; r++){
-    for(c=1; c<=12; c++){
-      table->setItemText(r,c,"r:"+FXStringVal(r)+" c:"+FXStringVal(c));
-      }
-    }
-
+*/
   table->setItemText(10,10,"This is multi-\nline text");
-  table->setRowHeight(10,35);
+//  table->setRowHeight(10,35);
   table->setItemJustify(10,10,FXTableItem::CENTER_X|FXTableItem::CENTER_Y);
 
   table->setItem(3,3,NULL);
@@ -216,6 +229,10 @@ TableWindow::TableWindow(FXApp* a):FXMainWindow(a,"Table Widget Test",NULL,NULL,
   new FXMenuCommand(selectmenu,"Select Row",NULL,table,FXTable::ID_SELECT_ROW);
   new FXMenuCommand(selectmenu,"Select Column",NULL,table,FXTable::ID_SELECT_COLUMN);
   new FXMenuCommand(selectmenu,"Deselect All",NULL,table,FXTable::ID_DESELECT_ALL);
+  new FXMenuCommand(selectmenu,"Cut to clipboard",NULL,table,FXTable::ID_CUT_SEL);
+  new FXMenuCommand(selectmenu,"Copy to clipboard",NULL,table,FXTable::ID_COPY_SEL);
+  new FXMenuCommand(selectmenu,"Paste from clipboard",NULL,table,FXTable::ID_PASTE_SEL);
+  new FXMenuCommand(selectmenu,"Delete",NULL,table,FXTable::ID_DELETE_SEL);
   new FXMenuTitle(menubar,"&Selection",NULL,selectmenu);
   }
 
